/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_B8VpTAXp);
  numBytes += sLine_init(&sLine_hCVSJGeT);
  numBytes += sLine_init(&sLine_PcZhNQpm);
  numBytes += sLine_init(&sLine_YQLUaU4A);
  numBytes += sLine_init(&sLine_Pe5Mm6xx);
  numBytes += sBiquad_init(&sBiquad_s_FhRoeOxW);
  numBytes += sLine_init(&sLine_gN7AeNHa);
  numBytes += sLine_init(&sLine_xbtYZy74);
  numBytes += sLine_init(&sLine_aISBR6S0);
  numBytes += sLine_init(&sLine_Qni8NWXm);
  numBytes += sLine_init(&sLine_moxq9Go6);
  numBytes += sBiquad_init(&sBiquad_s_Zc3gRG0y);
  numBytes += sLine_init(&sLine_G9XBcEEA);
  numBytes += sLine_init(&sLine_h8iT86i4);
  numBytes += sLine_init(&sLine_a2TBZHJR);
  numBytes += sLine_init(&sLine_yxb3L2kN);
  numBytes += sLine_init(&sLine_KMsSoLr7);
  numBytes += sLine_init(&sLine_hu9bTXdi);
  numBytes += sBiquad_init(&sBiquad_s_9VGLwEnd);
  numBytes += sLine_init(&sLine_N7pSDOD1);
  numBytes += sLine_init(&sLine_J3sH5Juy);
  numBytes += sLine_init(&sLine_kjdN2qEs);
  numBytes += sLine_init(&sLine_y8wbx5fi);
  numBytes += sLine_init(&sLine_BjiQgERK);
  numBytes += sLine_init(&sLine_nlbunnz9);
  numBytes += sBiquad_init(&sBiquad_s_65QUhcil);
  numBytes += sLine_init(&sLine_DQ0jUcYo);
  numBytes += sLine_init(&sLine_uAIsNeSY);
  numBytes += sLine_init(&sLine_bQqdC1Jc);
  numBytes += sLine_init(&sLine_VwhbUyhD);
  numBytes += sLine_init(&sLine_DXBNUfbS);
  numBytes += sBiquad_init(&sBiquad_s_YHbQbGwc);
  numBytes += sLine_init(&sLine_BaJpR5jD);
  numBytes += sLine_init(&sLine_NlsXBH3D);
  numBytes += sLine_init(&sLine_IyM0qxL5);
  numBytes += sLine_init(&sLine_wehOwrvB);
  numBytes += sLine_init(&sLine_eG4f4WJG);
  numBytes += sLine_init(&sLine_wC0W9NnK);
  numBytes += sBiquad_init(&sBiquad_s_IHQldDvy);
  numBytes += sLine_init(&sLine_ZMpfhBwT);
  numBytes += sLine_init(&sLine_XLfSsUWi);
  numBytes += sLine_init(&sLine_as1au9Jp);
  numBytes += sLine_init(&sLine_LlPnVQ15);
  numBytes += sLine_init(&sLine_5EgXFMls);
  numBytes += sLine_init(&sLine_tkI2i0YT);
  numBytes += sLine_init(&sLine_fnL2nUtH);
  numBytes += sLine_init(&sLine_H3iVh2tI);
  numBytes += sLine_init(&sLine_deU2Pzd3);
  numBytes += sLine_init(&sLine_FjVRQLnx);
  numBytes += sLine_init(&sLine_RPFrYt74);
  numBytes += sLine_init(&sLine_uQEdBznj);
  numBytes += sLine_init(&sLine_0mK7wafh);
  numBytes += sLine_init(&sLine_eoWW9Pce);
  numBytes += sLine_init(&sLine_jYFd0k10);
  numBytes += sEnv_init(&sEnv_0HmVfmcQ, 512, 256);
  numBytes += sEnv_init(&sEnv_PZ2KquSf, 512, 256);
  numBytes += sLine_init(&sLine_kchRL7yo);
  numBytes += sLine_init(&sLine_UNz9KVcE);
  numBytes += sLine_init(&sLine_rfBuu1Up);
  numBytes += sLine_init(&sLine_f8esvJwG);
  numBytes += sLine_init(&sLine_mzXzoS4N);
  numBytes += sLine_init(&sLine_nUTIg0M4);
  numBytes += sLine_init(&sLine_Ja58qyH4);
  numBytes += sLine_init(&sLine_QI3Yokhg);
  numBytes += sLine_init(&sLine_Dsmpp6Kc);
  numBytes += sLine_init(&sLine_ooj8Okrn);
  numBytes += sLine_init(&sLine_d6JVGv2r);
  numBytes += sLine_init(&sLine_ZCZKqEF8);
  numBytes += sLine_init(&sLine_8ubjhU6f);
  numBytes += sLine_init(&sLine_FFEzuyIQ);
  numBytes += sLine_init(&sLine_NB8pRGaw);
  numBytes += sLine_init(&sLine_AUN6fHQx);
  numBytes += sLine_init(&sLine_d4J8SYe3);
  numBytes += sLine_init(&sLine_mzs1TARu);
  numBytes += sEnv_init(&sEnv_CzX6y72S, 512, 256);
  numBytes += sEnv_init(&sEnv_0kOALBXK, 512, 256);
  numBytes += sLine_init(&sLine_hD9KjdUo);
  numBytes += sLine_init(&sLine_YNniUw2L);
  numBytes += sLine_init(&sLine_V56uGy6H);
  numBytes += sLine_init(&sLine_i7nfuP3z);
  numBytes += sLine_init(&sLine_ZLcSS2Wj);
  numBytes += sLine_init(&sLine_JDNuPB4P);
  numBytes += sLine_init(&sLine_26pryQYb);
  numBytes += sLine_init(&sLine_fiyrj77y);
  numBytes += sLine_init(&sLine_r3onwTIM);
  numBytes += sLine_init(&sLine_3HhGHDQ0);
  numBytes += sLine_init(&sLine_PyfWhrOs);
  numBytes += sLine_init(&sLine_ELsFdM82);
  numBytes += sLine_init(&sLine_1n6euF3C);
  numBytes += sLine_init(&sLine_BYmYGjfl);
  numBytes += sLine_init(&sLine_elVWOgD1);
  numBytes += sLine_init(&sLine_hKG3IoY3);
  numBytes += sLine_init(&sLine_ZFqLCQ1k);
  numBytes += sLine_init(&sLine_WnPWJfst);
  numBytes += sLine_init(&sLine_SSjcjdAH);
  numBytes += sLine_init(&sLine_49vNVd5q);
  numBytes += sEnv_init(&sEnv_07jQv5oD, 512, 256);
  numBytes += sEnv_init(&sEnv_GzsIqgOg, 512, 256);
  numBytes += sLine_init(&sLine_KmqYu8WU);
  numBytes += sLine_init(&sLine_7SVRN5Yo);
  numBytes += sLine_init(&sLine_I0R7Epxf);
  numBytes += sLine_init(&sLine_ogSdFWuu);
  numBytes += sLine_init(&sLine_dSBINeTO);
  numBytes += sLine_init(&sLine_XWNUIbpn);
  numBytes += sLine_init(&sLine_AzoM4Awg);
  numBytes += sLine_init(&sLine_WZTu2RSn);
  numBytes += sLine_init(&sLine_BczxQmEy);
  numBytes += sLine_init(&sLine_iBJFuMKm);
  numBytes += sLine_init(&sLine_fip42Fud);
  numBytes += sLine_init(&sLine_d6kJBYbM);
  numBytes += sLine_init(&sLine_FReKVDpm);
  numBytes += sLine_init(&sLine_fZNbvPTl);
  numBytes += sLine_init(&sLine_8nyuOLmi);
  numBytes += sLine_init(&sLine_xoXuKlgk);
  numBytes += sLine_init(&sLine_C8XQukgW);
  numBytes += sLine_init(&sLine_N6FxBB9Q);
  numBytes += sEnv_init(&sEnv_CEZfNXph, 512, 256);
  numBytes += sEnv_init(&sEnv_esMIjQMD, 512, 256);
  numBytes += sLine_init(&sLine_vunoRvLd);
  numBytes += sLine_init(&sLine_Iupblza6);
  numBytes += sLine_init(&sLine_3hWV6JTz);
  numBytes += sLine_init(&sLine_WcSrq6Qo);
  numBytes += sLine_init(&sLine_YrO2vMUg);
  numBytes += sLine_init(&sLine_4sVTRl64);
  numBytes += sLine_init(&sLine_9wEtTPvR);
  numBytes += sLine_init(&sLine_Gm4CORVX);
  numBytes += sLine_init(&sLine_NDvAocVa);
  numBytes += sLine_init(&sLine_XgqXX4Wf);
  numBytes += sLine_init(&sLine_mB8qETZb);
  numBytes += sLine_init(&sLine_okofCinN);
  numBytes += sLine_init(&sLine_q8tkcxV3);
  numBytes += sLine_init(&sLine_UE3U3iA0);
  numBytes += sLine_init(&sLine_NI487CUj);
  numBytes += sLine_init(&sLine_M1p1ERqF);
  numBytes += sLine_init(&sLine_DJ3H26CZ);
  numBytes += sLine_init(&sLine_VEVOV61h);
  numBytes += sLine_init(&sLine_GAyXeG5q);
  numBytes += sLine_init(&sLine_N3nljExq);
  numBytes += sEnv_init(&sEnv_VbOeiTi6, 512, 256);
  numBytes += sEnv_init(&sEnv_yqSKFNh5, 512, 256);
  numBytes += sLine_init(&sLine_tNHjsHDC);
  numBytes += sLine_init(&sLine_xVLPHzC3);
  numBytes += sLine_init(&sLine_MihoIFMK);
  numBytes += sLine_init(&sLine_bU1QlgXQ);
  numBytes += sLine_init(&sLine_h5P3utxo);
  numBytes += sLine_init(&sLine_ygvUtOtg);
  numBytes += sLine_init(&sLine_h5IzSJuH);
  numBytes += sLine_init(&sLine_a1zP4T8k);
  numBytes += sLine_init(&sLine_7Y9NzMRE);
  numBytes += sLine_init(&sLine_B4iM2IRL);
  numBytes += sLine_init(&sLine_jq63n30X);
  numBytes += sLine_init(&sLine_32HOGny0);
  numBytes += sLine_init(&sLine_FIoLLwn3);
  numBytes += sLine_init(&sLine_XVxykLJp);
  numBytes += sLine_init(&sLine_d3vRVI26);
  numBytes += sLine_init(&sLine_t9OU5TQP);
  numBytes += sLine_init(&sLine_sbI24bLm);
  numBytes += sLine_init(&sLine_X5aH9IJ0);
  numBytes += sEnv_init(&sEnv_0oW4pH8d, 512, 256);
  numBytes += sEnv_init(&sEnv_LZhyhGt6, 512, 256);
  numBytes += sLine_init(&sLine_H3B7m8a5);
  numBytes += sLine_init(&sLine_kimRrmJL);
  numBytes += sLine_init(&sLine_SXDfr4sB);
  numBytes += sLine_init(&sLine_2NkPVBct);
  numBytes += sLine_init(&sLine_YAghyYIJ);
  numBytes += sLine_init(&sLine_XQfxtmDL);
  numBytes += cVar_init_f(&cVar_Lgdc2NJm, 0.0f);
  numBytes += cVar_init_f(&cVar_oNPkBVmv, 0.0f);
  numBytes += cVar_init_f(&cVar_p8BgECbH, 0.0f);
  numBytes += cVar_init_f(&cVar_iEO1H9NN, 0.0f);
  numBytes += cVar_init_f(&cVar_9SwTRX1z, 0.0f);
  numBytes += cVar_init_f(&cVar_0gntx3dC, 1.0f);
  numBytes += cVar_init_f(&cVar_pcH1SsGi, 0.0f);
  numBytes += cVar_init_f(&cVar_7l0QiPRK, 0.0f);
  numBytes += cVar_init_f(&cVar_VHhf3vvh, 0.0f);
  numBytes += cVar_init_f(&cVar_LQlB7YD5, 0.0f);
  numBytes += cSlice_init(&cSlice_wCFoLLjs, 1, -1);
  numBytes += cVar_init_f(&cVar_a8eASCcD, 1337.0f);
  numBytes += cVar_init_f(&cVar_t29uluZS, 0.0f);
  numBytes += cIf_init(&cIf_eKsAfqt9, false);
  numBytes += cIf_init(&cIf_2EGYPRia, false);
  numBytes += cBinop_init(&cBinop_9PUhCPnT, 0.0f); // __pow
  numBytes += cIf_init(&cIf_R8DVWuNH, false);
  numBytes += cBinop_init(&cBinop_PGRRHOOI, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_sZqJBgIG, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Ace5LrL2, 0.0f);
  numBytes += cIf_init(&cIf_OBX9Z9wW, false);
  numBytes += cIf_init(&cIf_HivwkyY5, false);
  numBytes += cBinop_init(&cBinop_X4bJjyal, 0.0f); // __pow
  numBytes += cIf_init(&cIf_HM00EZvo, false);
  numBytes += cBinop_init(&cBinop_cneblnwP, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_LpR8QsGp, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_c2o5UWE1, 0.0f);
  numBytes += cIf_init(&cIf_FBTH6QFM, false);
  numBytes += cIf_init(&cIf_5MV217Zr, false);
  numBytes += cBinop_init(&cBinop_pL5LYgmx, 0.0f); // __pow
  numBytes += cIf_init(&cIf_nlpSWcDw, false);
  numBytes += cBinop_init(&cBinop_QlJxoHaW, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_mUsX75sj, -15.0f); // __eq
  numBytes += cIf_init(&cIf_VIfgxuMd, false);
  numBytes += cSlice_init(&cSlice_XkIE07nN, 1, -1);
  numBytes += cVar_init_f(&cVar_k2f8fgNI, 0.0f);
  numBytes += cSlice_init(&cSlice_z6hb0ZHK, 1, -1);
  numBytes += cVar_init_f(&cVar_d8BMzwng, 0.0f);
  numBytes += cSlice_init(&cSlice_63sFjcsj, 1, -1);
  numBytes += cVar_init_f(&cVar_IxhQXAy1, 0.0f);
  numBytes += cSlice_init(&cSlice_P3aMNg21, 1, -1);
  numBytes += cVar_init_f(&cVar_36Tm3B9Y, 0.313f);
  numBytes += cBinop_init(&cBinop_TvYHXhMx, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_HzGhLvB5, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ZWrbe5gl, 0.0f);
  numBytes += cVar_init_f(&cVar_82KHGqLn, 1337.0f);
  numBytes += cVar_init_f(&cVar_xu92GCYC, 0.3f);
  numBytes += cBinop_init(&cBinop_UZLVI2HV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xbGMFSHc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_oFtsrV4Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZXSreKFV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cXZnQwYc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DiojMUHZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cKprLBcM, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ynx0zw4Q, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_dKLGGUSu, 0.0f);
  numBytes += cVar_init_f(&cVar_VfC27wtP, 1337.0f);
  numBytes += cVar_init_f(&cVar_nJqGhJuo, 0.313f);
  numBytes += cBinop_init(&cBinop_mMN62HOb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_L3dmGNMa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wIp6Uhh1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1eJDRddH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_kxv69Dmv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7QaVc3WG, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_tu1bhuvV, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_XFCVNwbC, 0.0f);
  numBytes += cVar_init_f(&cVar_j9129ntY, 1037.0f);
  numBytes += cVar_init_f(&cVar_7KACCoys, 0.4f);
  numBytes += cBinop_init(&cBinop_fWW7dtve, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_sFhIFKZi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DDvFRlwN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EbfQeSZm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QLv0iUEB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W2YIm9sO, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_bO0o3rzp, 1, -1);
  numBytes += cVar_init_f(&cVar_T9k6fkkJ, 1337.0f);
  numBytes += cVar_init_f(&cVar_7VUUI9HL, 0.0f);
  numBytes += cIf_init(&cIf_Hicy0jyc, false);
  numBytes += cIf_init(&cIf_IzhtVedK, false);
  numBytes += cBinop_init(&cBinop_VECkKR9B, 0.0f); // __pow
  numBytes += cIf_init(&cIf_TheBcSSP, false);
  numBytes += cBinop_init(&cBinop_Jt06vLtz, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_50OtJw0C, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_deZkYkCa, 0.0f);
  numBytes += cIf_init(&cIf_YKvlCInN, false);
  numBytes += cIf_init(&cIf_3h9OFdva, false);
  numBytes += cBinop_init(&cBinop_zrz48N69, 0.0f); // __pow
  numBytes += cIf_init(&cIf_NKUtDQm7, false);
  numBytes += cBinop_init(&cBinop_7spMa9va, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_chngFoWS, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Yd5Pb2s4, 0.0f);
  numBytes += cIf_init(&cIf_y3dQSP2I, false);
  numBytes += cIf_init(&cIf_R6AAY2nu, false);
  numBytes += cBinop_init(&cBinop_eZsNI47V, 0.0f); // __pow
  numBytes += cIf_init(&cIf_sXMQvAGj, false);
  numBytes += cBinop_init(&cBinop_HckfDtwM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_jVHHz7Tf, -15.0f); // __eq
  numBytes += cIf_init(&cIf_0wsxz3b7, false);
  numBytes += cSlice_init(&cSlice_ScKcG1dg, 1, -1);
  numBytes += cVar_init_f(&cVar_5j6OuAA8, 0.0f);
  numBytes += cSlice_init(&cSlice_Tsa54Bg9, 1, -1);
  numBytes += cVar_init_f(&cVar_XJGG8aYv, 0.0f);
  numBytes += cSlice_init(&cSlice_YiDHaHia, 1, -1);
  numBytes += cVar_init_f(&cVar_Wgmp88QU, 0.0f);
  numBytes += cSlice_init(&cSlice_ObxvV62q, 1, -1);
  numBytes += cVar_init_f(&cVar_lwS99WFm, 0.313f);
  numBytes += cBinop_init(&cBinop_kGWB5J27, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_oOMsqrJA, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MMOppUjg, 0.0f);
  numBytes += cVar_init_f(&cVar_HIYQ7wwk, 1337.0f);
  numBytes += cVar_init_f(&cVar_tLA7p3Do, 0.3f);
  numBytes += cBinop_init(&cBinop_01q0NN8p, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7vujqOTW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_XgSZUgel, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9Jz8aq8v, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4nVVKWUm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cLg9fbPO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QJAKpIIa, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_8ok2beXl, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_fbIyYmAi, 0.0f);
  numBytes += cVar_init_f(&cVar_pPN91ibx, 1337.0f);
  numBytes += cVar_init_f(&cVar_g8HYDXRC, 0.313f);
  numBytes += cBinop_init(&cBinop_lwKEZWaT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zLwVTZYS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_olX7IzHV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_i2vd4vSc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_N9TIT2CU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_roGMCtjm, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_aq3bpQm4, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_EmtqbRIP, 0.0f);
  numBytes += cVar_init_f(&cVar_U1mdHZ0V, 1037.0f);
  numBytes += cVar_init_f(&cVar_tsYvaJye, 0.4f);
  numBytes += cBinop_init(&cBinop_0Qyr6E5K, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QLP854iS, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dfiEmn2C, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MyOsED1R, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zZ60LPKh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_KL9bEZpX, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_kFndYKhi, 5705.6f);
  numBytes += cVar_init_f(&cVar_lmyRChT3, 313.3f);
  numBytes += cBinop_init(&cBinop_RdCAb3i1, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_Gn8Lomwr, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_uj0a4Uwa, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_sH0QT4dx, 1, -1);
  numBytes += cVar_init_f(&cVar_bkg3uMst, 0.5f);
  numBytes += cVar_init_f(&cVar_egflv3T5, 0.0f);
  numBytes += cVar_init_f(&cVar_4UC0LJoE, 0.0f);
  numBytes += cIf_init(&cIf_t71lXQS1, false);
  numBytes += cIf_init(&cIf_iU1QOWAm, false);
  numBytes += cDelay_init(this, &cDelay_vilMkgv9, 10.0f);
  numBytes += cIf_init(&cIf_evUshZiX, false);
  numBytes += cIf_init(&cIf_ca0IS25G, false);
  numBytes += cDelay_init(this, &cDelay_b6po0c11, 10.0f);
  numBytes += cIf_init(&cIf_78TQw9IX, false);
  numBytes += cIf_init(&cIf_1ND61wM6, false);
  numBytes += cDelay_init(this, &cDelay_Tsrji8MY, 10.0f);
  numBytes += cIf_init(&cIf_2upPUHYa, false);
  numBytes += cIf_init(&cIf_ho1JxjTD, false);
  numBytes += cDelay_init(this, &cDelay_WN8sFm0P, 10.0f);
  numBytes += cIf_init(&cIf_O4T7fQEY, false);
  numBytes += cIf_init(&cIf_RWTiGZxu, false);
  numBytes += cDelay_init(this, &cDelay_RWxjcSYu, 10.0f);
  numBytes += cIf_init(&cIf_GDCvvFyn, false);
  numBytes += cIf_init(&cIf_QGWKqVs8, false);
  numBytes += cDelay_init(this, &cDelay_yxOTr7ee, 10.0f);
  numBytes += cIf_init(&cIf_bkTQ1BJd, false);
  numBytes += cIf_init(&cIf_DjKLBCE4, false);
  numBytes += cDelay_init(this, &cDelay_UGPjp5rN, 10.0f);
  numBytes += cIf_init(&cIf_GjH9CWut, false);
  numBytes += cIf_init(&cIf_HtXilm79, false);
  numBytes += cDelay_init(this, &cDelay_K0JWMt79, 10.0f);
  numBytes += cIf_init(&cIf_LOA7wfky, false);
  numBytes += cIf_init(&cIf_kk6ZekkG, false);
  numBytes += cDelay_init(this, &cDelay_7zyBaYiH, 10.0f);
  numBytes += cIf_init(&cIf_5yTpbZea, false);
  numBytes += cIf_init(&cIf_Gv31AX3n, false);
  numBytes += cDelay_init(this, &cDelay_419sMKDP, 10.0f);
  numBytes += cIf_init(&cIf_0rLrxaH1, false);
  numBytes += cIf_init(&cIf_n3WgGuss, false);
  numBytes += cDelay_init(this, &cDelay_y3Qbfqa2, 10.0f);
  numBytes += cIf_init(&cIf_GruTZCgW, false);
  numBytes += cIf_init(&cIf_kZOVNxrf, false);
  numBytes += cDelay_init(this, &cDelay_rc77y8oz, 10.0f);
  numBytes += sVarf_init(&sVarf_zlmHmdW0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9HAsJHMK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kd6CgsgT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YFySq87M, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KPHTtcg4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fGZK0rZh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_07yYVCzh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_o6xza5w8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_yIEV25Mi, 0.0f);
  numBytes += cSlice_init(&cSlice_SSrQGC1H, 1, -1);
  numBytes += cVar_init_f(&cVar_28gt6RSI, 1.0f);
  numBytes += cSlice_init(&cSlice_TQZp1Ggu, 1, -1);
  numBytes += cVar_init_f(&cVar_bRilKh5J, 0.0f);
  numBytes += cSlice_init(&cSlice_I0On8hyq, 1, -1);
  numBytes += cVar_init_f(&cVar_dnhbZgDr, 512.0f);
  numBytes += cSlice_init(&cSlice_ehgNYP1S, 1, -1);
  numBytes += cVar_init_f(&cVar_cm0FqbEe, 1.0f);
  numBytes += cSlice_init(&cSlice_CyZsZCq7, 1, -1);
  numBytes += cVar_init_f(&cVar_HIxdO1aO, 1.0f);
  numBytes += cDelay_init(this, &cDelay_6VoPlOUa, 20.0f);
  numBytes += cVar_init_f(&cVar_MXXGbrsh, 0.0f);
  numBytes += cIf_init(&cIf_AO7HaYPV, false);
  numBytes += cIf_init(&cIf_4kf5O6KA, false);
  numBytes += cBinop_init(&cBinop_bOlG5xtA, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_VGkQk9mI, 1, -1);
  numBytes += cVar_init_f(&cVar_QravkE1l, 0.0f);
  numBytes += sVarf_init(&sVarf_Q8XVUF8L, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0KY9QWJo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_u5CNuUPq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_A3DfOGSg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KZD5r2HZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yCtzL4d5, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lnyGf284, 0.0f);
  numBytes += cVar_init_f(&cVar_ACcsiWZz, 0.0f);
  numBytes += cIf_init(&cIf_1Yl4dDlv, false);
  numBytes += cIf_init(&cIf_Gs7eCnkd, false);
  numBytes += cDelay_init(this, &cDelay_xWoauPMa, 10.0f);
  numBytes += cIf_init(&cIf_lPLwdhNC, false);
  numBytes += cIf_init(&cIf_jOb61Dt1, false);
  numBytes += cDelay_init(this, &cDelay_Jn9cmKLp, 10.0f);
  numBytes += cIf_init(&cIf_3fqIVLl6, false);
  numBytes += cIf_init(&cIf_lWRaesU6, false);
  numBytes += cDelay_init(this, &cDelay_9yV1QODw, 10.0f);
  numBytes += cIf_init(&cIf_xPNekRfS, false);
  numBytes += cIf_init(&cIf_kk9PwCsE, false);
  numBytes += cDelay_init(this, &cDelay_ZX3sIr48, 10.0f);
  numBytes += cIf_init(&cIf_KKlFhYDs, false);
  numBytes += cIf_init(&cIf_GM95mZ2O, false);
  numBytes += cDelay_init(this, &cDelay_hZCIJXwQ, 10.0f);
  numBytes += cIf_init(&cIf_6SDKq8hW, false);
  numBytes += cIf_init(&cIf_dkKuimYF, false);
  numBytes += cDelay_init(this, &cDelay_JaqsoUD0, 10.0f);
  numBytes += cIf_init(&cIf_lXGApP8e, false);
  numBytes += cIf_init(&cIf_h7Hsq6DP, false);
  numBytes += cDelay_init(this, &cDelay_DsZhpH6E, 10.0f);
  numBytes += cIf_init(&cIf_5YetaJWa, false);
  numBytes += cIf_init(&cIf_lhr3OkLo, false);
  numBytes += cDelay_init(this, &cDelay_mNcwFoUJ, 10.0f);
  numBytes += cIf_init(&cIf_lBQDRyjC, false);
  numBytes += cIf_init(&cIf_FBPcCN55, false);
  numBytes += cDelay_init(this, &cDelay_qhFcr35G, 10.0f);
  numBytes += cIf_init(&cIf_coGAOHxd, false);
  numBytes += cIf_init(&cIf_jKUorcr9, false);
  numBytes += cDelay_init(this, &cDelay_3e232xCU, 10.0f);
  numBytes += cIf_init(&cIf_czvgA84n, false);
  numBytes += cIf_init(&cIf_OgCZ1IQT, false);
  numBytes += cDelay_init(this, &cDelay_sSvetzE9, 10.0f);
  numBytes += cIf_init(&cIf_WANSJZ4E, false);
  numBytes += cIf_init(&cIf_gv9rfD6u, false);
  numBytes += cDelay_init(this, &cDelay_ghzjECAq, 10.0f);
  numBytes += sVarf_init(&sVarf_nwz3einT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qKiMqxDi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dEkXqIwj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PI1T9EXF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dmugJmfW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rZR4PDFP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qy9KURN6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B6Eh2GKu, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_lrBKp10r, 0.0f);
  numBytes += cSlice_init(&cSlice_qiEjItvi, 1, -1);
  numBytes += cVar_init_f(&cVar_dS4N0SbW, 1.0f);
  numBytes += cSlice_init(&cSlice_aGxTWCRN, 1, -1);
  numBytes += cVar_init_f(&cVar_xCaSPl2j, 0.0f);
  numBytes += cSlice_init(&cSlice_45ogEDC3, 1, -1);
  numBytes += cVar_init_f(&cVar_jYrPM3Dj, 512.0f);
  numBytes += cSlice_init(&cSlice_OA7xIJuA, 1, -1);
  numBytes += cVar_init_f(&cVar_byBSdWrA, 1.0f);
  numBytes += cSlice_init(&cSlice_qwIVBAD7, 1, -1);
  numBytes += cVar_init_f(&cVar_4HE3UrFm, 1.0f);
  numBytes += cDelay_init(this, &cDelay_YHpSIfv2, 20.0f);
  numBytes += cVar_init_f(&cVar_lflBS7bj, 0.0f);
  numBytes += cIf_init(&cIf_tsctJHfE, false);
  numBytes += cIf_init(&cIf_BBWVVRt2, false);
  numBytes += cBinop_init(&cBinop_rH6h0KR5, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_XRcEUjvK, 1, -1);
  numBytes += cVar_init_f(&cVar_ELBmc68E, 0.0f);
  numBytes += sVarf_init(&sVarf_p8NgpJiF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wk3ruqcA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_efcBuVB3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ytLlpGCD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8XwR9bVo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sx7uAh1p, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Oz54zCxp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xJGWkDXq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l2RneahV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_301BvmGE, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_U65c1Fgq, 0.0f);
  numBytes += cVar_init_f(&cVar_DWaNM7nr, 0.0f);
  numBytes += cVar_init_f(&cVar_BIDTOkDp, 0.0f);
  numBytes += cVar_init_f(&cVar_Sdo3lpDM, 0.0f);
  numBytes += cVar_init_f(&cVar_Df8NG4jh, 0.0f);
  numBytes += cVar_init_f(&cVar_9bPzjpAS, 1.0f);
  numBytes += cSlice_init(&cSlice_I79RVpmu, 1, -1);
  numBytes += cVar_init_f(&cVar_znBPjYnm, 0.5f);
  numBytes += cVar_init_f(&cVar_kAsO31UA, 0.0f);
  numBytes += cVar_init_f(&cVar_gTwxuUUj, 0.0f);
  numBytes += cIf_init(&cIf_N406Go82, false);
  numBytes += cIf_init(&cIf_5N7z5Lc3, false);
  numBytes += cDelay_init(this, &cDelay_MOf91FGT, 10.0f);
  numBytes += cIf_init(&cIf_cG5Y7zkl, false);
  numBytes += cIf_init(&cIf_GaYfDQNM, false);
  numBytes += cDelay_init(this, &cDelay_h9YI0HEr, 10.0f);
  numBytes += cIf_init(&cIf_SWtr1Jdx, false);
  numBytes += cIf_init(&cIf_hWd1Bl6K, false);
  numBytes += cDelay_init(this, &cDelay_L36TfjxB, 10.0f);
  numBytes += cIf_init(&cIf_WWYALG1J, false);
  numBytes += cIf_init(&cIf_0eEQeqNg, false);
  numBytes += cDelay_init(this, &cDelay_OBlSSEJl, 10.0f);
  numBytes += cIf_init(&cIf_w6UQnE3X, false);
  numBytes += cIf_init(&cIf_AtjLhKCz, false);
  numBytes += cDelay_init(this, &cDelay_0skOWL7P, 10.0f);
  numBytes += cIf_init(&cIf_VSIrmLuN, false);
  numBytes += cIf_init(&cIf_ls68C0BA, false);
  numBytes += cDelay_init(this, &cDelay_1is1dWtL, 10.0f);
  numBytes += cIf_init(&cIf_wB7wemb3, false);
  numBytes += cIf_init(&cIf_Hd5vaaBr, false);
  numBytes += cDelay_init(this, &cDelay_ajXylLQC, 10.0f);
  numBytes += cIf_init(&cIf_drSIUGle, false);
  numBytes += cIf_init(&cIf_sgMkvW35, false);
  numBytes += cDelay_init(this, &cDelay_gTKZCYOh, 10.0f);
  numBytes += cIf_init(&cIf_sm4Rfkce, false);
  numBytes += cIf_init(&cIf_BbmL5yJr, false);
  numBytes += cDelay_init(this, &cDelay_Vrit6Gf0, 10.0f);
  numBytes += cIf_init(&cIf_NvFilMhR, false);
  numBytes += cIf_init(&cIf_irVWBLT2, false);
  numBytes += cDelay_init(this, &cDelay_F0ei79Ck, 10.0f);
  numBytes += cIf_init(&cIf_TV3aYk5I, false);
  numBytes += cIf_init(&cIf_X3eNGoeX, false);
  numBytes += cDelay_init(this, &cDelay_XzKQisgU, 10.0f);
  numBytes += cIf_init(&cIf_gQJn5gtX, false);
  numBytes += cIf_init(&cIf_BZX6gtFm, false);
  numBytes += cDelay_init(this, &cDelay_zYE7qVKN, 10.0f);
  numBytes += sVarf_init(&sVarf_Rhqa2uE3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_myooPsZ2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_P7lutH8Y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wENodh5n, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Eeg5HPsV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XzdS5UXi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Nx1dE2Iy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_C7OLZwnh, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Df7FmTrw, 0.0f);
  numBytes += cSlice_init(&cSlice_naXEHPUZ, 1, -1);
  numBytes += cVar_init_f(&cVar_Fy8ab7Nx, 1.0f);
  numBytes += cSlice_init(&cSlice_Vzs12xSd, 1, -1);
  numBytes += cVar_init_f(&cVar_RuMTqrAU, 0.0f);
  numBytes += cSlice_init(&cSlice_CTKqlNeR, 1, -1);
  numBytes += cVar_init_f(&cVar_Knxxtkzz, 512.0f);
  numBytes += cSlice_init(&cSlice_JFgrpWzc, 1, -1);
  numBytes += cVar_init_f(&cVar_7oueZOyc, 1.0f);
  numBytes += cSlice_init(&cSlice_FIR4qpoS, 1, -1);
  numBytes += cVar_init_f(&cVar_t0PBCmDi, 1.0f);
  numBytes += cDelay_init(this, &cDelay_ozq0BMOV, 20.0f);
  numBytes += cVar_init_f(&cVar_yiwzQT5I, 0.0f);
  numBytes += cIf_init(&cIf_uH8MQqrw, false);
  numBytes += cIf_init(&cIf_oqEcZqgp, false);
  numBytes += cBinop_init(&cBinop_FA2YVFEe, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_Az0zUi4p, 1, -1);
  numBytes += cVar_init_f(&cVar_3yk4dewA, 0.0f);
  numBytes += sVarf_init(&sVarf_YJBQCD2V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AyeqazWZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FjWm0Hby, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MkpviS73, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QOEfrcVk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cmiLLLWe, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Gzn2XyHT, 0.0f);
  numBytes += cVar_init_f(&cVar_fOt8modM, 0.0f);
  numBytes += cIf_init(&cIf_MOmWDVVX, false);
  numBytes += cIf_init(&cIf_gLDLq9sG, false);
  numBytes += cDelay_init(this, &cDelay_Keo3JHMO, 10.0f);
  numBytes += cIf_init(&cIf_kPiJSL7R, false);
  numBytes += cIf_init(&cIf_MypIK6hg, false);
  numBytes += cDelay_init(this, &cDelay_13GVCgbF, 10.0f);
  numBytes += cIf_init(&cIf_9N93RWIg, false);
  numBytes += cIf_init(&cIf_voui1Keb, false);
  numBytes += cDelay_init(this, &cDelay_BiqC81sF, 10.0f);
  numBytes += cIf_init(&cIf_MSRUiIIr, false);
  numBytes += cIf_init(&cIf_kxMURTSy, false);
  numBytes += cDelay_init(this, &cDelay_CVEkDFYq, 10.0f);
  numBytes += cIf_init(&cIf_AgHtakaE, false);
  numBytes += cIf_init(&cIf_yrmZYMCy, false);
  numBytes += cDelay_init(this, &cDelay_UFkQ5m4H, 10.0f);
  numBytes += cIf_init(&cIf_HIdd76zM, false);
  numBytes += cIf_init(&cIf_qY4fFNNJ, false);
  numBytes += cDelay_init(this, &cDelay_mQ00n06L, 10.0f);
  numBytes += cIf_init(&cIf_IS74DbwV, false);
  numBytes += cIf_init(&cIf_JU6cjnxp, false);
  numBytes += cDelay_init(this, &cDelay_zfXqE4me, 10.0f);
  numBytes += cIf_init(&cIf_tPAg6k8r, false);
  numBytes += cIf_init(&cIf_tgq2RQ6s, false);
  numBytes += cDelay_init(this, &cDelay_yYC9wVOq, 10.0f);
  numBytes += cIf_init(&cIf_BzHATfAk, false);
  numBytes += cIf_init(&cIf_5imHBnKW, false);
  numBytes += cDelay_init(this, &cDelay_1765GqpX, 10.0f);
  numBytes += cIf_init(&cIf_d46MQwm9, false);
  numBytes += cIf_init(&cIf_21Ol0d45, false);
  numBytes += cDelay_init(this, &cDelay_vdOmVxoz, 10.0f);
  numBytes += cIf_init(&cIf_ihCBaS1T, false);
  numBytes += cIf_init(&cIf_nTRgZSJX, false);
  numBytes += cDelay_init(this, &cDelay_YYOBXyGu, 10.0f);
  numBytes += cIf_init(&cIf_t1iDZxCl, false);
  numBytes += cIf_init(&cIf_ppIyWcs3, false);
  numBytes += cDelay_init(this, &cDelay_SMIv4PgW, 10.0f);
  numBytes += sVarf_init(&sVarf_RmkJYO76, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jyllSyN4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qE3hOzfR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oktpr2VI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iylwZ1xl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nHlPE4pD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GBnqKIgY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZFpV6TKb, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_hHScpxpH, 0.0f);
  numBytes += cSlice_init(&cSlice_B4J1VOOt, 1, -1);
  numBytes += cVar_init_f(&cVar_rIvGLzZp, 1.0f);
  numBytes += cSlice_init(&cSlice_jCnkPcPT, 1, -1);
  numBytes += cVar_init_f(&cVar_48U1IPvw, 0.0f);
  numBytes += cSlice_init(&cSlice_ftZyTJMc, 1, -1);
  numBytes += cVar_init_f(&cVar_RvIsNlho, 512.0f);
  numBytes += cSlice_init(&cSlice_X4vAF0Ol, 1, -1);
  numBytes += cVar_init_f(&cVar_lYhfEjTh, 1.0f);
  numBytes += cSlice_init(&cSlice_j77G3Y23, 1, -1);
  numBytes += cVar_init_f(&cVar_Egmh9Lpf, 1.0f);
  numBytes += cDelay_init(this, &cDelay_OCdOPhql, 20.0f);
  numBytes += cVar_init_f(&cVar_u8wCF9Zr, 0.0f);
  numBytes += cIf_init(&cIf_rDer0hQu, false);
  numBytes += cIf_init(&cIf_HUkkRbFB, false);
  numBytes += cBinop_init(&cBinop_duPRIQW8, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_uU2prGey, 1, -1);
  numBytes += cVar_init_f(&cVar_Gd9H39Ob, 0.0f);
  numBytes += sVarf_init(&sVarf_JGofW8Qs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iJGAORtR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dTd6nGt3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Yd32b5hZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7mGfusUl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QNxZxfb2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_boRTuumQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LZRRZoeg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yllOb11Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fN1VLAo0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ZX9Wv4MV, 0.0f);
  numBytes += cVar_init_f(&cVar_A5wjfCZV, 0.0f);
  numBytes += cVar_init_f(&cVar_gYNkXc1B, 0.0f);
  numBytes += cVar_init_f(&cVar_oskUz3BR, 0.0f);
  numBytes += cVar_init_f(&cVar_uVUKfnUT, 0.0f);
  numBytes += cVar_init_f(&cVar_0JYD7tiy, 1.0f);
  numBytes += cSlice_init(&cSlice_6W79JXnV, 1, -1);
  numBytes += cVar_init_f(&cVar_xioJyzjb, 0.5f);
  numBytes += cVar_init_f(&cVar_cYrB7Djs, 0.0f);
  numBytes += cVar_init_f(&cVar_ptjNQ6Tq, 0.0f);
  numBytes += cIf_init(&cIf_OgcR0xWX, false);
  numBytes += cIf_init(&cIf_0ZO13K8N, false);
  numBytes += cDelay_init(this, &cDelay_zLcP0nvz, 10.0f);
  numBytes += cIf_init(&cIf_yjIJvUzM, false);
  numBytes += cIf_init(&cIf_AZqoqAvA, false);
  numBytes += cDelay_init(this, &cDelay_Y9R0JkxV, 10.0f);
  numBytes += cIf_init(&cIf_4mRCU1Rw, false);
  numBytes += cIf_init(&cIf_Hhb1tRtU, false);
  numBytes += cDelay_init(this, &cDelay_b5rQMY1u, 10.0f);
  numBytes += cIf_init(&cIf_mwjY1Kze, false);
  numBytes += cIf_init(&cIf_FNf4LkC3, false);
  numBytes += cDelay_init(this, &cDelay_ag5fQWJ5, 10.0f);
  numBytes += cIf_init(&cIf_RW3TcrS3, false);
  numBytes += cIf_init(&cIf_P7RI5dkz, false);
  numBytes += cDelay_init(this, &cDelay_MsNiBi34, 10.0f);
  numBytes += cIf_init(&cIf_2nvRiqfA, false);
  numBytes += cIf_init(&cIf_MRw0Fx75, false);
  numBytes += cDelay_init(this, &cDelay_0nlH3tWC, 10.0f);
  numBytes += cIf_init(&cIf_mHomiVh1, false);
  numBytes += cIf_init(&cIf_9Sj2pNKL, false);
  numBytes += cDelay_init(this, &cDelay_uXbfeJOS, 10.0f);
  numBytes += cIf_init(&cIf_0JwEF1lC, false);
  numBytes += cIf_init(&cIf_dVxSGaj1, false);
  numBytes += cDelay_init(this, &cDelay_0f9GsR4s, 10.0f);
  numBytes += cIf_init(&cIf_3ETBWQQE, false);
  numBytes += cIf_init(&cIf_EoX3c2Ah, false);
  numBytes += cDelay_init(this, &cDelay_rTP6GvBl, 10.0f);
  numBytes += cIf_init(&cIf_9DcQ37h8, false);
  numBytes += cIf_init(&cIf_BvGLd2Yn, false);
  numBytes += cDelay_init(this, &cDelay_uF5hn9Bm, 10.0f);
  numBytes += cIf_init(&cIf_ImDll9J0, false);
  numBytes += cIf_init(&cIf_aZpcyXJg, false);
  numBytes += cDelay_init(this, &cDelay_gJbc8nye, 10.0f);
  numBytes += cIf_init(&cIf_mSdQQt0Z, false);
  numBytes += cIf_init(&cIf_hA4d1law, false);
  numBytes += cDelay_init(this, &cDelay_5aFfu2LM, 10.0f);
  numBytes += sVarf_init(&sVarf_a7RJ8pMI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cXT4ly8y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cxeavKNf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OFsQ6zBR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GDRMpUWh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T9iTm35d, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jvlQIHoi, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bcTh77DA, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_hvD66egp, 0.0f);
  numBytes += cSlice_init(&cSlice_y20qKm5Q, 1, -1);
  numBytes += cVar_init_f(&cVar_esMFhHkZ, 1.0f);
  numBytes += cSlice_init(&cSlice_BVZLTVr3, 1, -1);
  numBytes += cVar_init_f(&cVar_l03E5NFn, 0.0f);
  numBytes += cSlice_init(&cSlice_N1dUBT6f, 1, -1);
  numBytes += cVar_init_f(&cVar_elQrobAs, 512.0f);
  numBytes += cSlice_init(&cSlice_cBgLRigu, 1, -1);
  numBytes += cVar_init_f(&cVar_k4UvNNfc, 1.0f);
  numBytes += cSlice_init(&cSlice_a4yWsZSj, 1, -1);
  numBytes += cVar_init_f(&cVar_3rFsWThy, 1.0f);
  numBytes += cDelay_init(this, &cDelay_gfkKhcl1, 20.0f);
  numBytes += cVar_init_f(&cVar_kN6PYeKN, 0.0f);
  numBytes += cIf_init(&cIf_b3Tr2nBp, false);
  numBytes += cIf_init(&cIf_WViZEuTG, false);
  numBytes += cBinop_init(&cBinop_U5OyVyLv, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_WZHU89Az, 1, -1);
  numBytes += cVar_init_f(&cVar_bKRJLI8W, 0.0f);
  numBytes += sVarf_init(&sVarf_QixrpCEQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_utxZkkju, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gvsYJlTK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_r57eLSDZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cMwdiEmN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_56YKbWiK, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ziv4TCOm, 0.0f);
  numBytes += cVar_init_f(&cVar_d0nL95km, 0.0f);
  numBytes += cIf_init(&cIf_fsWELQVM, false);
  numBytes += cIf_init(&cIf_i95SjX4J, false);
  numBytes += cDelay_init(this, &cDelay_0sJKAH2l, 10.0f);
  numBytes += cIf_init(&cIf_5iI7lBGQ, false);
  numBytes += cIf_init(&cIf_1a7mLjvD, false);
  numBytes += cDelay_init(this, &cDelay_Y1CbydSc, 10.0f);
  numBytes += cIf_init(&cIf_SzQVb3nc, false);
  numBytes += cIf_init(&cIf_kuRPpUKM, false);
  numBytes += cDelay_init(this, &cDelay_oQG7lRUA, 10.0f);
  numBytes += cIf_init(&cIf_DDiZfLfD, false);
  numBytes += cIf_init(&cIf_PcyBNWOo, false);
  numBytes += cDelay_init(this, &cDelay_4aSvqN0Y, 10.0f);
  numBytes += cIf_init(&cIf_M3O2afSr, false);
  numBytes += cIf_init(&cIf_W3m1VkFF, false);
  numBytes += cDelay_init(this, &cDelay_Y9BdBT7A, 10.0f);
  numBytes += cIf_init(&cIf_V4VzFz5l, false);
  numBytes += cIf_init(&cIf_MdwjivAK, false);
  numBytes += cDelay_init(this, &cDelay_1S41F4pg, 10.0f);
  numBytes += cIf_init(&cIf_YPnK61nS, false);
  numBytes += cIf_init(&cIf_vArZgK2C, false);
  numBytes += cDelay_init(this, &cDelay_Bd1NwBJW, 10.0f);
  numBytes += cIf_init(&cIf_n8q5SITd, false);
  numBytes += cIf_init(&cIf_K4ugri5t, false);
  numBytes += cDelay_init(this, &cDelay_ny7LNx9L, 10.0f);
  numBytes += cIf_init(&cIf_sD0xcbCy, false);
  numBytes += cIf_init(&cIf_oheanOqr, false);
  numBytes += cDelay_init(this, &cDelay_DcE4QbZP, 10.0f);
  numBytes += cIf_init(&cIf_aYwZOvbe, false);
  numBytes += cIf_init(&cIf_JFJ1geJN, false);
  numBytes += cDelay_init(this, &cDelay_xhljCyzY, 10.0f);
  numBytes += cIf_init(&cIf_v8V6MjcD, false);
  numBytes += cIf_init(&cIf_ITVdBsIa, false);
  numBytes += cDelay_init(this, &cDelay_nppsJd9h, 10.0f);
  numBytes += cIf_init(&cIf_2gAolVg1, false);
  numBytes += cIf_init(&cIf_EUG2GJzX, false);
  numBytes += cDelay_init(this, &cDelay_w8YFZfc1, 10.0f);
  numBytes += sVarf_init(&sVarf_JXxpcs1C, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YyEKNKGq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tY4vqW83, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KY1cZi8a, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZwR86er3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pu5XSZyb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1Ea58nho, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rufkVpm4, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_VjpPQ4tC, 0.0f);
  numBytes += cSlice_init(&cSlice_kFTDXIk8, 1, -1);
  numBytes += cVar_init_f(&cVar_mvTtlBvk, 1.0f);
  numBytes += cSlice_init(&cSlice_Hri8LROb, 1, -1);
  numBytes += cVar_init_f(&cVar_F2Y7HQcM, 0.0f);
  numBytes += cSlice_init(&cSlice_p1XlZIRs, 1, -1);
  numBytes += cVar_init_f(&cVar_FZB0ZcyI, 512.0f);
  numBytes += cSlice_init(&cSlice_Fublmqw5, 1, -1);
  numBytes += cVar_init_f(&cVar_EHvukwr3, 1.0f);
  numBytes += cSlice_init(&cSlice_QtIoCRRp, 1, -1);
  numBytes += cVar_init_f(&cVar_aBaYNcqe, 1.0f);
  numBytes += cDelay_init(this, &cDelay_hdMNj3cw, 20.0f);
  numBytes += cVar_init_f(&cVar_CTNK4np4, 0.0f);
  numBytes += cIf_init(&cIf_SLnefy9F, false);
  numBytes += cIf_init(&cIf_Z3Yew3A4, false);
  numBytes += cBinop_init(&cBinop_EFPgFzbQ, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_PeZbOSGe, 1, -1);
  numBytes += cVar_init_f(&cVar_V2ZpxfWM, 0.0f);
  numBytes += sVarf_init(&sVarf_9vfhUxjv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1ClGFzmH, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p0qEee95, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PKKWqEdV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s7mlO3VF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gasrCciw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cWUxwiKw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gFEK1e2V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DICPepow, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PVOSpCGO, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JHogYyi2, 0.0f);
  numBytes += cVar_init_f(&cVar_76U8aiaE, 0.0f);
  numBytes += cVar_init_f(&cVar_J3EUOL4D, 0.0f);
  numBytes += sVarf_init(&sVarf_f19T5txh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KjFml1tN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2KpkWvp2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_x16RsUrd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IpRNBWVU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SaM7xH3r, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_C8pZIDpj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HCFW3yT7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HN3ANOlN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_reJO9akO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_URFlykIs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aJgXMgLX, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_0HmVfmcQ);
  sEnv_free(&sEnv_PZ2KquSf);
  sEnv_free(&sEnv_CzX6y72S);
  sEnv_free(&sEnv_0kOALBXK);
  sEnv_free(&sEnv_07jQv5oD);
  sEnv_free(&sEnv_GzsIqgOg);
  sEnv_free(&sEnv_CEZfNXph);
  sEnv_free(&sEnv_esMIjQMD);
  sEnv_free(&sEnv_VbOeiTi6);
  sEnv_free(&sEnv_yqSKFNh5);
  sEnv_free(&sEnv_0oW4pH8d);
  sEnv_free(&sEnv_LZhyhGt6);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qeBgpYjg_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FF68wK0S_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cxdHwCVK_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FO1bNkuR_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TZlZEZjf_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aWY7La0r_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7OMe6F37_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sGvYf9Wt_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bKBKOxHG_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_t9TFYvcK_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QIxboBLl_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ofDkbl2Q_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WkHT1t5Y_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TGatSi5r_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vBfp72iV_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9AO3cKfV_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qr3zUSvB_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Nymg8WOv_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rmOHNeNp_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FqtxxQ2v_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3sBPe6DG_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IvYXFDxj_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Jq3MWhEu_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7Z8MLVRN_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I37p7P2U_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cHODZiqS_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cNecRfs9_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HsxE3R6H_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8z6NW0pt_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G7AZZJAE_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Gh8ACpZe_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AfsD5W05_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_37IrWNZg_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l4B0dvUQ_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Smp9PkP5_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ygTsrcEc_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f82Pm7LD_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eeHq7nRF_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_48rDKiz1_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4noZkWWw_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YBATEbzO_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SbQAbDdr_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kuixHftH_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GPsSGD2v_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nW0QQuVs_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_y1matWRC_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XHaenwID_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZRbk3UBI_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eWMaMjCA_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Cg7CnHei_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gXtewtfd_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_czjXeeV7_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Oxk22QTk_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eRe6FGl1_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QmSFIOwO_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3sIuJVT2_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HUSobkk6_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n8yEkPHr_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hiJ3Y6L2_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_17ddtp5V_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gTH9AigY_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YCZT5bSZ_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RnzXylPY_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MjSfk0li_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4DsqxIPX_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T8350C9h_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_grs6P37p_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZCPKQpUX_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uh6qG0Be_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zEbLFWsK_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KYciATec_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qOblx3YZ_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1TurlE60_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ebs5Tv8C_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nSl8pbi7_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tXf7qvH8_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_loVKCh43_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XAgP5bex_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vXwFT9CL_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eq01d5fz_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HHgEpOb5_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lRkGrv7S_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sgDqyKCI_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Az1Z813o_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NeBwzRFY_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_65E3XGrF_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_itCH8w6K_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R3goB1eP_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zQef4QhO_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jUIFJC4d_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rIJM5ZMH_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QzSDW1Ch_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hmtNb6SG_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_Lgdc2NJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vsIPu6R6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_oNPkBVmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_klLqTZdr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_p8BgECbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_laBpC56H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_iEO1H9NN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O88oDTIa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9SwTRX1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5pp04Fpn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0gntx3dC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WiNoIXFa_sendMessage);
  cMsg_jyvx32lx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WiNoIXFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0gntx3dC, 1, m, &cVar_0gntx3dC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ql8uIEuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lPPCpfsq_sendMessage(_c, 0, m);
  cMsg_pVsBevlr_sendMessage(_c, 0, m);
  cMsg_YTxe5TsH_sendMessage(_c, 0, m);
  cMsg_3BRb2IlT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pcH1SsGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AxtYVOtF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_7l0QiPRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_46QnCIbm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_VHhf3vvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vWE7IDw0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_LQlB7YD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jK7GLV2V_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_59L03IdR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dAjtZr2d_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8YLJYVfU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3h39PxZ6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wCFoLLjs, 0, m, &cSlice_wCFoLLjs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xbpzOzH8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_wCFoLLjs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fEXqc3uz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fEXqc3uz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_a8eASCcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fEXqc3uz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fEXqc3uz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HsxE3R6H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_t29uluZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cKFlR5kF_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_eKsAfqt9, 0, m, &cIf_eKsAfqt9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_eKsAfqt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_LAsXix17_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2EGYPRia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Ia4dGm40_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_zKkHZ9C5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_VzwE0lqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9PUhCPnT, HV_BINOP_POW, 0, m, &cBinop_9PUhCPnT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9PUhCPnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R8DVWuNH, 0, m, &cIf_R8DVWuNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G6q1OK0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_3kwYN9gQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZNbWLACP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HiNSGaov_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3KcDqf3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2EGYPRia, 0, m, &cIf_2EGYPRia_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HiNSGaov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2EGYPRia, 1, m, &cIf_2EGYPRia_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zKkHZ9C5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_G6q1OK0q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ia4dGm40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_R8DVWuNH, 0, m, &cIf_R8DVWuNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3kwYN9gQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9PUhCPnT, HV_BINOP_POW, 1, m, &cBinop_9PUhCPnT_sendMessage);
  cMsg_VzwE0lqK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_R8DVWuNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Eyrh3DGk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_cKFlR5kF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eKsAfqt9, 1, m, &cIf_eKsAfqt9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LAsXix17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CtY4UyVC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t2mASqFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xq2zSFZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZNbWLACP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3KcDqf3Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PGRRHOOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R8DVWuNH, 1, m, &cIf_R8DVWuNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sZqJBgIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nCUbRiGv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nCUbRiGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Eyrh3DGk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ywUO2wdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_xq2zSFZb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t2mASqFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PGRRHOOI, HV_BINOP_GREATER_THAN, 1, m, &cBinop_PGRRHOOI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CtY4UyVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sZqJBgIG, HV_BINOP_EQ, 1, m, &cBinop_sZqJBgIG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vs15caxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_t29uluZS, 0, m, &cVar_t29uluZS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dtl0hveU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PGRRHOOI, HV_BINOP_GREATER_THAN, 0, m, &cBinop_PGRRHOOI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FWqSHQha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sZqJBgIG, HV_BINOP_EQ, 0, m, &cBinop_sZqJBgIG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FJeMkpAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ywUO2wdF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Ace5LrL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vbzgBORc_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_OBX9Z9wW, 0, m, &cIf_OBX9Z9wW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_OBX9Z9wW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_iNqYIrb6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HivwkyY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_RYazrgXg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_1vl08P52_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_CSJlV4tV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_X4bJjyal, HV_BINOP_POW, 0, m, &cBinop_X4bJjyal_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X4bJjyal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HM00EZvo, 0, m, &cIf_HM00EZvo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BZUrDvnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_XXB1Lrov_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tmnkljTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CtV24IWY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uuPRpKAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HivwkyY5, 0, m, &cIf_HivwkyY5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CtV24IWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HivwkyY5, 1, m, &cIf_HivwkyY5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1vl08P52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_BZUrDvnF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RYazrgXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HM00EZvo, 0, m, &cIf_HM00EZvo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XXB1Lrov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X4bJjyal, HV_BINOP_POW, 1, m, &cBinop_X4bJjyal_sendMessage);
  cMsg_CSJlV4tV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_HM00EZvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QRkMyR9f_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0lIryn0x_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_vbzgBORc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OBX9Z9wW, 1, m, &cIf_OBX9Z9wW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iNqYIrb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VlI89GYz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TIBLcrfB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fPSanNWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tmnkljTB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uuPRpKAc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cneblnwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HM00EZvo, 1, m, &cIf_HM00EZvo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LpR8QsGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KT9XeJdu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KT9XeJdu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QRkMyR9f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0lIryn0x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZkHTgbOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_fPSanNWl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VlI89GYz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LpR8QsGp, HV_BINOP_EQ, 1, m, &cBinop_LpR8QsGp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TIBLcrfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cneblnwP, HV_BINOP_GREATER_THAN, 1, m, &cBinop_cneblnwP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pp1AepTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LpR8QsGp, HV_BINOP_EQ, 0, m, &cBinop_LpR8QsGp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TXZ8CUzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZkHTgbOl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_gDnDeFRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ace5LrL2, 0, m, &cVar_Ace5LrL2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4heungkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cneblnwP, HV_BINOP_GREATER_THAN, 0, m, &cBinop_cneblnwP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_c2o5UWE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_VZ9T4w34_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_FBTH6QFM, 0, m, &cIf_FBTH6QFM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_FBTH6QFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GrRrbVEa_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5MV217Zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_28103FAb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_dLW31AYT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_iL2h5dl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_pL5LYgmx, HV_BINOP_POW, 0, m, &cBinop_pL5LYgmx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pL5LYgmx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nlpSWcDw, 0, m, &cIf_nlpSWcDw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r5i59oSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_L6VS4AW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ij55tMqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5MV217Zr, 0, m, &cIf_5MV217Zr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dv5dWd3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2mZSzVvZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2mZSzVvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5MV217Zr, 1, m, &cIf_5MV217Zr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dLW31AYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_r5i59oSs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_28103FAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_nlpSWcDw, 0, m, &cIf_nlpSWcDw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L6VS4AW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pL5LYgmx, HV_BINOP_POW, 1, m, &cBinop_pL5LYgmx_sendMessage);
  cMsg_iL2h5dl7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_nlpSWcDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7PC2dbGd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_VZ9T4w34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FBTH6QFM, 1, m, &cIf_FBTH6QFM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GrRrbVEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d1weetQh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XPCLFajD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qW5mCX1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dv5dWd3E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ij55tMqJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QlJxoHaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nlpSWcDw, 1, m, &cIf_nlpSWcDw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mUsX75sj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_otgmIxyE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_otgmIxyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_7PC2dbGd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LGZqRSZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_qW5mCX1E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d1weetQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUsX75sj, HV_BINOP_EQ, 1, m, &cBinop_mUsX75sj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XPCLFajD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QlJxoHaW, HV_BINOP_GREATER_THAN, 1, m, &cBinop_QlJxoHaW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TiqkMeGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUsX75sj, HV_BINOP_EQ, 0, m, &cBinop_mUsX75sj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K0WChgxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LGZqRSZI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_x0j1aiVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c2o5UWE1, 0, m, &cVar_c2o5UWE1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ICBtzlYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QlJxoHaW, HV_BINOP_GREATER_THAN, 0, m, &cBinop_QlJxoHaW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_VIfgxuMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JVcOLqr1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_K17MS296_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XkIE07nN, 0, m, &cSlice_XkIE07nN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2GnApZf8_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XkIE07nN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_llL0y20c_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_llL0y20c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_k2f8fgNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_llL0y20c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_llL0y20c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cHODZiqS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2GnApZf8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_z6hb0ZHK, 0, m, &cSlice_z6hb0ZHK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3h39PxZ6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_z6hb0ZHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_P3pp5M6y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_P3pp5M6y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_d8BMzwng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_P3pp5M6y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_P3pp5M6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_G7AZZJAE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xbpzOzH8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_63sFjcsj, 0, m, &cSlice_63sFjcsj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HusAGw3w_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_63sFjcsj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_q5fOwOZm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_q5fOwOZm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_IxhQXAy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q5fOwOZm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_q5fOwOZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cNecRfs9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HusAGw3w_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_P3aMNg21, 0, m, &cSlice_P3aMNg21_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_P3aMNg21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5uitBsrS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5uitBsrS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_36Tm3B9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5uitBsrS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5uitBsrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8z6NW0pt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_B8E3Krl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B8VpTAXp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AZMWpKKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hCVSJGeT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ux1WCCf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PcZhNQpm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sIXMRbgD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YQLUaU4A, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XHhFExLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Pe5Mm6xx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cI2zMJTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_yeATKPG6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_yeATKPG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvYHXhMx, HV_BINOP_DIVIDE, 1, m, &cBinop_TvYHXhMx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XHpf3cSX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_mP8cDm5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_zfFzuqY3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Purm4RlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_mP8cDm5t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zfFzuqY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TvYHXhMx, HV_BINOP_DIVIDE, 0, m, &cBinop_TvYHXhMx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XHpf3cSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Purm4RlS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TvYHXhMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzGhLvB5, HV_BINOP_MULTIPLY, 1, m, &cBinop_HzGhLvB5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HzGhLvB5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8EwLHlSR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jGbZTaCe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_1ZPGqhsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yhEiS48S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_0bwqACbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ny4XcBVa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EIgvNpnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6ksshTW4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6ksshTW4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HzGhLvB5, HV_BINOP_MULTIPLY, 0, m, &cBinop_HzGhLvB5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xwPOtW1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_8D1vfKY3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8D1vfKY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fnGQljUu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_LVM61JQ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZWrbe5gl, 1, m, &cVar_ZWrbe5gl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ZWrbe5gl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JSPiw3IF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_DqMaiGNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xbGMFSHc, HV_BINOP_MULTIPLY, 1, m, &cBinop_xbGMFSHc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g5VmJGSE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DqMaiGNS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J0ZJJlto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1OkKLRdN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1OkKLRdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oFtsrV4Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_oFtsrV4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nVQtrmx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZXSreKFV, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZXSreKFV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I4SA0ZiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_nVQtrmx7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ABmVkMJT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cXZnQwYc, HV_BINOP_MULTIPLY, 1, m, &cBinop_cXZnQwYc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YC5qPI3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Q9SZClID_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Q9SZClID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DiojMUHZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_DiojMUHZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_82KHGqLn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n4tq0B6D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_EIgvNpnm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_evcITrSd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_xu92GCYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_xwPOtW1S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jGbZTaCe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_0bwqACbb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8EwLHlSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_1ZPGqhsh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_yhEiS48S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_37IrWNZg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ny4XcBVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AfsD5W05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_60ZVpknh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Gh8ACpZe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fnGQljUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WPCGzyyS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WPCGzyyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZLVI2HV, HV_BINOP_MULTIPLY, 1, m, &cBinop_UZLVI2HV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UZLVI2HV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_PzB8TXbt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PzB8TXbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_60ZVpknh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JSPiw3IF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_d8pn5Qef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d8pn5Qef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QRrfhxjV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HcBEqjMH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FYDaTfyB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6i5rV5o4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K9mcDUcL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tL6XYlFZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xbGMFSHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B8E3Krl9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_oFtsrV4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AZMWpKKQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ZXSreKFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ux1WCCf0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cXZnQwYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sIXMRbgD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_DiojMUHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XHhFExLb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_IZFElw6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_82KHGqLn, 0, m, &cVar_82KHGqLn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sbcAdxOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xu92GCYC, 1, m, &cVar_xu92GCYC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6i5rV5o4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZXSreKFV, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZXSreKFV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QRrfhxjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_tL6XYlFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xbGMFSHc, HV_BINOP_MULTIPLY, 0, m, &cBinop_xbGMFSHc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FYDaTfyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cXZnQwYc, HV_BINOP_MULTIPLY, 0, m, &cBinop_cXZnQwYc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K9mcDUcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oFtsrV4Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_oFtsrV4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HcBEqjMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DiojMUHZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_DiojMUHZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_evcITrSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZWrbe5gl, 0, m, &cVar_ZWrbe5gl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n4tq0B6D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xu92GCYC, 0, m, &cVar_xu92GCYC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lQCUJAa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xbtYZy74, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9bu5d1qu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aISBR6S0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MeMuXXjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qni8NWXm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6SotVHcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_moxq9Go6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gsWmG7zR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IkIvGDld_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_IkIvGDld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cKprLBcM, HV_BINOP_DIVIDE, 1, m, &cBinop_cKprLBcM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GGEqNvsU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_tpompkYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_geshJsce_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_daadj1xW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_tpompkYm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_geshJsce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cKprLBcM, HV_BINOP_DIVIDE, 0, m, &cBinop_cKprLBcM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GGEqNvsU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_daadj1xW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cKprLBcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ynx0zw4Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_ynx0zw4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ynx0zw4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VZ47iwgU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ficlFWCL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_9WOm0AH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XSi5sebc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_uGOUkwso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xZIQBdea_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_SwS0c2sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_bAu7xiKb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bAu7xiKb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ynx0zw4Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_ynx0zw4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5UgPJJVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_V3kkShoo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V3kkShoo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4tgpW7oQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_rO38frYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wIp6Uhh1, HV_BINOP_MULTIPLY, 1, m, &cBinop_wIp6Uhh1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JQ0qETqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dKLGGUSu, 1, m, &cVar_dKLGGUSu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LD0ab0zA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1eJDRddH, HV_BINOP_MULTIPLY, 1, m, &cBinop_1eJDRddH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Qhg3cswC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_suZTWa3U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_suZTWa3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxv69Dmv, HV_BINOP_MULTIPLY, 1, m, &cBinop_kxv69Dmv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_dKLGGUSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3UCcYOyB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_VfC27wtP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BBtoRvg3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_SwS0c2sq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AxLKhIlw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_nJqGhJuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_5UgPJJVg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VZ47iwgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_9WOm0AH3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ficlFWCL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_uGOUkwso_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_XSi5sebc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ygTsrcEc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xZIQBdea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Smp9PkP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lDgSIAL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l4B0dvUQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4tgpW7oQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_MR8qFhlm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MR8qFhlm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mMN62HOb, HV_BINOP_MULTIPLY, 1, m, &cBinop_mMN62HOb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mMN62HOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hbAV3GDe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hbAV3GDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lDgSIAL7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3UCcYOyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_AayNRhaL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AayNRhaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Xxz5V1x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5F9C9XXf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QlYtL8AW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qS9EXbYR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L3dmGNMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lQCUJAa1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wIp6Uhh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9bu5d1qu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_1eJDRddH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MeMuXXjJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kxv69Dmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6SotVHcD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Wsez62SQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nJqGhJuo, 1, m, &cVar_nJqGhJuo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BnUJG2QP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VfC27wtP, 0, m, &cVar_VfC27wtP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BBtoRvg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nJqGhJuo, 0, m, &cVar_nJqGhJuo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AxLKhIlw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dKLGGUSu, 0, m, &cVar_dKLGGUSu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QlYtL8AW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wIp6Uhh1, HV_BINOP_MULTIPLY, 0, m, &cBinop_wIp6Uhh1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5F9C9XXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1eJDRddH, HV_BINOP_MULTIPLY, 0, m, &cBinop_1eJDRddH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qS9EXbYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L3dmGNMa, HV_BINOP_MULTIPLY, 0, m, &cBinop_L3dmGNMa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5Xxz5V1x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kxv69Dmv, HV_BINOP_MULTIPLY, 0, m, &cBinop_kxv69Dmv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TIiBinis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h8iT86i4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_toSRUJe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a2TBZHJR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ns5DRY48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yxb3L2kN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8yAuzYWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KMsSoLr7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g75OGskt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hu9bTXdi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mY2Rgig8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sRXc9Ud4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_sRXc9Ud4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7QaVc3WG, HV_BINOP_DIVIDE, 1, m, &cBinop_7QaVc3WG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WdaGCDwB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_lq0fDYkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_4Dcp3vLB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i2F26Ndt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_lq0fDYkD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4Dcp3vLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7QaVc3WG, HV_BINOP_DIVIDE, 0, m, &cBinop_7QaVc3WG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WdaGCDwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i2F26Ndt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_7QaVc3WG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tu1bhuvV, HV_BINOP_MULTIPLY, 1, m, &cBinop_tu1bhuvV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tu1bhuvV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b87krJfj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p4ly2kGU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_0LkTtTMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rozUPhyl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_tWNn0BxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZwuFlFMw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_acx58M32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_utQZGWG3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_utQZGWG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tu1bhuvV, HV_BINOP_MULTIPLY, 0, m, &cBinop_tu1bhuvV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rW92Mvf2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_W2shRyPU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W2shRyPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_33zqnXyI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kNJmveMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sFhIFKZi, HV_BINOP_MULTIPLY, 1, m, &cBinop_sFhIFKZi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NyfjKb0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_z4eazq69_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_z4eazq69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kNJmveMU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JBBxGKTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LwLHkGU6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LwLHkGU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DDvFRlwN, HV_BINOP_MULTIPLY, 1, m, &cBinop_DDvFRlwN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Yx7gD0SZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EbfQeSZm, HV_BINOP_MULTIPLY, 1, m, &cBinop_EbfQeSZm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vJ0ZjvL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TrzkD7iE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TrzkD7iE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Yx7gD0SZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4yWsiAPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XFCVNwbC, 1, m, &cVar_XFCVNwbC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VE4Tc74n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QLv0iUEB, HV_BINOP_MULTIPLY, 1, m, &cBinop_QLv0iUEB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WijLr83X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_p0er0Ghc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_p0er0Ghc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W2YIm9sO, HV_BINOP_MULTIPLY, 1, m, &cBinop_W2YIm9sO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_XFCVNwbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TvnChVMi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_j9129ntY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8tCv1d4R_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_acx58M32_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OymMXU70_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_7KACCoys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_rW92Mvf2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_b87krJfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_0LkTtTMj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p4ly2kGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_tWNn0BxB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_rozUPhyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_48rDKiz1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ZwuFlFMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eeHq7nRF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_M2viO4m3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_f82Pm7LD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_33zqnXyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7uWbbHvZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7uWbbHvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fWW7dtve, HV_BINOP_MULTIPLY, 1, m, &cBinop_fWW7dtve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fWW7dtve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SC1jBfgA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SC1jBfgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M2viO4m3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TvnChVMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_1mxN1Csp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1mxN1Csp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_scGDj3r1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fX37cMyN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1xecWe8O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x8Mo1q1J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yAdJupnf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xN0YEaPp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sFhIFKZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TIiBinis_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_DDvFRlwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_toSRUJe1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EbfQeSZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ns5DRY48_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QLv0iUEB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8yAuzYWW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_W2YIm9sO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g75OGskt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_EuhQFP3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j9129ntY, 0, m, &cVar_j9129ntY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IWczJKqJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7KACCoys, 1, m, &cVar_7KACCoys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_scGDj3r1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_xN0YEaPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sFhIFKZi, HV_BINOP_MULTIPLY, 0, m, &cBinop_sFhIFKZi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1xecWe8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QLv0iUEB, HV_BINOP_MULTIPLY, 0, m, &cBinop_QLv0iUEB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yAdJupnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DDvFRlwN, HV_BINOP_MULTIPLY, 0, m, &cBinop_DDvFRlwN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fX37cMyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W2YIm9sO, HV_BINOP_MULTIPLY, 0, m, &cBinop_W2YIm9sO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x8Mo1q1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EbfQeSZm, HV_BINOP_MULTIPLY, 0, m, &cBinop_EbfQeSZm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OymMXU70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XFCVNwbC, 0, m, &cVar_XFCVNwbC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8tCv1d4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7KACCoys, 0, m, &cVar_7KACCoys_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QNrNWYEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VIfgxuMd, 1, m, &cIf_VIfgxuMd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0355MsM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_JVcOLqr1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8wy3x4LO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0355MsM7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Ha3izUB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VIfgxuMd, 0, m, &cIf_VIfgxuMd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Eyrh3DGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gN7AeNHa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JVcOLqr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G9XBcEEA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7PC2dbGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N7pSDOD1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QRkMyR9f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_QNrNWYEZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8wy3x4LO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0lIryn0x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Ha3izUB7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_50ZJvLxj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bO0o3rzp, 0, m, &cSlice_bO0o3rzp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_e9XOnuXU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bO0o3rzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_t6xoliZW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_t6xoliZW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_T9k6fkkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t6xoliZW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_t6xoliZW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SbQAbDdr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_7VUUI9HL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IgALjvtO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Hicy0jyc, 0, m, &cIf_Hicy0jyc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Hicy0jyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_kQTmlxYB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IzhtVedK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_b88yqaVL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_K2NzFSiy_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_NhtP72Mq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VECkKR9B, HV_BINOP_POW, 0, m, &cBinop_VECkKR9B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VECkKR9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TheBcSSP, 0, m, &cIf_TheBcSSP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Tw26AKup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ndpuIAOa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DLJdDIm0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_txFONxYn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f40Gg01e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IzhtVedK, 0, m, &cIf_IzhtVedK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_txFONxYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IzhtVedK, 1, m, &cIf_IzhtVedK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K2NzFSiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Tw26AKup_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b88yqaVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_TheBcSSP, 0, m, &cIf_TheBcSSP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ndpuIAOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VECkKR9B, HV_BINOP_POW, 1, m, &cBinop_VECkKR9B_sendMessage);
  cMsg_NhtP72Mq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_TheBcSSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tV9J8Svl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_IgALjvtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hicy0jyc, 1, m, &cIf_Hicy0jyc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kQTmlxYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T4ssdr9g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6zZVX11c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m7jvBvqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DLJdDIm0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f40Gg01e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Jt06vLtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TheBcSSP, 1, m, &cIf_TheBcSSP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_50OtJw0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WR7mQNBM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WR7mQNBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_tV9J8Svl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hcCrhxV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_m7jvBvqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6zZVX11c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jt06vLtz, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Jt06vLtz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T4ssdr9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_50OtJw0C, HV_BINOP_EQ, 1, m, &cBinop_50OtJw0C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dwbdb8CS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hcCrhxV4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_b6j9uty3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jt06vLtz, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Jt06vLtz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I1JtdqOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7VUUI9HL, 0, m, &cVar_7VUUI9HL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MyKx8ROj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_50OtJw0C, HV_BINOP_EQ, 0, m, &cBinop_50OtJw0C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_deZkYkCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mdZdOfW3_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_YKvlCInN, 0, m, &cIf_YKvlCInN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_YKvlCInN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1q87kbR7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3h9OFdva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_SxKW5u25_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Uh9h7osB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_EQWZkAES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_zrz48N69, HV_BINOP_POW, 0, m, &cBinop_zrz48N69_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zrz48N69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NKUtDQm7, 0, m, &cIf_NKUtDQm7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uUSAuSOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_qlmM7soX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ItfbeyoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4uFxbNC7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E7IQ2TiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3h9OFdva, 0, m, &cIf_3h9OFdva_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4uFxbNC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3h9OFdva, 1, m, &cIf_3h9OFdva_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Uh9h7osB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uUSAuSOS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SxKW5u25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_NKUtDQm7, 0, m, &cIf_NKUtDQm7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qlmM7soX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zrz48N69, HV_BINOP_POW, 1, m, &cBinop_zrz48N69_sendMessage);
  cMsg_EQWZkAES_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_NKUtDQm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W93qSJWi_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KzVMVTNq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_mdZdOfW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YKvlCInN, 1, m, &cIf_YKvlCInN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1q87kbR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fKUrHBDG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xgSWcj73_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Gp9sZ32p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ItfbeyoZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E7IQ2TiC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7spMa9va_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NKUtDQm7, 1, m, &cIf_NKUtDQm7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_chngFoWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Br6PCkTf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Br6PCkTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W93qSJWi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KzVMVTNq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PAad4GNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Gp9sZ32p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xgSWcj73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7spMa9va, HV_BINOP_GREATER_THAN, 1, m, &cBinop_7spMa9va_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fKUrHBDG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_chngFoWS, HV_BINOP_EQ, 1, m, &cBinop_chngFoWS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KunLfVH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_deZkYkCa, 0, m, &cVar_deZkYkCa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IJm2piir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7spMa9va, HV_BINOP_GREATER_THAN, 0, m, &cBinop_7spMa9va_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t6Uy8GEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_chngFoWS, HV_BINOP_EQ, 0, m, &cBinop_chngFoWS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dQEl1piB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PAad4GNG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Yd5Pb2s4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_peoUnvyZ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_y3dQSP2I, 0, m, &cIf_y3dQSP2I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_y3dQSP2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vsIR662U_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_R6AAY2nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_eedhLCd1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_qJT9Rsed_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_Aio9D6pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eZsNI47V, HV_BINOP_POW, 0, m, &cBinop_eZsNI47V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eZsNI47V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sXMQvAGj, 0, m, &cIf_sXMQvAGj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qrdlYYvc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_tJGjf1RD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_meoAghRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R6AAY2nu, 0, m, &cIf_R6AAY2nu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aZgNRgaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_A4QRP6lw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A4QRP6lw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R6AAY2nu, 1, m, &cIf_R6AAY2nu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qJT9Rsed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_qrdlYYvc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eedhLCd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_sXMQvAGj, 0, m, &cIf_sXMQvAGj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tJGjf1RD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eZsNI47V, HV_BINOP_POW, 1, m, &cBinop_eZsNI47V_sendMessage);
  cMsg_Aio9D6pm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_sXMQvAGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5lmrTgdg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_peoUnvyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y3dQSP2I, 1, m, &cIf_y3dQSP2I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vsIR662U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6HcdmuVx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TUK2ri6N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kPch4Phk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aZgNRgaq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_meoAghRI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HckfDtwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sXMQvAGj, 1, m, &cIf_sXMQvAGj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jVHHz7Tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xPph262z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xPph262z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_5lmrTgdg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gAvdPW2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_kPch4Phk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TUK2ri6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HckfDtwM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_HckfDtwM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6HcdmuVx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jVHHz7Tf, HV_BINOP_EQ, 1, m, &cBinop_jVHHz7Tf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_neJL5AAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jVHHz7Tf, HV_BINOP_EQ, 0, m, &cBinop_jVHHz7Tf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7yxbiHoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gAvdPW2Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_goOFvyD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Yd5Pb2s4, 0, m, &cVar_Yd5Pb2s4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kEPklVyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HckfDtwM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_HckfDtwM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_0wsxz3b7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7JA7WDpg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fyipu96C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ScKcG1dg, 0, m, &cSlice_ScKcG1dg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_RYAqS0tg_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ScKcG1dg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6MAyCGHW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6MAyCGHW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_5j6OuAA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6MAyCGHW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_6MAyCGHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4noZkWWw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RYAqS0tg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Tsa54Bg9, 0, m, &cSlice_Tsa54Bg9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_50ZJvLxj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Tsa54Bg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hubRvM6T_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hubRvM6T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_XJGG8aYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hubRvM6T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hubRvM6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GPsSGD2v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e9XOnuXU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YiDHaHia, 0, m, &cSlice_YiDHaHia_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GkuhkWxQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_YiDHaHia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8NFDsS1q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8NFDsS1q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Wgmp88QU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8NFDsS1q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8NFDsS1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YBATEbzO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GkuhkWxQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ObxvV62q, 0, m, &cSlice_ObxvV62q_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ObxvV62q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fpshcp4p_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fpshcp4p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lwS99WFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fpshcp4p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fpshcp4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kuixHftH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jrJZpyPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J3sH5Juy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cLyrs2s3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kjdN2qEs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_n7w4suj5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y8wbx5fi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eCwRnsPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BjiQgERK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mXniIFj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nlbunnz9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jI8u7rUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_RyHFJr3s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_RyHFJr3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kGWB5J27, HV_BINOP_DIVIDE, 1, m, &cBinop_kGWB5J27_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9W7mYld2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_urabAa7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_kyIIoMjB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SVehOMY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_urabAa7c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kyIIoMjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kGWB5J27, HV_BINOP_DIVIDE, 0, m, &cBinop_kGWB5J27_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9W7mYld2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SVehOMY8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kGWB5J27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oOMsqrJA, HV_BINOP_MULTIPLY, 1, m, &cBinop_oOMsqrJA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oOMsqrJA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d2Xdl6Hr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ytsy8O7S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_FFEpR4Y0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mTgprkyY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_TH4YxviB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UVfOyJ7A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_fwFmuIvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_1lYfvsqf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1lYfvsqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oOMsqrJA, HV_BINOP_MULTIPLY, 0, m, &cBinop_oOMsqrJA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YDLa31tw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_BApYwIpl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BApYwIpl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NzM6ZEbi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_eroYetly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MMOppUjg, 1, m, &cVar_MMOppUjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_MMOppUjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BEiihrxt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_5IKwn8bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7vujqOTW, HV_BINOP_MULTIPLY, 1, m, &cBinop_7vujqOTW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_34AdfzCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5IKwn8bf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aNmCUIuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_icRZcg6J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_icRZcg6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XgSZUgel, HV_BINOP_MULTIPLY, 1, m, &cBinop_XgSZUgel_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0383HpoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Jz8aq8v, HV_BINOP_MULTIPLY, 1, m, &cBinop_9Jz8aq8v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AUYKsTjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0383HpoK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bjymOs78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4nVVKWUm, HV_BINOP_MULTIPLY, 1, m, &cBinop_4nVVKWUm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RtLhLc2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_shvfEm81_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_shvfEm81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cLg9fbPO, HV_BINOP_MULTIPLY, 1, m, &cBinop_cLg9fbPO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_HIYQ7wwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8bzAq7Nj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_fwFmuIvo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iJZYBiKt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_tLA7p3Do_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_YDLa31tw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d2Xdl6Hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_FFEpR4Y0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ytsy8O7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_TH4YxviB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_mTgprkyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XHaenwID_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UVfOyJ7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_y1matWRC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Ztvgir8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nW0QQuVs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NzM6ZEbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Fc7OsuNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fc7OsuNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_01q0NN8p, HV_BINOP_MULTIPLY, 1, m, &cBinop_01q0NN8p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_01q0NN8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mjVxzUsv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mjVxzUsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Ztvgir8T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BEiihrxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_urylUEUm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_urylUEUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vBk0rJh5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OiRICNeO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k2fq93cu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bYp5FZg2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YfSqFq2L_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LE9QId57_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7vujqOTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jrJZpyPW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_XgSZUgel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cLyrs2s3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_9Jz8aq8v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n7w4suj5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4nVVKWUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eCwRnsPr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cLg9fbPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mXniIFj2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_0J3rqq8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HIYQ7wwk, 0, m, &cVar_HIYQ7wwk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lgUYImLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tLA7p3Do, 1, m, &cVar_tLA7p3Do_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vBk0rJh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_LE9QId57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7vujqOTW, HV_BINOP_MULTIPLY, 0, m, &cBinop_7vujqOTW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k2fq93cu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4nVVKWUm, HV_BINOP_MULTIPLY, 0, m, &cBinop_4nVVKWUm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YfSqFq2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XgSZUgel, HV_BINOP_MULTIPLY, 0, m, &cBinop_XgSZUgel_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OiRICNeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cLg9fbPO, HV_BINOP_MULTIPLY, 0, m, &cBinop_cLg9fbPO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bYp5FZg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9Jz8aq8v, HV_BINOP_MULTIPLY, 0, m, &cBinop_9Jz8aq8v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iJZYBiKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MMOppUjg, 0, m, &cVar_MMOppUjg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8bzAq7Nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tLA7p3Do, 0, m, &cVar_tLA7p3Do_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rHROUYkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uAIsNeSY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RRmY8fpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bQqdC1Jc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SQCTWseo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VwhbUyhD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ozc2dM5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DXBNUfbS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3Syyj08p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_zgiXkT0z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_zgiXkT0z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJAKpIIa, HV_BINOP_DIVIDE, 1, m, &cBinop_QJAKpIIa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KYiG0KyQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_JevNylpK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_usqYrtKU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QV7jVepL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_JevNylpK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_usqYrtKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QJAKpIIa, HV_BINOP_DIVIDE, 0, m, &cBinop_QJAKpIIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KYiG0KyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QV7jVepL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QJAKpIIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ok2beXl, HV_BINOP_MULTIPLY, 1, m, &cBinop_8ok2beXl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8ok2beXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G3YzMu5T_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_D12h9tUb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_a2m4rw1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1fWmOUPk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_prDbOyWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OkPvwLIB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_V6KgMVzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_gyfiETCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gyfiETCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8ok2beXl, HV_BINOP_MULTIPLY, 0, m, &cBinop_8ok2beXl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fe720kmr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_M5h3LdsP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M5h3LdsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FxkhQtsw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wl58f7yt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_olX7IzHV, HV_BINOP_MULTIPLY, 1, m, &cBinop_olX7IzHV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_auXW9vGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fbIyYmAi, 1, m, &cVar_fbIyYmAi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VGr0hcjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i2vd4vSc, HV_BINOP_MULTIPLY, 1, m, &cBinop_i2vd4vSc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GVacmN4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_BSGiFe24_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BSGiFe24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N9TIT2CU, HV_BINOP_MULTIPLY, 1, m, &cBinop_N9TIT2CU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_fbIyYmAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_y49xk0um_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pPN91ibx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jmUcy7kI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_V6KgMVzc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_krSRsWZU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_g8HYDXRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_fe720kmr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G3YzMu5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_a2m4rw1F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_D12h9tUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_prDbOyWr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_1fWmOUPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Cg7CnHei_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OkPvwLIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eWMaMjCA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BPpHfZcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZRbk3UBI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FxkhQtsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5cMMsDwD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5cMMsDwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lwKEZWaT, HV_BINOP_MULTIPLY, 1, m, &cBinop_lwKEZWaT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lwKEZWaT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EMVKg70O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EMVKg70O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BPpHfZcf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_y49xk0um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TKnnnLzO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TKnnnLzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6EiNXSb6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V4eCgJdl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XkKi42yW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ujYrfz84_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zLwVTZYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rHROUYkl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_olX7IzHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RRmY8fpu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_i2vd4vSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SQCTWseo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_N9TIT2CU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ozc2dM5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cPwS4CfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g8HYDXRC, 1, m, &cVar_g8HYDXRC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RUFP2r3G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pPN91ibx, 0, m, &cVar_pPN91ibx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_krSRsWZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fbIyYmAi, 0, m, &cVar_fbIyYmAi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jmUcy7kI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_g8HYDXRC, 0, m, &cVar_g8HYDXRC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XkKi42yW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_olX7IzHV, HV_BINOP_MULTIPLY, 0, m, &cBinop_olX7IzHV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V4eCgJdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i2vd4vSc, HV_BINOP_MULTIPLY, 0, m, &cBinop_i2vd4vSc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ujYrfz84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zLwVTZYS, HV_BINOP_MULTIPLY, 0, m, &cBinop_zLwVTZYS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6EiNXSb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N9TIT2CU, HV_BINOP_MULTIPLY, 0, m, &cBinop_N9TIT2CU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_izaX3QBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NlsXBH3D, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0xHcLzUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IyM0qxL5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tS7Nd3vC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wehOwrvB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4XgYAzC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eG4f4WJG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3UzxU5o6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wC0W9NnK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SawlCcQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7T1ZA9Up_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_7T1ZA9Up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_roGMCtjm, HV_BINOP_DIVIDE, 1, m, &cBinop_roGMCtjm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WuOaxPNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_DPM5MKAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_31i6uN8Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_scITeAQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_DPM5MKAz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_31i6uN8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_roGMCtjm, HV_BINOP_DIVIDE, 0, m, &cBinop_roGMCtjm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WuOaxPNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_scITeAQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_roGMCtjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aq3bpQm4, HV_BINOP_MULTIPLY, 1, m, &cBinop_aq3bpQm4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aq3bpQm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dhdTt6qc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hGxzx3PN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_4SZjKyPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_856IILNG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_5wEkFTP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NG3zixsY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4DIPJAyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_r8wu6XDO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r8wu6XDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aq3bpQm4, HV_BINOP_MULTIPLY, 0, m, &cBinop_aq3bpQm4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hn4LzO3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_1GJQVjQp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1GJQVjQp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5h23HPEI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tAD7cLPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QLP854iS, HV_BINOP_MULTIPLY, 1, m, &cBinop_QLP854iS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o54j6TRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QvyVaNzw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QvyVaNzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tAD7cLPx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tkHDn6UB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_38p8ab0o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_38p8ab0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dfiEmn2C, HV_BINOP_MULTIPLY, 1, m, &cBinop_dfiEmn2C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KN5TiTxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MyOsED1R, HV_BINOP_MULTIPLY, 1, m, &cBinop_MyOsED1R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GVzndg7u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zkRhnbpE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zkRhnbpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_KN5TiTxD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ko8CU3zD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EmtqbRIP, 1, m, &cVar_EmtqbRIP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w1s0iN2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zZ60LPKh, HV_BINOP_MULTIPLY, 1, m, &cBinop_zZ60LPKh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cISjBaAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_64eeJ1Jt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_64eeJ1Jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KL9bEZpX, HV_BINOP_MULTIPLY, 1, m, &cBinop_KL9bEZpX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_EmtqbRIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FpvEOLIA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_U1mdHZ0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y7cYyayL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_4DIPJAyk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gkkn8M7r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_tsYvaJye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_hn4LzO3H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hGxzx3PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_5wEkFTP0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dhdTt6qc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_4SZjKyPW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_856IILNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Oxk22QTk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NG3zixsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_czjXeeV7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mIscb9fG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gXtewtfd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5h23HPEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7E9FBxTg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7E9FBxTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Qyr6E5K, HV_BINOP_MULTIPLY, 1, m, &cBinop_0Qyr6E5K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0Qyr6E5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_NUHB7sFj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NUHB7sFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mIscb9fG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FpvEOLIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2WDGXb19_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2WDGXb19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0I3k6mMN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dBQmLfK6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vomO0Yb5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gV52fCHw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lWuR8Rnr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HPl0RtOT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QLP854iS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_izaX3QBg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dfiEmn2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0xHcLzUx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MyOsED1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tS7Nd3vC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_zZ60LPKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4XgYAzC3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_KL9bEZpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3UzxU5o6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WQ4oeUhZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tsYvaJye, 1, m, &cVar_tsYvaJye_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LUhIev2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U1mdHZ0V, 0, m, &cVar_U1mdHZ0V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gV52fCHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MyOsED1R, HV_BINOP_MULTIPLY, 0, m, &cBinop_MyOsED1R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0I3k6mMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_HPl0RtOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QLP854iS, HV_BINOP_MULTIPLY, 0, m, &cBinop_QLP854iS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vomO0Yb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zZ60LPKh, HV_BINOP_MULTIPLY, 0, m, &cBinop_zZ60LPKh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lWuR8Rnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dfiEmn2C, HV_BINOP_MULTIPLY, 0, m, &cBinop_dfiEmn2C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dBQmLfK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KL9bEZpX, HV_BINOP_MULTIPLY, 0, m, &cBinop_KL9bEZpX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y7cYyayL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tsYvaJye, 0, m, &cVar_tsYvaJye_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gkkn8M7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EmtqbRIP, 0, m, &cVar_EmtqbRIP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2x1dAfcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0wsxz3b7, 1, m, &cIf_0wsxz3b7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_krD2AOIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_7JA7WDpg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lAyE4zJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_krD2AOIH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_cHRkidKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0wsxz3b7, 0, m, &cIf_0wsxz3b7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tV9J8Svl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DQ0jUcYo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7JA7WDpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BaJpR5jD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5lmrTgdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZMpfhBwT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_W93qSJWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2x1dAfcp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lAyE4zJZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KzVMVTNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_cHRkidKX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_kFndYKhi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gn8Lomwr, HV_BINOP_DIVIDE, 0, m, &cBinop_Gn8Lomwr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_lmyRChT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RdCAb3i1, HV_BINOP_DIVIDE, 1, m, &cBinop_RdCAb3i1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Gn8Lomwr, HV_BINOP_DIVIDE, 1, m, &cBinop_Gn8Lomwr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_up4swFT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uj0a4Uwa, HV_BINOP_DIVIDE, 0, m, &cBinop_uj0a4Uwa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_V1Eg0UoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uj0a4Uwa, HV_BINOP_DIVIDE, 1, m, &cBinop_uj0a4Uwa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dAjtZr2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kFndYKhi, 0, m, &cVar_kFndYKhi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_59L03IdR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lmyRChT3, 0, m, &cVar_lmyRChT3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8YLJYVfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RdCAb3i1, HV_BINOP_DIVIDE, 0, m, &cBinop_RdCAb3i1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RdCAb3i1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_up4swFT6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Gn8Lomwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_V1Eg0UoK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uj0a4Uwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_99br8kHh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_G3BcjkFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_hWhfPiia_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cfrGjDvL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_MisIf7Pf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_99br8kHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_cfrGjDvL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MisIf7Pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_G3BcjkFq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hWhfPiia_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2KOaBRms_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EbcIXOsP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sH0QT4dx, 0, m, &cSlice_sH0QT4dx_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sH0QT4dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_c2F6Njkq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_c2F6Njkq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_bkg3uMst_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_c2F6Njkq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_c2F6Njkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eRe6FGl1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_LWVUjZ1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OWgAaA2s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OWgAaA2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_5n7n2eVN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5n7n2eVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3Au4Cdp5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3Au4Cdp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JMTbULxf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ksD0JMbY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ksD0JMbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PO5KQo60_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JMTbULxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_bAPcTdod_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bAPcTdod_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_sskuYPAf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PO5KQo60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rkhQQF8C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rkhQQF8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eWDQ3sen_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sskuYPAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hEMiYPxW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_eWDQ3sen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T0KjOSIe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hEMiYPxW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_as1au9Jp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_T0KjOSIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XLfSsUWi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_egflv3T5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E5ecGqcw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_4UC0LJoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CwO76XAt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cdKgCLXX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C8QSDCcA_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_71z7LHGT_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8ZnwAowR_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BE7GHDeg_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VrmVYNFF_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D3Pm1nLU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_C8QSDCcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KTKomL8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_71z7LHGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yeYM6s4y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8ZnwAowR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sabnLEDV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BE7GHDeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lgCG6eOQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VrmVYNFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wkhnyixy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_D3Pm1nLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_neJ2uFV6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_t71lXQS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_B90r28Wn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_iU1QOWAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_in8g5w0I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aidDLB0X_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DsGu5Muj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DsGu5Muj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vilMkgv9, 1, m, &cDelay_vilMkgv9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XbHoLYPM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vilMkgv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vilMkgv9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_t71lXQS1, 0, m, &cIf_t71lXQS1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DsGu5Muj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vilMkgv9, 0, m, &cDelay_vilMkgv9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XbHoLYPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vilMkgv9, 0, m, &cDelay_vilMkgv9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xIAsjLLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YQWijahn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OvsuZe8S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w8hk4z2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UUHoitIN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZscHpv8Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UUHoitIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t71lXQS1, 1, m, &cIf_t71lXQS1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZscHpv8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aidDLB0X_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YQWijahn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iU1QOWAm, 1, m, &cIf_iU1QOWAm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OvsuZe8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iU1QOWAm, 0, m, &cIf_iU1QOWAm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_in8g5w0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fnL2nUtH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_B90r28Wn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fnL2nUtH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_evUshZiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xI9MaSkw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ca0IS25G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xsuCJMgo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oC37XCgU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6Ym59sRK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6Ym59sRK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_b6po0c11, 1, m, &cDelay_b6po0c11_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GT1jc0Gp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_b6po0c11_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b6po0c11, m);
  cIf_onMessage(_c, &Context(_c)->cIf_evUshZiX, 0, m, &cIf_evUshZiX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6Ym59sRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_b6po0c11, 0, m, &cDelay_b6po0c11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GT1jc0Gp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b6po0c11, 0, m, &cDelay_b6po0c11_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sxLyWyIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sIHhwmX1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7PFMmAgi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZBtvh4wT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QTH1gQKB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_odEILMud_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QTH1gQKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_evUshZiX, 1, m, &cIf_evUshZiX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_odEILMud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oC37XCgU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_sIHhwmX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ca0IS25G, 1, m, &cIf_ca0IS25G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7PFMmAgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ca0IS25G, 0, m, &cIf_ca0IS25G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xsuCJMgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FjVRQLnx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xI9MaSkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FjVRQLnx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_78TQw9IX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yha5ktr3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1ND61wM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WZZx1JjV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qXZtupst_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_p9NoGOMc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_p9NoGOMc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Tsrji8MY, 1, m, &cDelay_Tsrji8MY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y8CBN4BB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Tsrji8MY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Tsrji8MY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_78TQw9IX, 0, m, &cIf_78TQw9IX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p9NoGOMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tsrji8MY, 0, m, &cDelay_Tsrji8MY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y8CBN4BB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Tsrji8MY, 0, m, &cDelay_Tsrji8MY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ikNBhqcY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OR4tURrz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nYmkJTAZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k2DSTq6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qTRQM4bL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Etcdh0b0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qTRQM4bL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_78TQw9IX, 1, m, &cIf_78TQw9IX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Etcdh0b0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qXZtupst_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nYmkJTAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1ND61wM6, 0, m, &cIf_1ND61wM6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OR4tURrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1ND61wM6, 1, m, &cIf_1ND61wM6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WZZx1JjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0mK7wafh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yha5ktr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0mK7wafh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2upPUHYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ql6xkPC7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ho1JxjTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SANmwZPl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HwnXonN2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YQ9hYH3O_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YQ9hYH3O_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WN8sFm0P, 1, m, &cDelay_WN8sFm0P_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_J2QFDhmI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WN8sFm0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WN8sFm0P, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2upPUHYa, 0, m, &cIf_2upPUHYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YQ9hYH3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WN8sFm0P, 0, m, &cDelay_WN8sFm0P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_J2QFDhmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WN8sFm0P, 0, m, &cDelay_WN8sFm0P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tEP6sNPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CwazXWAI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F9vpFnuO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Oa8By7GG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ea9jaRhp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sB7M0qc4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sB7M0qc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HwnXonN2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Ea9jaRhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2upPUHYa, 1, m, &cIf_2upPUHYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F9vpFnuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ho1JxjTD, 0, m, &cIf_ho1JxjTD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CwazXWAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ho1JxjTD, 1, m, &cIf_ho1JxjTD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SANmwZPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H3iVh2tI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ql6xkPC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H3iVh2tI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_O4T7fQEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GM57sh0L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RWTiGZxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YDri8piF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eBQ7UlOK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cmPp01u5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cmPp01u5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RWxjcSYu, 1, m, &cDelay_RWxjcSYu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iNdSvrLU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RWxjcSYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RWxjcSYu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_O4T7fQEY, 0, m, &cIf_O4T7fQEY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cmPp01u5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RWxjcSYu, 0, m, &cDelay_RWxjcSYu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iNdSvrLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RWxjcSYu, 0, m, &cDelay_RWxjcSYu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rX7xIyXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wFMkXOyh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nvydPkaU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KZlJQbau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mDXZrcZx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_odPUR5sz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_odPUR5sz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eBQ7UlOK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mDXZrcZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O4T7fQEY, 1, m, &cIf_O4T7fQEY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nvydPkaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RWTiGZxu, 0, m, &cIf_RWTiGZxu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wFMkXOyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RWTiGZxu, 1, m, &cIf_RWTiGZxu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YDri8piF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RPFrYt74, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GM57sh0L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RPFrYt74, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GDCvvFyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TPuzZ3vD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QGWKqVs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VWwkmPMC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uDSP1aBd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YgG5lKjJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YgG5lKjJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yxOTr7ee, 1, m, &cDelay_yxOTr7ee_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fduRwetx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yxOTr7ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yxOTr7ee, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GDCvvFyn, 0, m, &cIf_GDCvvFyn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YgG5lKjJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yxOTr7ee, 0, m, &cDelay_yxOTr7ee_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fduRwetx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yxOTr7ee, 0, m, &cDelay_yxOTr7ee_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3bsQW4U6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Huunzgj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WiJ0qt6T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M7AaxPcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_axLgCZls_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NBH2nCu4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_axLgCZls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GDCvvFyn, 1, m, &cIf_GDCvvFyn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NBH2nCu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uDSP1aBd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WiJ0qt6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QGWKqVs8, 0, m, &cIf_QGWKqVs8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9Huunzgj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QGWKqVs8, 1, m, &cIf_QGWKqVs8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VWwkmPMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eoWW9Pce, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TPuzZ3vD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eoWW9Pce, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bkTQ1BJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MTlZCr9v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DjKLBCE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LRCF7vh0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Pltdqdg8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GX9sPhuG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GX9sPhuG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UGPjp5rN, 1, m, &cDelay_UGPjp5rN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IA5i6HaV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UGPjp5rN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UGPjp5rN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bkTQ1BJd, 0, m, &cIf_bkTQ1BJd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GX9sPhuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UGPjp5rN, 0, m, &cDelay_UGPjp5rN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IA5i6HaV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UGPjp5rN, 0, m, &cDelay_UGPjp5rN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sKDkQkox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cZh8fNEc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4epcybDE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3lw7YNhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RelpYyUX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JRz1B1OU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RelpYyUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bkTQ1BJd, 1, m, &cIf_bkTQ1BJd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JRz1B1OU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Pltdqdg8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cZh8fNEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DjKLBCE4, 1, m, &cIf_DjKLBCE4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4epcybDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DjKLBCE4, 0, m, &cIf_DjKLBCE4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LRCF7vh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_deU2Pzd3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MTlZCr9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_deU2Pzd3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GjH9CWut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7qMhSm5c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HtXilm79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_h3OyRWay_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tjeimrVr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6aUyKX6Q_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6aUyKX6Q_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_K0JWMt79, 1, m, &cDelay_K0JWMt79_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GZNNLfj9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_K0JWMt79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_K0JWMt79, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GjH9CWut, 0, m, &cIf_GjH9CWut_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6aUyKX6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_K0JWMt79, 0, m, &cDelay_K0JWMt79_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GZNNLfj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_K0JWMt79, 0, m, &cDelay_K0JWMt79_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SPnbMEx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1HBsTv1c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DBC9xysL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pkCudnNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7s9cAsJS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OzDdrGoG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7s9cAsJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GjH9CWut, 1, m, &cIf_GjH9CWut_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OzDdrGoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tjeimrVr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1HBsTv1c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HtXilm79, 1, m, &cIf_HtXilm79_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DBC9xysL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HtXilm79, 0, m, &cIf_HtXilm79_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h3OyRWay_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uQEdBznj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7qMhSm5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uQEdBznj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_LOA7wfky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cSF5iWXq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kk6ZekkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vw1EFe7g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_U6IuR7LE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XrD48qyz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XrD48qyz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7zyBaYiH, 1, m, &cDelay_7zyBaYiH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WLW9BKSA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7zyBaYiH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7zyBaYiH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LOA7wfky, 0, m, &cIf_LOA7wfky_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XrD48qyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7zyBaYiH, 0, m, &cDelay_7zyBaYiH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WLW9BKSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7zyBaYiH, 0, m, &cDelay_7zyBaYiH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5jMTY2u9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vsLsHiQ5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U2YOnMcr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5DwwaOaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mjuxXbro_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kGtX7Zaz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kGtX7Zaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_U6IuR7LE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mjuxXbro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LOA7wfky, 1, m, &cIf_LOA7wfky_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vsLsHiQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kk6ZekkG, 1, m, &cIf_kk6ZekkG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U2YOnMcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kk6ZekkG, 0, m, &cIf_kk6ZekkG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vw1EFe7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jYFd0k10, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cSF5iWXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jYFd0k10, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5yTpbZea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_e2xpXwiB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Gv31AX3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UjzdugI0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MZTQGmZn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Z0TD1AtX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Z0TD1AtX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_419sMKDP, 1, m, &cDelay_419sMKDP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o3lDVG0Z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_419sMKDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_419sMKDP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5yTpbZea, 0, m, &cIf_5yTpbZea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z0TD1AtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_419sMKDP, 0, m, &cDelay_419sMKDP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o3lDVG0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_419sMKDP, 0, m, &cDelay_419sMKDP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LxIw6Dap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R8FoGKQI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bgF3xm25_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AXh97fnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CTmFNA5u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_riMOA6FU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_riMOA6FU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_MZTQGmZn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CTmFNA5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5yTpbZea, 1, m, &cIf_5yTpbZea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bgF3xm25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gv31AX3n, 0, m, &cIf_Gv31AX3n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R8FoGKQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gv31AX3n, 1, m, &cIf_Gv31AX3n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UjzdugI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LlPnVQ15, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_e2xpXwiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LlPnVQ15, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0rLrxaH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qAS1VaOR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_n3WgGuss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HyZrZc3T_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZHvRcytn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_b4TvEP50_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_b4TvEP50_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_y3Qbfqa2, 1, m, &cDelay_y3Qbfqa2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p7EByYpA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_y3Qbfqa2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_y3Qbfqa2, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0rLrxaH1, 0, m, &cIf_0rLrxaH1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b4TvEP50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_y3Qbfqa2, 0, m, &cDelay_y3Qbfqa2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p7EByYpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_y3Qbfqa2, 0, m, &cDelay_y3Qbfqa2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vFm82kXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oNzHkO3Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FhOSVzJd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mU6xfAwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QMEpb8tN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kbZ1Dd5q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QMEpb8tN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0rLrxaH1, 1, m, &cIf_0rLrxaH1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kbZ1Dd5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZHvRcytn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oNzHkO3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n3WgGuss, 1, m, &cIf_n3WgGuss_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FhOSVzJd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n3WgGuss, 0, m, &cIf_n3WgGuss_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HyZrZc3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5EgXFMls, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qAS1VaOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5EgXFMls, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GruTZCgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O43pbK1G_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kZOVNxrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZkuhXpTZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_D7LDL8Tv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HJDUwuGl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HJDUwuGl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rc77y8oz, 1, m, &cDelay_rc77y8oz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O48Wgnzj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rc77y8oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rc77y8oz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GruTZCgW, 0, m, &cIf_GruTZCgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HJDUwuGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rc77y8oz, 0, m, &cDelay_rc77y8oz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O48Wgnzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rc77y8oz, 0, m, &cDelay_rc77y8oz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IOyLtd1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FGIQrBeT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0yDxzyUo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_auhHcPpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2EiEY3eK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bp4Xh4ro_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2EiEY3eK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GruTZCgW, 1, m, &cIf_GruTZCgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bp4Xh4ro_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_D7LDL8Tv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FGIQrBeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kZOVNxrf, 1, m, &cIf_kZOVNxrf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0yDxzyUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kZOVNxrf, 0, m, &cIf_kZOVNxrf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZkuhXpTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tkI2i0YT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_O43pbK1G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tkI2i0YT, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KTKomL8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_02f5HuMb_sendMessage(_c, 0, m);
  cMsg_FIsmVjHb_sendMessage(_c, 0, m);
  cMsg_HAWLkaTd_sendMessage(_c, 0, m);
  cMsg_B681Ext1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yeYM6s4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_02f5HuMb_sendMessage(_c, 0, m);
  cMsg_0S7drRKY_sendMessage(_c, 0, m);
  cMsg_ORmIPNuk_sendMessage(_c, 0, m);
  cMsg_Yed8KAYt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sabnLEDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_1zsFgtmw_sendMessage(_c, 0, m);
  cMsg_0S7drRKY_sendMessage(_c, 0, m);
  cMsg_B681Ext1_sendMessage(_c, 0, m);
  cMsg_uPpgEwtg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lgCG6eOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_1zsFgtmw_sendMessage(_c, 0, m);
  cMsg_7H84ibLG_sendMessage(_c, 0, m);
  cMsg_HAWLkaTd_sendMessage(_c, 0, m);
  cMsg_NJyvwdGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wkhnyixy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_v9otY9Kg_sendMessage(_c, 0, m);
  cMsg_Yed8KAYt_sendMessage(_c, 0, m);
  cMsg_HcPrVLmO_sendMessage(_c, 0, m);
  cMsg_HAWLkaTd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_neJ2uFV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_v9otY9Kg_sendMessage(_c, 0, m);
  cMsg_NJyvwdGo_sendMessage(_c, 0, m);
  cMsg_0S7drRKY_sendMessage(_c, 0, m);
  cMsg_0gPRSLVq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4CJHGUuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w8hk4z2o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xIAsjLLY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j7oecDMh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w8hk4z2o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xIAsjLLY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ouMqdHI5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZBtvh4wT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sxLyWyIo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y3QkjBYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZBtvh4wT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sxLyWyIo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6qpmXgw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k2DSTq6x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ikNBhqcY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7crtMhmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k2DSTq6x_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ikNBhqcY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_02f5HuMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_4CJHGUuW_sendMessage(_c, 0, m);
  cMsg_Y3QkjBYf_sendMessage(_c, 0, m);
  cMsg_7crtMhmR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1zsFgtmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_j7oecDMh_sendMessage(_c, 0, m);
  cMsg_ouMqdHI5_sendMessage(_c, 0, m);
  cMsg_7crtMhmR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v9otY9Kg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_j7oecDMh_sendMessage(_c, 0, m);
  cMsg_Y3QkjBYf_sendMessage(_c, 0, m);
  cMsg_6qpmXgw4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lIzrUL8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Oa8By7GG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tEP6sNPZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jMDGgX1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Oa8By7GG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tEP6sNPZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XWA0czEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KZlJQbau_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rX7xIyXM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h561myYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KZlJQbau_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rX7xIyXM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Yu0rEOpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M7AaxPcI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3bsQW4U6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HJrzm4Nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M7AaxPcI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3bsQW4U6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0S7drRKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_jMDGgX1f_sendMessage(_c, 0, m);
  cMsg_h561myYv_sendMessage(_c, 0, m);
  cMsg_HJrzm4Nz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FIsmVjHb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_jMDGgX1f_sendMessage(_c, 0, m);
  cMsg_XWA0czEz_sendMessage(_c, 0, m);
  cMsg_Yu0rEOpR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7H84ibLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_lIzrUL8R_sendMessage(_c, 0, m);
  cMsg_h561myYv_sendMessage(_c, 0, m);
  cMsg_Yu0rEOpR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gW3bBSNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AXh97fnk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LxIw6Dap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qKy9La5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AXh97fnk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LxIw6Dap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5sKU1kN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mU6xfAwF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vFm82kXe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VWVP7rIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mU6xfAwF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vFm82kXe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FwgoeuWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_auhHcPpa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IOyLtd1P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nPQddCwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_auhHcPpa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IOyLtd1P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NJyvwdGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_gW3bBSNx_sendMessage(_c, 0, m);
  cMsg_VWVP7rIQ_sendMessage(_c, 0, m);
  cMsg_nPQddCwt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Yed8KAYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_qKy9La5u_sendMessage(_c, 0, m);
  cMsg_5sKU1kN0_sendMessage(_c, 0, m);
  cMsg_nPQddCwt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_B681Ext1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_qKy9La5u_sendMessage(_c, 0, m);
  cMsg_VWVP7rIQ_sendMessage(_c, 0, m);
  cMsg_FwgoeuWq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GOqI94od_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3lw7YNhy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sKDkQkox_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Qw4xnbIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3lw7YNhy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sKDkQkox_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R2bbpnE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pkCudnNO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SPnbMEx1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QJ9AR5ow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pkCudnNO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SPnbMEx1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oROn4g5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5DwwaOaW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5jMTY2u9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vhi77kkB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5DwwaOaW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5jMTY2u9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HAWLkaTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_Qw4xnbIJ_sendMessage(_c, 0, m);
  cMsg_QJ9AR5ow_sendMessage(_c, 0, m);
  cMsg_vhi77kkB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ORmIPNuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_Qw4xnbIJ_sendMessage(_c, 0, m);
  cMsg_R2bbpnE7_sendMessage(_c, 0, m);
  cMsg_oROn4g5P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0gPRSLVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_GOqI94od_sendMessage(_c, 0, m);
  cMsg_R2bbpnE7_sendMessage(_c, 0, m);
  cMsg_vhi77kkB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HcPrVLmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_lIzrUL8R_sendMessage(_c, 0, m);
  cMsg_XWA0czEz_sendMessage(_c, 0, m);
  cMsg_HJrzm4Nz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uPpgEwtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_GOqI94od_sendMessage(_c, 0, m);
  cMsg_QJ9AR5ow_sendMessage(_c, 0, m);
  cMsg_oROn4g5P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_yIEV25Mi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n3LVSwRJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_F1ZjE3Lx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SSrQGC1H, 0, m, &cSlice_SSrQGC1H_sendMessage);
      break;
    }
    default: {
      cSwitchcase_y8fqXKOM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_SSrQGC1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_U3ifZe1d_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_U3ifZe1d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_28gt6RSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_U3ifZe1d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_U3ifZe1d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3sIuJVT2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_q8rzfF7o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_TQZp1Ggu, 0, m, &cSlice_TQZp1Ggu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bC9wTzBn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_TQZp1Ggu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PcbFpbe6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PcbFpbe6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_bRilKh5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PcbFpbe6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_PcbFpbe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_17ddtp5V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bC9wTzBn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I0On8hyq, 0, m, &cSlice_I0On8hyq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_F1ZjE3Lx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_I0On8hyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_14eszU29_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_14eszU29_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dnhbZgDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_14eszU29_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_14eszU29_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QmSFIOwO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_y8fqXKOM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ehgNYP1S, 0, m, &cSlice_ehgNYP1S_sendMessage);
      break;
    }
    default: {
      cSwitchcase_9DnVInhM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ehgNYP1S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Lw07J9zP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Lw07J9zP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_cm0FqbEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Lw07J9zP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Lw07J9zP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hiJ3Y6L2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9DnVInhM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CyZsZCq7, 0, m, &cSlice_CyZsZCq7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nNKHyNrY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_CyZsZCq7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HuH8E0fw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HuH8E0fw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_HIxdO1aO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HuH8E0fw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HuH8E0fw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n8yEkPHr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_miTEgYeE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_M8jz0fP0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_M8jz0fP0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6VoPlOUa, 1, m, &cDelay_6VoPlOUa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e9UKYYJ9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6VoPlOUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6VoPlOUa, m);
  cMsg_BYMP9q8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_M8jz0fP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6VoPlOUa, 0, m, &cDelay_6VoPlOUa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e9UKYYJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6VoPlOUa, 0, m, &cDelay_6VoPlOUa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_MXXGbrsh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOlG5xtA, HV_BINOP_SUBTRACT, 0, m, &cBinop_bOlG5xtA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_AO7HaYPV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dqlAoGgm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4kf5O6KA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dqlAoGgm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_0HmVfmcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MXXGbrsh, 0, m, &cVar_MXXGbrsh_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_PZ2KquSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FDCdMxvZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GKJUKAaH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T03gieSn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bOlG5xtA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VoArWfiw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VoArWfiw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JZsj9qBP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JZsj9qBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_iYty6CA0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tQJCclrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vILhrYrN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UO4UZkhC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UO4UZkhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rlCRsvFV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_vILhrYrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AO7HaYPV, 1, m, &cIf_AO7HaYPV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pHFWbN8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4kf5O6KA, 1, m, &cIf_4kf5O6KA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rlCRsvFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AO7HaYPV, 0, m, &cIf_AO7HaYPV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iYty6CA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4kf5O6KA, 0, m, &cIf_4kf5O6KA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GKJUKAaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bOlG5xtA, HV_BINOP_SUBTRACT, 1, m, &cBinop_bOlG5xtA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FDCdMxvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_T03gieSn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MXXGbrsh, 0, m, &cVar_MXXGbrsh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dqlAoGgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kchRL7yo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nNKHyNrY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VGkQk9mI, 0, m, &cSlice_VGkQk9mI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VGkQk9mI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_LBZBhkdm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_LBZBhkdm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_QravkE1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LBZBhkdm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LBZBhkdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HUSobkk6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_E5ecGqcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nUTIg0M4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CwO76XAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f8esvJwG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_3lLibdOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4UC0LJoE, 0, m, &cVar_4UC0LJoE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n3LVSwRJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mzXzoS4N, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EnI7UUGl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_miTEgYeE_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_37KCsRBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OdqQ3uih_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BYMP9q8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UNz9KVcE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OdqQ3uih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UNz9KVcE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LbvaNpzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_9eGoPTn7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9eGoPTn7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WRx5HBRv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WRx5HBRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rfBuu1Up, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_lnyGf284_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iUBdbGO0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ACcsiWZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_peYMd5r9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8zfqxD0E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g8pJV0KR_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xNKNcjh0_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7pBTg5J7_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TIlOYpKF_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4dCH4RGS_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OhHoLyJY_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_g8pJV0KR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nlnPCAuz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_xNKNcjh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1B15IO12_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_7pBTg5J7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CaBXnCV0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_TIlOYpKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UQ3hEjlU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_4dCH4RGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T4o5tdOW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_OhHoLyJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fwjPth0y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_1Yl4dDlv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_m0te3yWe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Gs7eCnkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EGO6od59_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AWDEXCUC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_prMvqNH4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_prMvqNH4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xWoauPMa, 1, m, &cDelay_xWoauPMa_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j2sXWH1q_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xWoauPMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xWoauPMa, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1Yl4dDlv, 0, m, &cIf_1Yl4dDlv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_prMvqNH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xWoauPMa, 0, m, &cDelay_xWoauPMa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j2sXWH1q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xWoauPMa, 0, m, &cDelay_xWoauPMa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_biJAV4l6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_76IWfXgq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1debqWQA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6yZUn8ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_912NinLL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Op1tsPuK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Op1tsPuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AWDEXCUC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_912NinLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1Yl4dDlv, 1, m, &cIf_1Yl4dDlv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1debqWQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gs7eCnkd, 0, m, &cIf_Gs7eCnkd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_76IWfXgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gs7eCnkd, 1, m, &cIf_Gs7eCnkd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EGO6od59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ooj8Okrn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_m0te3yWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ooj8Okrn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lPLwdhNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uep5k7HD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jOb61Dt1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IflUHbbY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PkcxaVCs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZZ5LiE27_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZZ5LiE27_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Jn9cmKLp, 1, m, &cDelay_Jn9cmKLp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4v8D2eOD_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Jn9cmKLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Jn9cmKLp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lPLwdhNC, 0, m, &cIf_lPLwdhNC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZZ5LiE27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Jn9cmKLp, 0, m, &cDelay_Jn9cmKLp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4v8D2eOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Jn9cmKLp, 0, m, &cDelay_Jn9cmKLp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QBNqmsvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ws2qlGTU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SLzVfXtK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9iH4VkxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sco3TD6F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Prjp1P0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sco3TD6F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lPLwdhNC, 1, m, &cIf_lPLwdhNC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Prjp1P0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PkcxaVCs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Ws2qlGTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jOb61Dt1, 1, m, &cIf_jOb61Dt1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SLzVfXtK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jOb61Dt1, 0, m, &cIf_jOb61Dt1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IflUHbbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8ubjhU6f, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uep5k7HD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8ubjhU6f, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3fqIVLl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8VkBQFOU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lWRaesU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uUH7PTBK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tRSk5W0c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_T7hPvGIh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_T7hPvGIh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9yV1QODw, 1, m, &cDelay_9yV1QODw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VeDUchGO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9yV1QODw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9yV1QODw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3fqIVLl6, 0, m, &cIf_3fqIVLl6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T7hPvGIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9yV1QODw, 0, m, &cDelay_9yV1QODw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VeDUchGO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9yV1QODw, 0, m, &cDelay_9yV1QODw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C204L844_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FWr1DVk7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZHn5wNgk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e8lX5bSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XXzfvAng_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zdyQeXWW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zdyQeXWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tRSk5W0c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XXzfvAng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3fqIVLl6, 1, m, &cIf_3fqIVLl6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FWr1DVk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lWRaesU6, 1, m, &cIf_lWRaesU6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZHn5wNgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lWRaesU6, 0, m, &cIf_lWRaesU6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uUH7PTBK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AUN6fHQx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8VkBQFOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AUN6fHQx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xPNekRfS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UaJSUUaI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kk9PwCsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mTotMjrp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XceLz4zs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NXAIxIg3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NXAIxIg3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZX3sIr48, 1, m, &cDelay_ZX3sIr48_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C2mG6tgz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZX3sIr48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZX3sIr48, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xPNekRfS, 0, m, &cIf_xPNekRfS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NXAIxIg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZX3sIr48, 0, m, &cDelay_ZX3sIr48_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_C2mG6tgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZX3sIr48, 0, m, &cDelay_ZX3sIr48_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4UEL4VjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oZGY1EBR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bUFxwUGC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SKDVO3gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hlu6WHNZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Au93KRLA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Au93KRLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XceLz4zs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hlu6WHNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xPNekRfS, 1, m, &cIf_xPNekRfS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bUFxwUGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kk9PwCsE, 0, m, &cIf_kk9PwCsE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oZGY1EBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kk9PwCsE, 1, m, &cIf_kk9PwCsE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mTotMjrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d6JVGv2r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UaJSUUaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d6JVGv2r, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KKlFhYDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CQzVNqIR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_GM95mZ2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hKdhHLvw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KVKc2wA3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nUVJJzDx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nUVJJzDx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hZCIJXwQ, 1, m, &cDelay_hZCIJXwQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yFjIDuvH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hZCIJXwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hZCIJXwQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KKlFhYDs, 0, m, &cIf_KKlFhYDs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nUVJJzDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hZCIJXwQ, 0, m, &cDelay_hZCIJXwQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yFjIDuvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hZCIJXwQ, 0, m, &cDelay_hZCIJXwQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Mike1Squ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JTzfE9fV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UPGOikto_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DDU52hyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ys9Aq0KD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QvtK3kBL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QvtK3kBL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KVKc2wA3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Ys9Aq0KD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KKlFhYDs, 1, m, &cIf_KKlFhYDs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UPGOikto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GM95mZ2O, 0, m, &cIf_GM95mZ2O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JTzfE9fV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GM95mZ2O, 1, m, &cIf_GM95mZ2O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hKdhHLvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FFEzuyIQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CQzVNqIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FFEzuyIQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6SDKq8hW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_duevpxpy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dkKuimYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3bn4L1QY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aDkQUDcy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_n35CfKGk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_n35CfKGk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JaqsoUD0, 1, m, &cDelay_JaqsoUD0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HGmY66nM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JaqsoUD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JaqsoUD0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6SDKq8hW, 0, m, &cIf_6SDKq8hW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n35CfKGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JaqsoUD0, 0, m, &cDelay_JaqsoUD0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HGmY66nM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JaqsoUD0, 0, m, &cDelay_JaqsoUD0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nCJPCBPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_38WgHRhX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FOopkm0t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k18cJeyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ntWlBNPD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XRL7ZvMn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XRL7ZvMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aDkQUDcy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ntWlBNPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6SDKq8hW, 1, m, &cIf_6SDKq8hW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FOopkm0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dkKuimYF, 0, m, &cIf_dkKuimYF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_38WgHRhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dkKuimYF, 1, m, &cIf_dkKuimYF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3bn4L1QY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d4J8SYe3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_duevpxpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d4J8SYe3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lXGApP8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6xEIL0VB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_h7Hsq6DP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ylfvtNoj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SOL7Qf7p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CpE4ZzXw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CpE4ZzXw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DsZhpH6E, 1, m, &cDelay_DsZhpH6E_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RnntB9pZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_DsZhpH6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DsZhpH6E, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lXGApP8e, 0, m, &cIf_lXGApP8e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CpE4ZzXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DsZhpH6E, 0, m, &cDelay_DsZhpH6E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RnntB9pZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DsZhpH6E, 0, m, &cDelay_DsZhpH6E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_13PH05f8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Hgam8xwm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bNrZzzLo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yJUnw9qN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2xzROTWt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8uXKg58a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8uXKg58a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SOL7Qf7p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2xzROTWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lXGApP8e, 1, m, &cIf_lXGApP8e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bNrZzzLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h7Hsq6DP, 0, m, &cIf_h7Hsq6DP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hgam8xwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h7Hsq6DP, 1, m, &cIf_h7Hsq6DP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ylfvtNoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZCZKqEF8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6xEIL0VB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZCZKqEF8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5YetaJWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MujWHRMi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lhr3OkLo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YvM8RUrW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CJXTQmpi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8DJ2LoWX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8DJ2LoWX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mNcwFoUJ, 1, m, &cDelay_mNcwFoUJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mdxMRVQl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mNcwFoUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mNcwFoUJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5YetaJWa, 0, m, &cIf_5YetaJWa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8DJ2LoWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mNcwFoUJ, 0, m, &cDelay_mNcwFoUJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mdxMRVQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mNcwFoUJ, 0, m, &cDelay_mNcwFoUJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BM3S9Ivs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t38Ltkry_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2ZxcBdTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qR1vyFNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qougEpys_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e5uRxTSB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qougEpys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5YetaJWa, 1, m, &cIf_5YetaJWa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e5uRxTSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CJXTQmpi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2ZxcBdTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lhr3OkLo, 0, m, &cIf_lhr3OkLo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t38Ltkry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lhr3OkLo, 1, m, &cIf_lhr3OkLo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YvM8RUrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NB8pRGaw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MujWHRMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NB8pRGaw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_lBQDRyjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MVPGKEEX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FBPcCN55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZR6AQjWo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Q506Pyy5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rtokXoZw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rtokXoZw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qhFcr35G, 1, m, &cDelay_qhFcr35G_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eCBZL3hG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qhFcr35G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qhFcr35G, m);
  cIf_onMessage(_c, &Context(_c)->cIf_lBQDRyjC, 0, m, &cIf_lBQDRyjC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rtokXoZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qhFcr35G, 0, m, &cDelay_qhFcr35G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eCBZL3hG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qhFcr35G, 0, m, &cDelay_qhFcr35G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P5nPx8eq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IBoAaFMr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cHg2bxl7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_368Rzoew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T25Zt1vY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LZy6s3L8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LZy6s3L8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Q506Pyy5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_T25Zt1vY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lBQDRyjC, 1, m, &cIf_lBQDRyjC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cHg2bxl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FBPcCN55, 0, m, &cIf_FBPcCN55_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IBoAaFMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FBPcCN55, 1, m, &cIf_FBPcCN55_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZR6AQjWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mzs1TARu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MVPGKEEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mzs1TARu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_coGAOHxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rKxk87sq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_jKUorcr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nym15U6Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1n1MSTti_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_z1bWBXJ6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_z1bWBXJ6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3e232xCU, 1, m, &cDelay_3e232xCU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xmihpA4L_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_3e232xCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3e232xCU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_coGAOHxd, 0, m, &cIf_coGAOHxd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z1bWBXJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3e232xCU, 0, m, &cDelay_3e232xCU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xmihpA4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3e232xCU, 0, m, &cDelay_3e232xCU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qEOLA8pA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TFq32nsy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FtvlFQ0b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gfrt5SEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ebV7YDEe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ygxM8VOl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ygxM8VOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1n1MSTti_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ebV7YDEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_coGAOHxd, 1, m, &cIf_coGAOHxd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FtvlFQ0b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jKUorcr9, 0, m, &cIf_jKUorcr9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TFq32nsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jKUorcr9, 1, m, &cIf_jKUorcr9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nym15U6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ja58qyH4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rKxk87sq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ja58qyH4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_czvgA84n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_K0nLOMHd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_OgCZ1IQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_F4gnSscn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ebYoUs3B_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UYvROvSX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UYvROvSX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sSvetzE9, 1, m, &cDelay_sSvetzE9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JMGv8qXp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sSvetzE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sSvetzE9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_czvgA84n, 0, m, &cIf_czvgA84n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UYvROvSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sSvetzE9, 0, m, &cDelay_sSvetzE9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JMGv8qXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sSvetzE9, 0, m, &cDelay_sSvetzE9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ucoYZzrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2iLBbQdr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gbtqbBMq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jj7Bsgpe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3XxG7ANk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TSAmqLn5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TSAmqLn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ebYoUs3B_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3XxG7ANk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_czvgA84n, 1, m, &cIf_czvgA84n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gbtqbBMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OgCZ1IQT, 0, m, &cIf_OgCZ1IQT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2iLBbQdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OgCZ1IQT, 1, m, &cIf_OgCZ1IQT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_F4gnSscn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QI3Yokhg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_K0nLOMHd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QI3Yokhg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_WANSJZ4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_v60suO1h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gv9rfD6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mnNXvkNR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mR6OkmwH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eUVKtgJu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eUVKtgJu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ghzjECAq, 1, m, &cDelay_ghzjECAq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OmwX7c2R_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ghzjECAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ghzjECAq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WANSJZ4E, 0, m, &cIf_WANSJZ4E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eUVKtgJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ghzjECAq, 0, m, &cDelay_ghzjECAq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OmwX7c2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ghzjECAq, 0, m, &cDelay_ghzjECAq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8gRR8NNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zOBPlyn5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hmbVc4u6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_beQJ5VIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uI7R79pn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cQCTxU6y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uI7R79pn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WANSJZ4E, 1, m, &cIf_WANSJZ4E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cQCTxU6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_mR6OkmwH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hmbVc4u6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gv9rfD6u, 0, m, &cIf_gv9rfD6u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zOBPlyn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gv9rfD6u, 1, m, &cIf_gv9rfD6u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mnNXvkNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dsmpp6Kc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_v60suO1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dsmpp6Kc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nlnPCAuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_HpQX7KF1_sendMessage(_c, 0, m);
  cMsg_3a9KvZzY_sendMessage(_c, 0, m);
  cMsg_JlkXBMzk_sendMessage(_c, 0, m);
  cMsg_bCp3X8aW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1B15IO12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_HpQX7KF1_sendMessage(_c, 0, m);
  cMsg_QrXr1ewU_sendMessage(_c, 0, m);
  cMsg_I5aVBcf8_sendMessage(_c, 0, m);
  cMsg_ClpfKi9Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CaBXnCV0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_EaAfLTix_sendMessage(_c, 0, m);
  cMsg_QrXr1ewU_sendMessage(_c, 0, m);
  cMsg_bCp3X8aW_sendMessage(_c, 0, m);
  cMsg_AZm5g7Zh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UQ3hEjlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_EaAfLTix_sendMessage(_c, 0, m);
  cMsg_UD8A2XOT_sendMessage(_c, 0, m);
  cMsg_JlkXBMzk_sendMessage(_c, 0, m);
  cMsg_ORinK0F6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_T4o5tdOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_2xqcyq0E_sendMessage(_c, 0, m);
  cMsg_ClpfKi9Q_sendMessage(_c, 0, m);
  cMsg_rEGQLfVM_sendMessage(_c, 0, m);
  cMsg_JlkXBMzk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fwjPth0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_2xqcyq0E_sendMessage(_c, 0, m);
  cMsg_ORinK0F6_sendMessage(_c, 0, m);
  cMsg_QrXr1ewU_sendMessage(_c, 0, m);
  cMsg_O9fgskSD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_u8TqhMCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6yZUn8ww_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_biJAV4l6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BEbjYjz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6yZUn8ww_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_biJAV4l6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YzGGr7dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9iH4VkxZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QBNqmsvj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fimfk4P6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9iH4VkxZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QBNqmsvj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g7MRaX57_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_e8lX5bSG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C204L844_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YbGKAtNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_e8lX5bSG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C204L844_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HpQX7KF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_u8TqhMCM_sendMessage(_c, 0, m);
  cMsg_fimfk4P6_sendMessage(_c, 0, m);
  cMsg_YbGKAtNx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EaAfLTix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_BEbjYjz9_sendMessage(_c, 0, m);
  cMsg_YzGGr7dl_sendMessage(_c, 0, m);
  cMsg_YbGKAtNx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2xqcyq0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_BEbjYjz9_sendMessage(_c, 0, m);
  cMsg_fimfk4P6_sendMessage(_c, 0, m);
  cMsg_g7MRaX57_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tA4YLyH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SKDVO3gc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4UEL4VjM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hXxkd6hs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SKDVO3gc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4UEL4VjM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e8IgcpCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DDU52hyT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Mike1Squ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AFxjitkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DDU52hyT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Mike1Squ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z0qB2TBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k18cJeyX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nCJPCBPX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rAX9Vga1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_k18cJeyX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nCJPCBPX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QrXr1ewU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_hXxkd6hs_sendMessage(_c, 0, m);
  cMsg_AFxjitkW_sendMessage(_c, 0, m);
  cMsg_rAX9Vga1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3a9KvZzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_hXxkd6hs_sendMessage(_c, 0, m);
  cMsg_e8IgcpCE_sendMessage(_c, 0, m);
  cMsg_z0qB2TBG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UD8A2XOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_tA4YLyH6_sendMessage(_c, 0, m);
  cMsg_AFxjitkW_sendMessage(_c, 0, m);
  cMsg_z0qB2TBG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eLmS6Adv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gfrt5SEv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qEOLA8pA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wia5SfSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gfrt5SEv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qEOLA8pA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BKExFmkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jj7Bsgpe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ucoYZzrp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oM1NEkvW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jj7Bsgpe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ucoYZzrp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yaaoyVh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_beQJ5VIe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8gRR8NNs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gMhTicf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_beQJ5VIe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8gRR8NNs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ORinK0F6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_eLmS6Adv_sendMessage(_c, 0, m);
  cMsg_oM1NEkvW_sendMessage(_c, 0, m);
  cMsg_gMhTicf1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ClpfKi9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Wia5SfSf_sendMessage(_c, 0, m);
  cMsg_BKExFmkK_sendMessage(_c, 0, m);
  cMsg_gMhTicf1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bCp3X8aW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Wia5SfSf_sendMessage(_c, 0, m);
  cMsg_oM1NEkvW_sendMessage(_c, 0, m);
  cMsg_yaaoyVh3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OkimD7AM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yJUnw9qN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_13PH05f8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WuRRRgbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yJUnw9qN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_13PH05f8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9OhVKKaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qR1vyFNk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BM3S9Ivs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5XLuP4MU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qR1vyFNk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_BM3S9Ivs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VdWemmu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_368Rzoew_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_P5nPx8eq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hHxqyx9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_368Rzoew_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_P5nPx8eq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JlkXBMzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_WuRRRgbQ_sendMessage(_c, 0, m);
  cMsg_5XLuP4MU_sendMessage(_c, 0, m);
  cMsg_hHxqyx9c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I5aVBcf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_WuRRRgbQ_sendMessage(_c, 0, m);
  cMsg_9OhVKKaP_sendMessage(_c, 0, m);
  cMsg_VdWemmu1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_O9fgskSD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_OkimD7AM_sendMessage(_c, 0, m);
  cMsg_9OhVKKaP_sendMessage(_c, 0, m);
  cMsg_hHxqyx9c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rEGQLfVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_tA4YLyH6_sendMessage(_c, 0, m);
  cMsg_e8IgcpCE_sendMessage(_c, 0, m);
  cMsg_rAX9Vga1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AZm5g7Zh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_OkimD7AM_sendMessage(_c, 0, m);
  cMsg_5XLuP4MU_sendMessage(_c, 0, m);
  cMsg_VdWemmu1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_lrBKp10r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IVi0O49d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hEfktmbn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qiEjItvi, 0, m, &cSlice_qiEjItvi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_FdC09tDN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_qiEjItvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AoBzZirh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AoBzZirh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dS4N0SbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AoBzZirh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AoBzZirh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YCZT5bSZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tAcNmxUs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aGxTWCRN, 0, m, &cSlice_aGxTWCRN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_JcOo6Aij_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_aGxTWCRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FwucK89b_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FwucK89b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_xCaSPl2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FwucK89b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FwucK89b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_T8350C9h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JcOo6Aij_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_45ogEDC3, 0, m, &cSlice_45ogEDC3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hEfktmbn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_45ogEDC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XCClklmH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XCClklmH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jYrPM3Dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XCClklmH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XCClklmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gTH9AigY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FdC09tDN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_OA7xIJuA, 0, m, &cSlice_OA7xIJuA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_KPZyNoeS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_OA7xIJuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_M5tKxSNb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_M5tKxSNb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_byBSdWrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_M5tKxSNb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_M5tKxSNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4DsqxIPX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KPZyNoeS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qwIVBAD7, 0, m, &cSlice_qwIVBAD7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_C52ihWOt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_qwIVBAD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YuumO9jp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YuumO9jp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_4HE3UrFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YuumO9jp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_YuumO9jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MjSfk0li_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tE9QLeqZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5f8IdoLX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5f8IdoLX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YHpSIfv2, 1, m, &cDelay_YHpSIfv2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qq78kt2T_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YHpSIfv2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YHpSIfv2, m);
  cMsg_9CuLJB7F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5f8IdoLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YHpSIfv2, 0, m, &cDelay_YHpSIfv2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qq78kt2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YHpSIfv2, 0, m, &cDelay_YHpSIfv2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_lflBS7bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rH6h0KR5, HV_BINOP_SUBTRACT, 0, m, &cBinop_rH6h0KR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_tsctJHfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5L0ySjLR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BBWVVRt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5L0ySjLR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_CzX6y72S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lflBS7bj, 0, m, &cVar_lflBS7bj_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_0kOALBXK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tqov4roO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DaMCvIng_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qZDLXctp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rH6h0KR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SA3j9ESR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SA3j9ESR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_T9GQhMRC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T9GQhMRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HNPAx3Wi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rsQQUdGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fbj26pOt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hBFmsbTP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Fbj26pOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tsctJHfE, 1, m, &cIf_tsctJHfE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hBFmsbTP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XDVBjspU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_UztV2Sby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BBWVVRt2, 1, m, &cIf_BBWVVRt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XDVBjspU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tsctJHfE, 0, m, &cIf_tsctJHfE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HNPAx3Wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BBWVVRt2, 0, m, &cIf_BBWVVRt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tqov4roO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_qZDLXctp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lflBS7bj, 0, m, &cVar_lflBS7bj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DaMCvIng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rH6h0KR5, HV_BINOP_SUBTRACT, 1, m, &cBinop_rH6h0KR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5L0ySjLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hD9KjdUo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_C52ihWOt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XRcEUjvK, 0, m, &cSlice_XRcEUjvK_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XRcEUjvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_m4Ue2wQA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_m4Ue2wQA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ELBmc68E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_m4Ue2wQA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_m4Ue2wQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RnzXylPY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iUBdbGO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JDNuPB4P, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_peYMd5r9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i7nfuP3z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_WbDjag2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ACcsiWZz, 0, m, &cVar_ACcsiWZz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IVi0O49d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZLcSS2Wj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WJCTv3Xq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fb8jhW1i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_gX5URXZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tE9QLeqZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9CuLJB7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YNniUw2L, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Fb8jhW1i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YNniUw2L, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1FCAFIrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_vuAjdtR6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vuAjdtR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wS8a0Nir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wS8a0Nir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V56uGy6H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_U65c1Fgq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Urx4CI6R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_DWaNM7nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j4p9ROIU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_BIDTOkDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WoKxMsbF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Sdo3lpDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FlxLAEJs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Df8NG4jh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aqneh2ID_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9bPzjpAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lyBrVqjv_sendMessage);
  cMsg_qal9rl05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lyBrVqjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9bPzjpAS, 1, m, &cVar_9bPzjpAS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_V6QyDWyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LUCEp5cW_sendMessage(_c, 0, m);
  cMsg_HHfGJ1AK_sendMessage(_c, 0, m);
  cMsg_rUCy8EF5_sendMessage(_c, 0, m);
  cMsg_iZGhYBcM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SlIa71ak_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I79RVpmu, 0, m, &cSlice_I79RVpmu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_I79RVpmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Dh8NoUC8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Dh8NoUC8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_znBPjYnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Dh8NoUC8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Dh8NoUC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_grs6P37p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0h4UBJ0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_1aY9q8Si_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1aY9q8Si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_J8wUBJkp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J8wUBJkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1Svrrado_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1Svrrado_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KDu0EDtv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qcgATsGF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qcgATsGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K4iCBwzS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_KDu0EDtv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_MU2BoFeO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MU2BoFeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_D5vEqO6w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K4iCBwzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_hK9UYK5i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hK9UYK5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rQAsQgBG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D5vEqO6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rh99YjW1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_rQAsQgBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xmgySbtO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rh99YjW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fiyrj77y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xmgySbtO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_26pryQYb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_kAsO31UA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pe4HHawW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_gTwxuUUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yZiSPOek_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qwFgzyux_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V5Lt9Jlu_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R6arVpql_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h9top5sl_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eLvbdJ3m_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qp059GZE_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_goTDqtrs_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_V5Lt9Jlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lli5nGAF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_R6arVpql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WWSQw0xA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_h9top5sl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P5h7B3Dm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_eLvbdJ3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OhJQYXBq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_qp059GZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6GiuXyDo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_goTDqtrs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BwiUWJXl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_N406Go82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fKe5iYqt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5N7z5Lc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QEmoi6ST_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7zDVRkxm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_N8BKJj2z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_N8BKJj2z_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MOf91FGT, 1, m, &cDelay_MOf91FGT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lPdCyK1a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MOf91FGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MOf91FGT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_N406Go82, 0, m, &cIf_N406Go82_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N8BKJj2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MOf91FGT, 0, m, &cDelay_MOf91FGT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lPdCyK1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MOf91FGT, 0, m, &cDelay_MOf91FGT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VQfitTOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s09Yr2ZM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XQtYv9uG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O4rWVWPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xzrNtD6I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_05HChYlV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_05HChYlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7zDVRkxm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xzrNtD6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N406Go82, 1, m, &cIf_N406Go82_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XQtYv9uG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5N7z5Lc3, 0, m, &cIf_5N7z5Lc3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s09Yr2ZM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5N7z5Lc3, 1, m, &cIf_5N7z5Lc3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QEmoi6ST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ELsFdM82, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fKe5iYqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ELsFdM82, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_cG5Y7zkl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uIJL3QmJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_GaYfDQNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Mro7eia6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kXZJJ7R3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MOxNY8rO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MOxNY8rO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_h9YI0HEr, 1, m, &cDelay_h9YI0HEr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pee9ft1l_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_h9YI0HEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h9YI0HEr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_cG5Y7zkl, 0, m, &cIf_cG5Y7zkl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MOxNY8rO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_h9YI0HEr, 0, m, &cDelay_h9YI0HEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pee9ft1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h9YI0HEr, 0, m, &cDelay_h9YI0HEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b0QTeyOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VTls8p5F_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lpxtEkdi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ehCdfZNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4zgYuuCP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XObSx14q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XObSx14q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kXZJJ7R3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4zgYuuCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cG5Y7zkl, 1, m, &cIf_cG5Y7zkl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lpxtEkdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GaYfDQNM, 0, m, &cIf_GaYfDQNM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VTls8p5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GaYfDQNM, 1, m, &cIf_GaYfDQNM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Mro7eia6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_elVWOgD1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uIJL3QmJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_elVWOgD1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SWtr1Jdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6zcFRPL9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hWd1Bl6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DBlgJF2Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_poMH7lod_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_tSPTL5xQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_tSPTL5xQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_L36TfjxB, 1, m, &cDelay_L36TfjxB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0q38MMwa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_L36TfjxB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L36TfjxB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SWtr1Jdx, 0, m, &cIf_SWtr1Jdx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tSPTL5xQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_L36TfjxB, 0, m, &cDelay_L36TfjxB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0q38MMwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_L36TfjxB, 0, m, &cDelay_L36TfjxB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O5RYBu1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1iXU1ZeW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_21WwNlnH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E7PgaP9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FjCHqJi0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B9jvExrD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B9jvExrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_poMH7lod_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FjCHqJi0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SWtr1Jdx, 1, m, &cIf_SWtr1Jdx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_21WwNlnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hWd1Bl6K, 0, m, &cIf_hWd1Bl6K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1iXU1ZeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hWd1Bl6K, 1, m, &cIf_hWd1Bl6K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DBlgJF2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WnPWJfst, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6zcFRPL9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WnPWJfst, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_WWYALG1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dVcU5zex_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0eEQeqNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iUSoLstd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Z1yPR9Uj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XC4Ku0jz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XC4Ku0jz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OBlSSEJl, 1, m, &cDelay_OBlSSEJl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uvQFIUsv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OBlSSEJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OBlSSEJl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WWYALG1J, 0, m, &cIf_WWYALG1J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XC4Ku0jz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OBlSSEJl, 0, m, &cDelay_OBlSSEJl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uvQFIUsv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OBlSSEJl, 0, m, &cDelay_OBlSSEJl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G4KyXYyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ddMUXOR8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YWnLPJ0i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Z7aWd0bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g4iq8A00_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VpzUU47K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VpzUU47K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Z1yPR9Uj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_g4iq8A00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WWYALG1J, 1, m, &cIf_WWYALG1J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ddMUXOR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0eEQeqNg, 1, m, &cIf_0eEQeqNg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YWnLPJ0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0eEQeqNg, 0, m, &cIf_0eEQeqNg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iUSoLstd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1n6euF3C, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dVcU5zex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1n6euF3C, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_w6UQnE3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hwxLSpSW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AtjLhKCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_e5z2VEwx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KAV2pQYa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qX9WhjcH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qX9WhjcH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0skOWL7P, 1, m, &cDelay_0skOWL7P_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SkTxrZVZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0skOWL7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0skOWL7P, m);
  cIf_onMessage(_c, &Context(_c)->cIf_w6UQnE3X, 0, m, &cIf_w6UQnE3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qX9WhjcH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0skOWL7P, 0, m, &cDelay_0skOWL7P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SkTxrZVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0skOWL7P, 0, m, &cDelay_0skOWL7P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TpbjBk3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ICTQ9ebi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GAhnGljf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SPQDG4hU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SQNHQLmS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n33ZkQVA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n33ZkQVA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KAV2pQYa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SQNHQLmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_w6UQnE3X, 1, m, &cIf_w6UQnE3X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GAhnGljf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AtjLhKCz, 0, m, &cIf_AtjLhKCz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ICTQ9ebi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AtjLhKCz, 1, m, &cIf_AtjLhKCz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e5z2VEwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hKG3IoY3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hwxLSpSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hKG3IoY3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VSIrmLuN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9UcrCtuJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ls68C0BA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_A2t4CY5P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_l5CRVHCL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Y2XwGWni_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Y2XwGWni_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1is1dWtL, 1, m, &cDelay_1is1dWtL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IpF1KtG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1is1dWtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1is1dWtL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VSIrmLuN, 0, m, &cIf_VSIrmLuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Y2XwGWni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1is1dWtL, 0, m, &cDelay_1is1dWtL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8IpF1KtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1is1dWtL, 0, m, &cDelay_1is1dWtL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KbAXHu1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gWcVXcbW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GiQ2NmXd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Sv3ozr1Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UTSXm41d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UplVwPvP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UplVwPvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_l5CRVHCL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_UTSXm41d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VSIrmLuN, 1, m, &cIf_VSIrmLuN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GiQ2NmXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ls68C0BA, 0, m, &cIf_ls68C0BA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gWcVXcbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ls68C0BA, 1, m, &cIf_ls68C0BA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A2t4CY5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SSjcjdAH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9UcrCtuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SSjcjdAH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_wB7wemb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZmsBZhTA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Hd5vaaBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z93I68UI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_b6D7Spmo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_b1UuRHuY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_b1UuRHuY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ajXylLQC, 1, m, &cDelay_ajXylLQC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L6Cr7MOZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ajXylLQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ajXylLQC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_wB7wemb3, 0, m, &cIf_wB7wemb3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b1UuRHuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ajXylLQC, 0, m, &cDelay_ajXylLQC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L6Cr7MOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ajXylLQC, 0, m, &cDelay_ajXylLQC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QWdAs5qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0EMnNjV2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bx8VbzME_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sr5mrbby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FdnrNv6y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BArxeQoy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BArxeQoy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_b6D7Spmo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FdnrNv6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wB7wemb3, 1, m, &cIf_wB7wemb3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bx8VbzME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hd5vaaBr, 0, m, &cIf_Hd5vaaBr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0EMnNjV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hd5vaaBr, 1, m, &cIf_Hd5vaaBr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z93I68UI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BYmYGjfl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZmsBZhTA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BYmYGjfl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_drSIUGle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3vGWYCsq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sgMkvW35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W0HEIo1L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_M7iK6JOq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OfHTeRHQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OfHTeRHQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gTKZCYOh, 1, m, &cDelay_gTKZCYOh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_190F4sbi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gTKZCYOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gTKZCYOh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_drSIUGle, 0, m, &cIf_drSIUGle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OfHTeRHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gTKZCYOh, 0, m, &cDelay_gTKZCYOh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_190F4sbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gTKZCYOh, 0, m, &cDelay_gTKZCYOh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PwaSSgo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gtdQ042N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NhZu2uDl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e6j9JjNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SPg1JoaN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tc9KQLdk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tc9KQLdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_M7iK6JOq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SPg1JoaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_drSIUGle, 1, m, &cIf_drSIUGle_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NhZu2uDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sgMkvW35, 0, m, &cIf_sgMkvW35_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gtdQ042N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sgMkvW35, 1, m, &cIf_sgMkvW35_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W0HEIo1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZFqLCQ1k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3vGWYCsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZFqLCQ1k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sm4Rfkce_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_f0FPdyj0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BbmL5yJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sX6iDfAJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HJPMpX70_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_H5kNo7wu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_H5kNo7wu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Vrit6Gf0, 1, m, &cDelay_Vrit6Gf0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jaSI55CX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Vrit6Gf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Vrit6Gf0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sm4Rfkce, 0, m, &cIf_sm4Rfkce_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H5kNo7wu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vrit6Gf0, 0, m, &cDelay_Vrit6Gf0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jaSI55CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Vrit6Gf0, 0, m, &cDelay_Vrit6Gf0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HiJEsE5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QASULMJ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2uapwq2G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XVpUeaXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4IzGbB2V_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Kw3LXqa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4IzGbB2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sm4Rfkce, 1, m, &cIf_sm4Rfkce_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0Kw3LXqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HJPMpX70_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2uapwq2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BbmL5yJr, 0, m, &cIf_BbmL5yJr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QASULMJ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BbmL5yJr, 1, m, &cIf_BbmL5yJr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sX6iDfAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_49vNVd5q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f0FPdyj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_49vNVd5q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NvFilMhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3N5ZclKr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_irVWBLT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4QHaHnq9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KGZJSrDk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bq6WykCR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bq6WykCR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_F0ei79Ck, 1, m, &cDelay_F0ei79Ck_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l4ovt718_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_F0ei79Ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_F0ei79Ck, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NvFilMhR, 0, m, &cIf_NvFilMhR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bq6WykCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_F0ei79Ck, 0, m, &cDelay_F0ei79Ck_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l4ovt718_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_F0ei79Ck, 0, m, &cDelay_F0ei79Ck_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sE64xJdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xOp4SM1T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5BLjE6YA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hLhf3voV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DdlnBCeT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GZSwrVeQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DdlnBCeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NvFilMhR, 1, m, &cIf_NvFilMhR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GZSwrVeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KGZJSrDk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xOp4SM1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_irVWBLT2, 1, m, &cIf_irVWBLT2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5BLjE6YA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_irVWBLT2, 0, m, &cIf_irVWBLT2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4QHaHnq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r3onwTIM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3N5ZclKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r3onwTIM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_TV3aYk5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PdtAalFT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_X3eNGoeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pl7TWUUi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6LPElMUa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3qT5qyNN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3qT5qyNN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_XzKQisgU, 1, m, &cDelay_XzKQisgU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RTPfW4gE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_XzKQisgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_XzKQisgU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TV3aYk5I, 0, m, &cIf_TV3aYk5I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3qT5qyNN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_XzKQisgU, 0, m, &cDelay_XzKQisgU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RTPfW4gE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_XzKQisgU, 0, m, &cDelay_XzKQisgU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wApHxAqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fpbTEdfR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bBWZZOyk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZvPUR1ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vEkQ7nwh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZgjarEHC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vEkQ7nwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TV3aYk5I, 1, m, &cIf_TV3aYk5I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZgjarEHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6LPElMUa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_fpbTEdfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X3eNGoeX, 1, m, &cIf_X3eNGoeX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bBWZZOyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_X3eNGoeX, 0, m, &cIf_X3eNGoeX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pl7TWUUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3HhGHDQ0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PdtAalFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3HhGHDQ0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gQJn5gtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ifDO3HsA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BZX6gtFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7lErIBjR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IJsJiHUs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HVxT5m5k_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HVxT5m5k_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zYE7qVKN, 1, m, &cDelay_zYE7qVKN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qc4VJk7q_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zYE7qVKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zYE7qVKN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gQJn5gtX, 0, m, &cIf_gQJn5gtX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HVxT5m5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zYE7qVKN, 0, m, &cDelay_zYE7qVKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qc4VJk7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zYE7qVKN, 0, m, &cDelay_zYE7qVKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qrnbkCEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9EB0qxMj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_roNAZs3q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Len4eC6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QzOkdfh7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PGu0hhFW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PGu0hhFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IJsJiHUs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_QzOkdfh7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gQJn5gtX, 1, m, &cIf_gQJn5gtX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_roNAZs3q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BZX6gtFm, 0, m, &cIf_BZX6gtFm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9EB0qxMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BZX6gtFm, 1, m, &cIf_BZX6gtFm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7lErIBjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PyfWhrOs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ifDO3HsA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PyfWhrOs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Lli5nGAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_JyvQdYAh_sendMessage(_c, 0, m);
  cMsg_Un7Ms37P_sendMessage(_c, 0, m);
  cMsg_BbZw5ekG_sendMessage(_c, 0, m);
  cMsg_uL9uVFhp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WWSQw0xA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_JyvQdYAh_sendMessage(_c, 0, m);
  cMsg_m4nZpK89_sendMessage(_c, 0, m);
  cMsg_MWRFV3mX_sendMessage(_c, 0, m);
  cMsg_VxO2rhlP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_P5h7B3Dm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_EF7aFPUz_sendMessage(_c, 0, m);
  cMsg_m4nZpK89_sendMessage(_c, 0, m);
  cMsg_uL9uVFhp_sendMessage(_c, 0, m);
  cMsg_Xl6GdUzf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OhJQYXBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_EF7aFPUz_sendMessage(_c, 0, m);
  cMsg_v1kM8qd0_sendMessage(_c, 0, m);
  cMsg_BbZw5ekG_sendMessage(_c, 0, m);
  cMsg_FiF1ZbND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6GiuXyDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_UUqLFsi1_sendMessage(_c, 0, m);
  cMsg_VxO2rhlP_sendMessage(_c, 0, m);
  cMsg_pIx8CdZz_sendMessage(_c, 0, m);
  cMsg_BbZw5ekG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BwiUWJXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_UUqLFsi1_sendMessage(_c, 0, m);
  cMsg_FiF1ZbND_sendMessage(_c, 0, m);
  cMsg_m4nZpK89_sendMessage(_c, 0, m);
  cMsg_2nQ82xSB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Icwp4l5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O4rWVWPb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VQfitTOX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wKa2NFx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O4rWVWPb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_VQfitTOX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3mWBitXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ehCdfZNY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_b0QTeyOD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yjypPeo1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ehCdfZNY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_b0QTeyOD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xOFWfOk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E7PgaP9k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O5RYBu1f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IakKatwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E7PgaP9k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_O5RYBu1f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JyvQdYAh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Icwp4l5A_sendMessage(_c, 0, m);
  cMsg_yjypPeo1_sendMessage(_c, 0, m);
  cMsg_IakKatwV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EF7aFPUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_wKa2NFx7_sendMessage(_c, 0, m);
  cMsg_3mWBitXg_sendMessage(_c, 0, m);
  cMsg_IakKatwV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UUqLFsi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_wKa2NFx7_sendMessage(_c, 0, m);
  cMsg_yjypPeo1_sendMessage(_c, 0, m);
  cMsg_xOFWfOk9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_P5t2k80c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Z7aWd0bh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_G4KyXYyl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bFjpxYBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Z7aWd0bh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_G4KyXYyl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r4WR01iJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SPQDG4hU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TpbjBk3I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_svw4LQ5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SPQDG4hU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TpbjBk3I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PqcFSpML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Sv3ozr1Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KbAXHu1T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TxFLYcrZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Sv3ozr1Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KbAXHu1T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m4nZpK89_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_bFjpxYBa_sendMessage(_c, 0, m);
  cMsg_svw4LQ5B_sendMessage(_c, 0, m);
  cMsg_TxFLYcrZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Un7Ms37P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_bFjpxYBa_sendMessage(_c, 0, m);
  cMsg_r4WR01iJ_sendMessage(_c, 0, m);
  cMsg_PqcFSpML_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v1kM8qd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_P5t2k80c_sendMessage(_c, 0, m);
  cMsg_svw4LQ5B_sendMessage(_c, 0, m);
  cMsg_PqcFSpML_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GlYazHjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hLhf3voV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sE64xJdL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tN4b8pbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hLhf3voV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_sE64xJdL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1b5cWbgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZvPUR1ch_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wApHxAqb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5g9jjEuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZvPUR1ch_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wApHxAqb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xsmPYl2W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Len4eC6b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qrnbkCEE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jcIFedDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Len4eC6b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qrnbkCEE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FiF1ZbND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_GlYazHjt_sendMessage(_c, 0, m);
  cMsg_5g9jjEuX_sendMessage(_c, 0, m);
  cMsg_jcIFedDX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VxO2rhlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_tN4b8pbm_sendMessage(_c, 0, m);
  cMsg_1b5cWbgY_sendMessage(_c, 0, m);
  cMsg_jcIFedDX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uL9uVFhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_tN4b8pbm_sendMessage(_c, 0, m);
  cMsg_5g9jjEuX_sendMessage(_c, 0, m);
  cMsg_xsmPYl2W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gjd4XK4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sr5mrbby_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QWdAs5qT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TmA5NYSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sr5mrbby_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QWdAs5qT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7qXImIzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_e6j9JjNG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PwaSSgo4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mKslMNAq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_e6j9JjNG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PwaSSgo4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ndTCFrbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XVpUeaXR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HiJEsE5e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R9OmPgms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XVpUeaXR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HiJEsE5e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BbZw5ekG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_TmA5NYSS_sendMessage(_c, 0, m);
  cMsg_mKslMNAq_sendMessage(_c, 0, m);
  cMsg_R9OmPgms_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MWRFV3mX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_TmA5NYSS_sendMessage(_c, 0, m);
  cMsg_7qXImIzW_sendMessage(_c, 0, m);
  cMsg_ndTCFrbb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2nQ82xSB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_gjd4XK4Y_sendMessage(_c, 0, m);
  cMsg_7qXImIzW_sendMessage(_c, 0, m);
  cMsg_R9OmPgms_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pIx8CdZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_P5t2k80c_sendMessage(_c, 0, m);
  cMsg_r4WR01iJ_sendMessage(_c, 0, m);
  cMsg_TxFLYcrZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Xl6GdUzf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_gjd4XK4Y_sendMessage(_c, 0, m);
  cMsg_mKslMNAq_sendMessage(_c, 0, m);
  cMsg_ndTCFrbb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Df7FmTrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A0vPFGb4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cQb5P9ko_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_naXEHPUZ, 0, m, &cSlice_naXEHPUZ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_M41zdIOz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_naXEHPUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SFf5en15_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SFf5en15_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Fy8ab7Nx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SFf5en15_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_SFf5en15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uh6qG0Be_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3Ov4pMpV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Vzs12xSd, 0, m, &cSlice_Vzs12xSd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_e7ySqgVC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Vzs12xSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_9fVrOMKz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_9fVrOMKz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_RuMTqrAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9fVrOMKz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9fVrOMKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1TurlE60_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e7ySqgVC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CTKqlNeR, 0, m, &cSlice_CTKqlNeR_sendMessage);
      break;
    }
    default: {
      cSwitchcase_cQb5P9ko_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_CTKqlNeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ttwvqeKt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ttwvqeKt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Knxxtkzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ttwvqeKt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ttwvqeKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZCPKQpUX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_M41zdIOz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_JFgrpWzc, 0, m, &cSlice_JFgrpWzc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CaAENsNM_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_JFgrpWzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_W5IMkNm1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_W5IMkNm1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_7oueZOyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_W5IMkNm1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_W5IMkNm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qOblx3YZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CaAENsNM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_FIR4qpoS, 0, m, &cSlice_FIR4qpoS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fmeBkL6a_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_FIR4qpoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3Uf6p7AO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3Uf6p7AO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_t0PBCmDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3Uf6p7AO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3Uf6p7AO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KYciATec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JYcnlWlH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_63F7UP7t_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_63F7UP7t_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ozq0BMOV, 1, m, &cDelay_ozq0BMOV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NzhreUTp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ozq0BMOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ozq0BMOV, m);
  cMsg_3bx7WfpR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_63F7UP7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ozq0BMOV, 0, m, &cDelay_ozq0BMOV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NzhreUTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ozq0BMOV, 0, m, &cDelay_ozq0BMOV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_yiwzQT5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FA2YVFEe, HV_BINOP_SUBTRACT, 0, m, &cBinop_FA2YVFEe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_uH8MQqrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RCrdwwAF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oqEcZqgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RCrdwwAF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_07jQv5oD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yiwzQT5I, 0, m, &cVar_yiwzQT5I_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_GzsIqgOg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pvYpZFzL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NCLIlm4J_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yDt4wmGq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FA2YVFEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zMfTe6K6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zMfTe6K6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_msiD7Y00_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_msiD7Y00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_DqWBl8de_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_efxn6JHE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_k8jnwepT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RumkCuTp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k8jnwepT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uH8MQqrw, 1, m, &cIf_uH8MQqrw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RumkCuTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9BQuimbI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_b2lJLGT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oqEcZqgp, 1, m, &cIf_oqEcZqgp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9BQuimbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_uH8MQqrw, 0, m, &cIf_uH8MQqrw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DqWBl8de_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oqEcZqgp, 0, m, &cIf_oqEcZqgp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pvYpZFzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_yDt4wmGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yiwzQT5I, 0, m, &cVar_yiwzQT5I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NCLIlm4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FA2YVFEe, HV_BINOP_SUBTRACT, 1, m, &cBinop_FA2YVFEe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RCrdwwAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KmqYu8WU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fmeBkL6a_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Az0zUi4p, 0, m, &cSlice_Az0zUi4p_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Az0zUi4p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RLdqiVuo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RLdqiVuo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3yk4dewA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RLdqiVuo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_RLdqiVuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zEbLFWsK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pe4HHawW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XWNUIbpn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yZiSPOek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ogSdFWuu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_k7kXq8EJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gTwxuUUj, 0, m, &cVar_gTwxuUUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_A0vPFGb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dSBINeTO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gMxGZzK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BWoMmJEM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_UPd3PMau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JYcnlWlH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3bx7WfpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7SVRN5Yo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BWoMmJEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7SVRN5Yo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MDijuY6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_ZFmjirkC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZFmjirkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rekpcgHq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rekpcgHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I0R7Epxf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_Gzn2XyHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r64aUSNq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_fOt8modM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xxkCvgsy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jNONJAsL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JkmDaNv5_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6eXpyxYN_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DqbidWjT_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1sNrwlHU_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dOHP5fiM_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U732d8M0_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_JkmDaNv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dj6W86c6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_6eXpyxYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4vhb27zf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_DqbidWjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VswDn9og_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_1sNrwlHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GIcsjXBR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_dOHP5fiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aHIOUtqE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_U732d8M0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_McHlO1Bl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_MOmWDVVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_27uvi8Zp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gLDLq9sG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_u4w2uLuq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P9vCQ4Zg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_JldCUkKq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_JldCUkKq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Keo3JHMO, 1, m, &cDelay_Keo3JHMO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Us6X3Jq6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Keo3JHMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Keo3JHMO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MOmWDVVX, 0, m, &cIf_MOmWDVVX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JldCUkKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Keo3JHMO, 0, m, &cDelay_Keo3JHMO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Us6X3Jq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Keo3JHMO, 0, m, &cDelay_Keo3JHMO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pP74PlUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HSCKMW8f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r89SeTaO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iV3kCyT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dt5twGLO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LebEELEr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Dt5twGLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MOmWDVVX, 1, m, &cIf_MOmWDVVX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LebEELEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_P9vCQ4Zg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HSCKMW8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gLDLq9sG, 1, m, &cIf_gLDLq9sG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r89SeTaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gLDLq9sG, 0, m, &cIf_gLDLq9sG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u4w2uLuq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iBJFuMKm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_27uvi8Zp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iBJFuMKm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_kPiJSL7R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mcBcrNIP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MypIK6hg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_y37c1D9r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pDohVxpJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DLPBlZZG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DLPBlZZG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_13GVCgbF, 1, m, &cDelay_13GVCgbF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tv6oQRII_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_13GVCgbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_13GVCgbF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kPiJSL7R, 0, m, &cIf_kPiJSL7R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DLPBlZZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_13GVCgbF, 0, m, &cDelay_13GVCgbF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tv6oQRII_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_13GVCgbF, 0, m, &cDelay_13GVCgbF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JGaT1o91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gShMaTYq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r9KLgm2j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DV7RGBfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HmOZwgP1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ydlUBP78_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ydlUBP78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pDohVxpJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HmOZwgP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kPiJSL7R, 1, m, &cIf_kPiJSL7R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gShMaTYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MypIK6hg, 1, m, &cIf_MypIK6hg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r9KLgm2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MypIK6hg, 0, m, &cIf_MypIK6hg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y37c1D9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FReKVDpm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mcBcrNIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FReKVDpm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9N93RWIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_j3WDHOdF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_voui1Keb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CrF2vDet_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_y94DwoOL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MhReZpRs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MhReZpRs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BiqC81sF, 1, m, &cDelay_BiqC81sF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8BrM8yrb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BiqC81sF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BiqC81sF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9N93RWIg, 0, m, &cIf_9N93RWIg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MhReZpRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BiqC81sF, 0, m, &cDelay_BiqC81sF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8BrM8yrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BiqC81sF, 0, m, &cDelay_BiqC81sF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QrTxv47a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3v2pi602_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NfsyrThb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oghWsrjx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AzL3Ysfh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mJmZTM8T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AzL3Ysfh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9N93RWIg, 1, m, &cIf_9N93RWIg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mJmZTM8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_y94DwoOL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NfsyrThb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_voui1Keb, 0, m, &cIf_voui1Keb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3v2pi602_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_voui1Keb, 1, m, &cIf_voui1Keb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CrF2vDet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xoXuKlgk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_j3WDHOdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xoXuKlgk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_MSRUiIIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7t0UGWIH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kxMURTSy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nVLdJw28_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aMYWw68E_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_E1aH4N7D_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_E1aH4N7D_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CVEkDFYq, 1, m, &cDelay_CVEkDFYq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qqo9YK8f_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CVEkDFYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CVEkDFYq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MSRUiIIr, 0, m, &cIf_MSRUiIIr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E1aH4N7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CVEkDFYq, 0, m, &cDelay_CVEkDFYq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qqo9YK8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CVEkDFYq, 0, m, &cDelay_CVEkDFYq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1vbbviwx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4NIszbZg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Okpz2DjB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O2hvUsGs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vfidvLkj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vbeHxNEy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vfidvLkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MSRUiIIr, 1, m, &cIf_MSRUiIIr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vbeHxNEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aMYWw68E_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4NIszbZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kxMURTSy, 1, m, &cIf_kxMURTSy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Okpz2DjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kxMURTSy, 0, m, &cIf_kxMURTSy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nVLdJw28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fip42Fud, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7t0UGWIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fip42Fud, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_AgHtakaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ikye4rKx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yrmZYMCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_iR4sW7eq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RTdSRZHx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_SWzoxZ7n_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_SWzoxZ7n_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UFkQ5m4H, 1, m, &cDelay_UFkQ5m4H_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CYlOdXCx_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UFkQ5m4H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UFkQ5m4H, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AgHtakaE, 0, m, &cIf_AgHtakaE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SWzoxZ7n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UFkQ5m4H, 0, m, &cDelay_UFkQ5m4H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CYlOdXCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UFkQ5m4H, 0, m, &cDelay_UFkQ5m4H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8Jb1WG4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p8iQH4g7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aBlRWKE2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UTYbrynI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tdkcVeBm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SJfHAKLF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tdkcVeBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AgHtakaE, 1, m, &cIf_AgHtakaE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SJfHAKLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RTdSRZHx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_p8iQH4g7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yrmZYMCy, 1, m, &cIf_yrmZYMCy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aBlRWKE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yrmZYMCy, 0, m, &cIf_yrmZYMCy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iR4sW7eq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fZNbvPTl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ikye4rKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fZNbvPTl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HIdd76zM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PQxXdjo5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qY4fFNNJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ozKiinxS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AHOGrk4m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Rw4mUjuO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Rw4mUjuO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mQ00n06L, 1, m, &cDelay_mQ00n06L_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_38nOPhng_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mQ00n06L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mQ00n06L, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HIdd76zM, 0, m, &cIf_HIdd76zM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Rw4mUjuO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mQ00n06L, 0, m, &cDelay_mQ00n06L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_38nOPhng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mQ00n06L, 0, m, &cDelay_mQ00n06L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1PR3EKjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l5MzCSTv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IjFnIwq3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_57Z04UWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hMCl04uw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MAerGstE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MAerGstE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AHOGrk4m_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_hMCl04uw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HIdd76zM, 1, m, &cIf_HIdd76zM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l5MzCSTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qY4fFNNJ, 1, m, &cIf_qY4fFNNJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IjFnIwq3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qY4fFNNJ, 0, m, &cIf_qY4fFNNJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ozKiinxS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C8XQukgW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PQxXdjo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C8XQukgW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_IS74DbwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6ZjG4mAJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JU6cjnxp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kTlOz7E8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_y68oXYHY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qV9YWmDE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qV9YWmDE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zfXqE4me, 1, m, &cDelay_zfXqE4me_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lN15seGI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zfXqE4me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zfXqE4me, m);
  cIf_onMessage(_c, &Context(_c)->cIf_IS74DbwV, 0, m, &cIf_IS74DbwV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qV9YWmDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zfXqE4me, 0, m, &cDelay_zfXqE4me_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lN15seGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zfXqE4me, 0, m, &cDelay_zfXqE4me_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_prVTiT1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MxSlVWWk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pswVW0nD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f5gdQT8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wzhnu13q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xRYJ9EyN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xRYJ9EyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_y68oXYHY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_wzhnu13q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IS74DbwV, 1, m, &cIf_IS74DbwV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pswVW0nD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JU6cjnxp, 0, m, &cIf_JU6cjnxp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MxSlVWWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JU6cjnxp, 1, m, &cIf_JU6cjnxp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kTlOz7E8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d6kJBYbM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6ZjG4mAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d6kJBYbM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tPAg6k8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5g8e2o7M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_tgq2RQ6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ckTJ2E49_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oWPukpNe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_g2VwQBGF_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_g2VwQBGF_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yYC9wVOq, 1, m, &cDelay_yYC9wVOq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_duNY67nr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_yYC9wVOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yYC9wVOq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tPAg6k8r, 0, m, &cIf_tPAg6k8r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g2VwQBGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yYC9wVOq, 0, m, &cDelay_yYC9wVOq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_duNY67nr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yYC9wVOq, 0, m, &cDelay_yYC9wVOq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QNOrpdRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dxzeDucp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9ZiAVF60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VZ8Nbyfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HVg630nW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GwA3FiEk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GwA3FiEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oWPukpNe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HVg630nW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tPAg6k8r, 1, m, &cIf_tPAg6k8r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9ZiAVF60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tgq2RQ6s, 0, m, &cIf_tgq2RQ6s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dxzeDucp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tgq2RQ6s, 1, m, &cIf_tgq2RQ6s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ckTJ2E49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8nyuOLmi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5g8e2o7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8nyuOLmi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_BzHATfAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6WZgEKgs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5imHBnKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xhuNmRvb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FD9Q6nCI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mU45eGbd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mU45eGbd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1765GqpX, 1, m, &cDelay_1765GqpX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kQ3csu7c_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1765GqpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1765GqpX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BzHATfAk, 0, m, &cIf_BzHATfAk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mU45eGbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1765GqpX, 0, m, &cDelay_1765GqpX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kQ3csu7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1765GqpX, 0, m, &cDelay_1765GqpX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FBrrLcmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UFBQ65zZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XRAbI4T3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q1lh5kWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kzxg4RZP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qJQgBMgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qJQgBMgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FD9Q6nCI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kzxg4RZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BzHATfAk, 1, m, &cIf_BzHATfAk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XRAbI4T3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5imHBnKW, 0, m, &cIf_5imHBnKW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UFBQ65zZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5imHBnKW, 1, m, &cIf_5imHBnKW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xhuNmRvb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N6FxBB9Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6WZgEKgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N6FxBB9Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_d46MQwm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_n8aTHFPS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_21Ol0d45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pPnyvEkm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_synERxry_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_06ah6WBi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_06ah6WBi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vdOmVxoz, 1, m, &cDelay_vdOmVxoz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yOBST2BG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vdOmVxoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vdOmVxoz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_d46MQwm9, 0, m, &cIf_d46MQwm9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_06ah6WBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vdOmVxoz, 0, m, &cDelay_vdOmVxoz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yOBST2BG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vdOmVxoz, 0, m, &cDelay_vdOmVxoz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MXboWg5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OM4RvIPi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cwZttq1T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GXaFCyEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_629qkRVh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7CbzCZ38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7CbzCZ38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_synERxry_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_629qkRVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d46MQwm9, 1, m, &cIf_d46MQwm9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OM4RvIPi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_21Ol0d45, 1, m, &cIf_21Ol0d45_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cwZttq1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_21Ol0d45, 0, m, &cIf_21Ol0d45_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pPnyvEkm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AzoM4Awg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_n8aTHFPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AzoM4Awg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ihCBaS1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MLDaopH3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_nTRgZSJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1NtRWXtN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ihvxVSVA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Vs5oQjQP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Vs5oQjQP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YYOBXyGu, 1, m, &cDelay_YYOBXyGu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r8hhexXS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YYOBXyGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YYOBXyGu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ihCBaS1T, 0, m, &cIf_ihCBaS1T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vs5oQjQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YYOBXyGu, 0, m, &cDelay_YYOBXyGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r8hhexXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YYOBXyGu, 0, m, &cDelay_YYOBXyGu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u08GTvGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LDibhwXH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tsLVEAd9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XAXF8A5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PZpXjHPx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZBM1OuBz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZBM1OuBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ihvxVSVA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_PZpXjHPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ihCBaS1T, 1, m, &cIf_ihCBaS1T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tsLVEAd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nTRgZSJX, 0, m, &cIf_nTRgZSJX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LDibhwXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nTRgZSJX, 1, m, &cIf_nTRgZSJX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1NtRWXtN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WZTu2RSn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MLDaopH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WZTu2RSn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_t1iDZxCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yk5AXF5X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ppIyWcs3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jCPKcUhD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vINTUZD2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BvUmxCzw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BvUmxCzw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_SMIv4PgW, 1, m, &cDelay_SMIv4PgW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iIvhyC8a_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_SMIv4PgW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_SMIv4PgW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_t1iDZxCl, 0, m, &cIf_t1iDZxCl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BvUmxCzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_SMIv4PgW, 0, m, &cDelay_SMIv4PgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iIvhyC8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_SMIv4PgW, 0, m, &cDelay_SMIv4PgW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gnqlrMIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AklMOMHN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DNRJYEZR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_18nHzEPy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_J4BC9Z0t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TDBO2OtL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TDBO2OtL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vINTUZD2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_J4BC9Z0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_t1iDZxCl, 1, m, &cIf_t1iDZxCl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DNRJYEZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ppIyWcs3, 0, m, &cIf_ppIyWcs3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AklMOMHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ppIyWcs3, 1, m, &cIf_ppIyWcs3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jCPKcUhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BczxQmEy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yk5AXF5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BczxQmEy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Dj6W86c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_AwAZaHGo_sendMessage(_c, 0, m);
  cMsg_ahecNgld_sendMessage(_c, 0, m);
  cMsg_wad2S263_sendMessage(_c, 0, m);
  cMsg_ngsVzuRA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4vhb27zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_AwAZaHGo_sendMessage(_c, 0, m);
  cMsg_dmr6M4nQ_sendMessage(_c, 0, m);
  cMsg_3aRIK7su_sendMessage(_c, 0, m);
  cMsg_VuijQQgA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VswDn9og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_pWgyh2Ss_sendMessage(_c, 0, m);
  cMsg_dmr6M4nQ_sendMessage(_c, 0, m);
  cMsg_ngsVzuRA_sendMessage(_c, 0, m);
  cMsg_FOxxYyzU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GIcsjXBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_pWgyh2Ss_sendMessage(_c, 0, m);
  cMsg_ezKC73X8_sendMessage(_c, 0, m);
  cMsg_wad2S263_sendMessage(_c, 0, m);
  cMsg_OnM5lLsz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aHIOUtqE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_hllPVLHw_sendMessage(_c, 0, m);
  cMsg_VuijQQgA_sendMessage(_c, 0, m);
  cMsg_94aKxgOh_sendMessage(_c, 0, m);
  cMsg_wad2S263_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_McHlO1Bl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_hllPVLHw_sendMessage(_c, 0, m);
  cMsg_OnM5lLsz_sendMessage(_c, 0, m);
  cMsg_dmr6M4nQ_sendMessage(_c, 0, m);
  cMsg_p5BvUvL1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pLJtXWNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iV3kCyT6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pP74PlUG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IQVkIZxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iV3kCyT6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pP74PlUG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ssUavsGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DV7RGBfi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JGaT1o91_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_liqOiv1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DV7RGBfi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JGaT1o91_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ptgeGP3S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oghWsrjx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QrTxv47a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QJQ72W5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_oghWsrjx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QrTxv47a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AwAZaHGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_pLJtXWNq_sendMessage(_c, 0, m);
  cMsg_liqOiv1D_sendMessage(_c, 0, m);
  cMsg_QJQ72W5e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pWgyh2Ss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_IQVkIZxR_sendMessage(_c, 0, m);
  cMsg_ssUavsGG_sendMessage(_c, 0, m);
  cMsg_QJQ72W5e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hllPVLHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_IQVkIZxR_sendMessage(_c, 0, m);
  cMsg_liqOiv1D_sendMessage(_c, 0, m);
  cMsg_ptgeGP3S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MJTc3PQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O2hvUsGs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1vbbviwx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GBLabFot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_O2hvUsGs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1vbbviwx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M1KBT0bf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UTYbrynI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8Jb1WG4M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K8rizyid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UTYbrynI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8Jb1WG4M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cOsKdoQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_57Z04UWH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1PR3EKjw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yo8msF2Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_57Z04UWH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1PR3EKjw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dmr6M4nQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_GBLabFot_sendMessage(_c, 0, m);
  cMsg_K8rizyid_sendMessage(_c, 0, m);
  cMsg_yo8msF2Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ahecNgld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_GBLabFot_sendMessage(_c, 0, m);
  cMsg_M1KBT0bf_sendMessage(_c, 0, m);
  cMsg_cOsKdoQU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ezKC73X8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_MJTc3PQ2_sendMessage(_c, 0, m);
  cMsg_K8rizyid_sendMessage(_c, 0, m);
  cMsg_cOsKdoQU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_56jfQggM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GXaFCyEx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MXboWg5U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kZRO9oOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GXaFCyEx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MXboWg5U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2yZGOydF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XAXF8A5I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u08GTvGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YcV5VDNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XAXF8A5I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u08GTvGS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jubRRFni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_18nHzEPy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gnqlrMIw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_STIeK0CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_18nHzEPy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gnqlrMIw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OnM5lLsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_56jfQggM_sendMessage(_c, 0, m);
  cMsg_YcV5VDNS_sendMessage(_c, 0, m);
  cMsg_STIeK0CX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VuijQQgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_kZRO9oOC_sendMessage(_c, 0, m);
  cMsg_2yZGOydF_sendMessage(_c, 0, m);
  cMsg_STIeK0CX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ngsVzuRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_kZRO9oOC_sendMessage(_c, 0, m);
  cMsg_YcV5VDNS_sendMessage(_c, 0, m);
  cMsg_jubRRFni_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Mnpt3ViC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_f5gdQT8p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_prVTiT1X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GBclrHrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_f5gdQT8p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_prVTiT1X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Eo8npj5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VZ8Nbyfk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QNOrpdRV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8aq97V7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VZ8Nbyfk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QNOrpdRV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1B1vYCox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_q1lh5kWx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FBrrLcmq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_po2vaUle_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_q1lh5kWx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_FBrrLcmq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wad2S263_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_GBclrHrd_sendMessage(_c, 0, m);
  cMsg_8aq97V7p_sendMessage(_c, 0, m);
  cMsg_po2vaUle_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3aRIK7su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_GBclrHrd_sendMessage(_c, 0, m);
  cMsg_Eo8npj5Y_sendMessage(_c, 0, m);
  cMsg_1B1vYCox_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p5BvUvL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Mnpt3ViC_sendMessage(_c, 0, m);
  cMsg_Eo8npj5Y_sendMessage(_c, 0, m);
  cMsg_po2vaUle_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_94aKxgOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_MJTc3PQ2_sendMessage(_c, 0, m);
  cMsg_M1KBT0bf_sendMessage(_c, 0, m);
  cMsg_yo8msF2Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FOxxYyzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Mnpt3ViC_sendMessage(_c, 0, m);
  cMsg_8aq97V7p_sendMessage(_c, 0, m);
  cMsg_1B1vYCox_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hHScpxpH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9pFwI8nn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GwZm2hSd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_B4J1VOOt, 0, m, &cSlice_B4J1VOOt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_x9S7Snb0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_B4J1VOOt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HLcH739A_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HLcH739A_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_rIvGLzZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HLcH739A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HLcH739A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nSl8pbi7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VrDXfVVM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jCnkPcPT, 0, m, &cSlice_jCnkPcPT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_yjweGg0u_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_jCnkPcPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NhVPn1xF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NhVPn1xF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_48U1IPvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NhVPn1xF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NhVPn1xF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vXwFT9CL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yjweGg0u_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ftZyTJMc, 0, m, &cSlice_ftZyTJMc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_GwZm2hSd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ftZyTJMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XBjjH5SS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XBjjH5SS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_RvIsNlho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XBjjH5SS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XBjjH5SS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ebs5Tv8C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_x9S7Snb0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_X4vAF0Ol, 0, m, &cSlice_X4vAF0Ol_sendMessage);
      break;
    }
    default: {
      cSwitchcase_AAzEyfRK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_X4vAF0Ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yLSbMSRC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yLSbMSRC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_lYhfEjTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yLSbMSRC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yLSbMSRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XAgP5bex_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AAzEyfRK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_j77G3Y23, 0, m, &cSlice_j77G3Y23_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mRb9i2Xc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_j77G3Y23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PvIkXHu1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PvIkXHu1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Egmh9Lpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PvIkXHu1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_PvIkXHu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_loVKCh43_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UwANliIY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CcpLzMyD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CcpLzMyD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OCdOPhql, 1, m, &cDelay_OCdOPhql_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SeqDoBQQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OCdOPhql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OCdOPhql, m);
  cMsg_wBvivlse_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CcpLzMyD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OCdOPhql, 0, m, &cDelay_OCdOPhql_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SeqDoBQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OCdOPhql, 0, m, &cDelay_OCdOPhql_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_u8wCF9Zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_duPRIQW8, HV_BINOP_SUBTRACT, 0, m, &cBinop_duPRIQW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_rDer0hQu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_c1r1PwnT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HUkkRbFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_c1r1PwnT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_CEZfNXph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u8wCF9Zr, 0, m, &cVar_u8wCF9Zr_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_esMIjQMD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VNliPjKU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OGTesjv5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pyIbjwBo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_duPRIQW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LqIvt9pO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LqIvt9pO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yaNBWAtM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yaNBWAtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lEwxcxC8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kMEagXoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P0KC0gMW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XKbGrwI6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_P0KC0gMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rDer0hQu, 1, m, &cIf_rDer0hQu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XKbGrwI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eVgufRFC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2Dq5Hsd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HUkkRbFB, 1, m, &cIf_HUkkRbFB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eVgufRFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_rDer0hQu, 0, m, &cIf_rDer0hQu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lEwxcxC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HUkkRbFB, 0, m, &cIf_HUkkRbFB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VNliPjKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_pyIbjwBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_u8wCF9Zr, 0, m, &cVar_u8wCF9Zr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OGTesjv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_duPRIQW8, HV_BINOP_SUBTRACT, 1, m, &cBinop_duPRIQW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c1r1PwnT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vunoRvLd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mRb9i2Xc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uU2prGey, 0, m, &cSlice_uU2prGey_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_uU2prGey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rwc9tDuo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rwc9tDuo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Gd9H39Ob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rwc9tDuo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rwc9tDuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tXf7qvH8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_r64aUSNq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4sVTRl64, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xxkCvgsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WcSrq6Qo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_XYIBsIk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fOt8modM, 0, m, &cVar_fOt8modM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9pFwI8nn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YrO2vMUg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_i5dHdtch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WTfSN8OT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GOusd91H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UwANliIY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wBvivlse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Iupblza6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WTfSN8OT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Iupblza6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bYjlwAD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_vNqU56Co_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vNqU56Co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ky0EENDC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ky0EENDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3hWV6JTz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_ZX9Wv4MV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mhjLflmh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_A5wjfCZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LdCI810x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_gYNkXc1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bj3b7vsc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_oskUz3BR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Zwa3zjBP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_uVUKfnUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AqM8Kvn9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0JYD7tiy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CnRYNiGy_sendMessage);
  cMsg_eibpRtvj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CnRYNiGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0JYD7tiy, 1, m, &cVar_0JYD7tiy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m0fyB4Lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ts77w7fI_sendMessage(_c, 0, m);
  cMsg_c2wVNaFE_sendMessage(_c, 0, m);
  cMsg_2wZ8u2n9_sendMessage(_c, 0, m);
  cMsg_FBx0euOC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GM8ZOKQA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6W79JXnV, 0, m, &cSlice_6W79JXnV_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_6W79JXnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dcfcijz8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dcfcijz8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_xioJyzjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dcfcijz8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dcfcijz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eq01d5fz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_RvPFOLN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_x8Aw22HZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x8Aw22HZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_f5ysAlmq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f5ysAlmq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_RkykVczf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RkykVczf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FQgBK2AL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_L7xRWePv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FQgBK2AL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ecghTYcA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L7xRWePv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qmd6qjG0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ecghTYcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vdA7PTdZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Qmd6qjG0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5hqGAe60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5hqGAe60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8MkOkpaI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vdA7PTdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vsO1n7lL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8MkOkpaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mJW8VK5u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vsO1n7lL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Gm4CORVX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mJW8VK5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9wEtTPvR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_cYrB7Djs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PZCMhqx7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ptjNQ6Tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mdliTsX4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Fmy4M0wC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_27EJGQtT_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9vcx6Deo_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vohGdJOv_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_isPnpIz8_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CLW1F5HP_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OanBchNG_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_27EJGQtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7qb6kc3g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_9vcx6Deo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OrmgdMEj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_vohGdJOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wS8OCQeS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_isPnpIz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iIzOj55E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_CLW1F5HP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7oE3bJC6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_OanBchNG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NBFXYSZg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_OgcR0xWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0FT7isQb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0ZO13K8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_l503Mb9p_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OWuHA62m_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TTd5uOHN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TTd5uOHN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_zLcP0nvz, 1, m, &cDelay_zLcP0nvz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LQRIoN9L_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_zLcP0nvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_zLcP0nvz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OgcR0xWX, 0, m, &cIf_OgcR0xWX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TTd5uOHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_zLcP0nvz, 0, m, &cDelay_zLcP0nvz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LQRIoN9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_zLcP0nvz, 0, m, &cDelay_zLcP0nvz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4dIeswhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_13iNpsAQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BVB5cxhp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vy5RZNUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v5D0ruOY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9yq6RlWx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v5D0ruOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OgcR0xWX, 1, m, &cIf_OgcR0xWX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9yq6RlWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OWuHA62m_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_13iNpsAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0ZO13K8N, 1, m, &cIf_0ZO13K8N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BVB5cxhp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0ZO13K8N, 0, m, &cIf_0ZO13K8N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l503Mb9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_okofCinN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0FT7isQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_okofCinN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_yjIJvUzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kzyMcDf1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AZqoqAvA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oURJM980_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zLHQOn0h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_S2popaG5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_S2popaG5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Y9R0JkxV, 1, m, &cDelay_Y9R0JkxV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E9hSU930_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Y9R0JkxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y9R0JkxV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_yjIJvUzM, 0, m, &cIf_yjIJvUzM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_S2popaG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y9R0JkxV, 0, m, &cDelay_Y9R0JkxV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E9hSU930_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y9R0JkxV, 0, m, &cDelay_Y9R0JkxV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_azPBVJqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wB5oZ3r9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UeP5PTzO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GgLPMNMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3FzqYoEI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jRhSzTGk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3FzqYoEI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yjIJvUzM, 1, m, &cIf_yjIJvUzM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jRhSzTGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zLHQOn0h_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_wB5oZ3r9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AZqoqAvA, 1, m, &cIf_AZqoqAvA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UeP5PTzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AZqoqAvA, 0, m, &cIf_AZqoqAvA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oURJM980_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NI487CUj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kzyMcDf1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NI487CUj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4mRCU1Rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Shnfz9Nz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Hhb1tRtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qiZqffQr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lJEPdIOt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TH2PqDm8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TH2PqDm8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_b5rQMY1u, 1, m, &cDelay_b5rQMY1u_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iUQlP0jp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_b5rQMY1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b5rQMY1u, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4mRCU1Rw, 0, m, &cIf_4mRCU1Rw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TH2PqDm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_b5rQMY1u, 0, m, &cDelay_b5rQMY1u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iUQlP0jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b5rQMY1u, 0, m, &cDelay_b5rQMY1u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xBOTSDzU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F2sW99dc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pazlUuD6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7GaVSqqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZgZSQ5Bg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zih2ma22_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zih2ma22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lJEPdIOt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZgZSQ5Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4mRCU1Rw, 1, m, &cIf_4mRCU1Rw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F2sW99dc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hhb1tRtU, 1, m, &cIf_Hhb1tRtU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pazlUuD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hhb1tRtU, 0, m, &cIf_Hhb1tRtU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qiZqffQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VEVOV61h, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Shnfz9Nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VEVOV61h, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mwjY1Kze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fiQiNfj0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FNf4LkC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5R3UhWDx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_k8iFuRl6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oF7UW2Ee_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oF7UW2Ee_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ag5fQWJ5, 1, m, &cDelay_ag5fQWJ5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gtbNTREh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ag5fQWJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ag5fQWJ5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mwjY1Kze, 0, m, &cIf_mwjY1Kze_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oF7UW2Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ag5fQWJ5, 0, m, &cDelay_ag5fQWJ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gtbNTREh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ag5fQWJ5, 0, m, &cDelay_ag5fQWJ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_roMsdNUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BbQUiFm7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TFfuBoXH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2spq3PjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Irz7kpc2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ghwznacq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ghwznacq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_k8iFuRl6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Irz7kpc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mwjY1Kze, 1, m, &cIf_mwjY1Kze_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TFfuBoXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FNf4LkC3, 0, m, &cIf_FNf4LkC3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BbQUiFm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FNf4LkC3, 1, m, &cIf_FNf4LkC3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5R3UhWDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8tkcxV3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fiQiNfj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q8tkcxV3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RW3TcrS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jN1Sjlci_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_P7RI5dkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5sBHVOuU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZRjDcgcl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AOLkfLnU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AOLkfLnU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MsNiBi34, 1, m, &cDelay_MsNiBi34_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JpsnqF4E_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MsNiBi34_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MsNiBi34, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RW3TcrS3, 0, m, &cIf_RW3TcrS3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AOLkfLnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MsNiBi34, 0, m, &cDelay_MsNiBi34_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JpsnqF4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MsNiBi34, 0, m, &cDelay_MsNiBi34_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cPma8qxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AM3ihGNT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MNZEKJCV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3MqVK5TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W2S9ge9A_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bDsYrmkx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W2S9ge9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RW3TcrS3, 1, m, &cIf_RW3TcrS3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bDsYrmkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ZRjDcgcl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AM3ihGNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P7RI5dkz, 1, m, &cIf_P7RI5dkz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MNZEKJCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P7RI5dkz, 0, m, &cIf_P7RI5dkz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5sBHVOuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M1p1ERqF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jN1Sjlci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M1p1ERqF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2nvRiqfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JoHi2Sm1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MRw0Fx75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8iX4eyZD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ECLOrHKw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gUnGQrER_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gUnGQrER_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0nlH3tWC, 1, m, &cDelay_0nlH3tWC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3eaD6wRX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0nlH3tWC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0nlH3tWC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2nvRiqfA, 0, m, &cIf_2nvRiqfA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gUnGQrER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0nlH3tWC, 0, m, &cDelay_0nlH3tWC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3eaD6wRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0nlH3tWC, 0, m, &cDelay_0nlH3tWC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2ditrCeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ETA1haQb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VJPJ7Obu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G5zlpLke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q31Qaw8e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MICTmuDc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q31Qaw8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2nvRiqfA, 1, m, &cIf_2nvRiqfA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MICTmuDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ECLOrHKw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ETA1haQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MRw0Fx75, 1, m, &cIf_MRw0Fx75_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VJPJ7Obu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MRw0Fx75, 0, m, &cIf_MRw0Fx75_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8iX4eyZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GAyXeG5q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JoHi2Sm1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GAyXeG5q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mHomiVh1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sFUWRBZN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9Sj2pNKL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ANrV3UAC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iD8Mrxc3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7dkVgx9w_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7dkVgx9w_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uXbfeJOS, 1, m, &cDelay_uXbfeJOS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KC3EhUjz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uXbfeJOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uXbfeJOS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mHomiVh1, 0, m, &cIf_mHomiVh1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7dkVgx9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uXbfeJOS, 0, m, &cDelay_uXbfeJOS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KC3EhUjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uXbfeJOS, 0, m, &cDelay_uXbfeJOS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4mSZJEMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q1I9QVSG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TXBhWOV6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V4qGE8Dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rwMWofeI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jA0x1yZ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jA0x1yZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iD8Mrxc3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rwMWofeI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mHomiVh1, 1, m, &cIf_mHomiVh1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q1I9QVSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9Sj2pNKL, 1, m, &cIf_9Sj2pNKL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TXBhWOV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9Sj2pNKL, 0, m, &cIf_9Sj2pNKL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ANrV3UAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UE3U3iA0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sFUWRBZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UE3U3iA0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0JwEF1lC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wrTGLLRs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dVxSGaj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZwYaEPV6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_c4UT3KWw_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hwsKKn2N_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hwsKKn2N_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0f9GsR4s, 1, m, &cDelay_0f9GsR4s_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jZYzcZJe_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0f9GsR4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0f9GsR4s, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0JwEF1lC, 0, m, &cIf_0JwEF1lC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hwsKKn2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0f9GsR4s, 0, m, &cDelay_0f9GsR4s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jZYzcZJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0f9GsR4s, 0, m, &cDelay_0f9GsR4s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_55W9Ay9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ALNGgtFr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4hmMDOwX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2tw3IPeO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Kd8gsKl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OttD92AC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OttD92AC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_c4UT3KWw_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9Kd8gsKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0JwEF1lC, 1, m, &cIf_0JwEF1lC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4hmMDOwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dVxSGaj1, 0, m, &cIf_dVxSGaj1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ALNGgtFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dVxSGaj1, 1, m, &cIf_dVxSGaj1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZwYaEPV6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DJ3H26CZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wrTGLLRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DJ3H26CZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3ETBWQQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Fw68ZRMF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EoX3c2Ah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_scXRfeM7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yutWqqAV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_GjkyokG2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_GjkyokG2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rTP6GvBl, 1, m, &cDelay_rTP6GvBl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e0bp5hl8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rTP6GvBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rTP6GvBl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3ETBWQQE, 0, m, &cIf_3ETBWQQE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GjkyokG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rTP6GvBl, 0, m, &cDelay_rTP6GvBl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_e0bp5hl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rTP6GvBl, 0, m, &cDelay_rTP6GvBl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Xb3PZXH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iXTS4ifj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fTEXi9wW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VYTxJkuK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v8EW6VyS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YKi4xfOM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YKi4xfOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_yutWqqAV_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_v8EW6VyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3ETBWQQE, 1, m, &cIf_3ETBWQQE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fTEXi9wW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EoX3c2Ah, 0, m, &cIf_EoX3c2Ah_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iXTS4ifj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EoX3c2Ah, 1, m, &cIf_EoX3c2Ah_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_scXRfeM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N3nljExq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Fw68ZRMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N3nljExq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9DcQ37h8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8Sekmk51_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BvGLd2Yn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1PDSNVTM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_L3QPS84K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KEp6J7YK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KEp6J7YK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uF5hn9Bm, 1, m, &cDelay_uF5hn9Bm_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wlySPtxV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uF5hn9Bm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uF5hn9Bm, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9DcQ37h8, 0, m, &cIf_9DcQ37h8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KEp6J7YK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uF5hn9Bm, 0, m, &cDelay_uF5hn9Bm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wlySPtxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uF5hn9Bm, 0, m, &cDelay_uF5hn9Bm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wTRuw4d9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oogUcmBx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DaAZeHqQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IM07QcPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3TuICnrg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JIiAKomY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JIiAKomY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_L3QPS84K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3TuICnrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9DcQ37h8, 1, m, &cIf_9DcQ37h8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DaAZeHqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BvGLd2Yn, 0, m, &cIf_BvGLd2Yn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oogUcmBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BvGLd2Yn, 1, m, &cIf_BvGLd2Yn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1PDSNVTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NDvAocVa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8Sekmk51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NDvAocVa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ImDll9J0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VsoqUVDL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_aZpcyXJg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z7AHHeCU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_utK8vLWb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TvssHhpY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TvssHhpY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gJbc8nye, 1, m, &cDelay_gJbc8nye_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1R8x8oPg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gJbc8nye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gJbc8nye, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ImDll9J0, 0, m, &cIf_ImDll9J0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TvssHhpY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gJbc8nye, 0, m, &cDelay_gJbc8nye_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1R8x8oPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gJbc8nye, 0, m, &cDelay_gJbc8nye_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nLdKigWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ZIC2Skr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ya34xQYb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qf5nhT0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EDrFAwx5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vz48eX6B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vz48eX6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_utK8vLWb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EDrFAwx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ImDll9J0, 1, m, &cIf_ImDll9J0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ya34xQYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aZpcyXJg, 0, m, &cIf_aZpcyXJg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2ZIC2Skr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aZpcyXJg, 1, m, &cIf_aZpcyXJg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z7AHHeCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XgqXX4Wf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VsoqUVDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XgqXX4Wf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mSdQQt0Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1w1j0XHl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hA4d1law_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZCOYuniS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AymalfrA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qIRUvP5V_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qIRUvP5V_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5aFfu2LM, 1, m, &cDelay_5aFfu2LM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OfNmSnVS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5aFfu2LM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5aFfu2LM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mSdQQt0Z, 0, m, &cIf_mSdQQt0Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qIRUvP5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5aFfu2LM, 0, m, &cDelay_5aFfu2LM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OfNmSnVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5aFfu2LM, 0, m, &cDelay_5aFfu2LM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_23jpzAoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XHaxaFNz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5PWhxCBW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kvq8PEkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bug0m2Vk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aP2zx8Pq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aP2zx8Pq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AymalfrA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Bug0m2Vk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mSdQQt0Z, 1, m, &cIf_mSdQQt0Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5PWhxCBW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hA4d1law, 0, m, &cIf_hA4d1law_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XHaxaFNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hA4d1law, 1, m, &cIf_hA4d1law_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZCOYuniS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mB8qETZb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1w1j0XHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mB8qETZb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7qb6kc3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_UsJWDHaH_sendMessage(_c, 0, m);
  cMsg_hgVDNVJn_sendMessage(_c, 0, m);
  cMsg_R2G0ZEUB_sendMessage(_c, 0, m);
  cMsg_0q46K3jx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OrmgdMEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_UsJWDHaH_sendMessage(_c, 0, m);
  cMsg_wwbyhfGM_sendMessage(_c, 0, m);
  cMsg_O6ZQmpWR_sendMessage(_c, 0, m);
  cMsg_9LWPcLy2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wS8OCQeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_QIP14L2I_sendMessage(_c, 0, m);
  cMsg_wwbyhfGM_sendMessage(_c, 0, m);
  cMsg_0q46K3jx_sendMessage(_c, 0, m);
  cMsg_RRNzdasz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iIzOj55E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_QIP14L2I_sendMessage(_c, 0, m);
  cMsg_jcQtNU2V_sendMessage(_c, 0, m);
  cMsg_R2G0ZEUB_sendMessage(_c, 0, m);
  cMsg_o8lMnKE0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7oE3bJC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_YtJZFwKF_sendMessage(_c, 0, m);
  cMsg_9LWPcLy2_sendMessage(_c, 0, m);
  cMsg_PWHh759x_sendMessage(_c, 0, m);
  cMsg_R2G0ZEUB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NBFXYSZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_YtJZFwKF_sendMessage(_c, 0, m);
  cMsg_o8lMnKE0_sendMessage(_c, 0, m);
  cMsg_wwbyhfGM_sendMessage(_c, 0, m);
  cMsg_rDweEXAT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lYT8Vpko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vy5RZNUm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4dIeswhI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zwh4JqIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Vy5RZNUm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4dIeswhI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KfZiGijW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GgLPMNMp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_azPBVJqK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SsqpV6JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GgLPMNMp_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_azPBVJqK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xpbfhNbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7GaVSqqW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xBOTSDzU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Uo3i5Q7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7GaVSqqW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xBOTSDzU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UsJWDHaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_lYT8Vpko_sendMessage(_c, 0, m);
  cMsg_SsqpV6JY_sendMessage(_c, 0, m);
  cMsg_Uo3i5Q7F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QIP14L2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_zwh4JqIh_sendMessage(_c, 0, m);
  cMsg_KfZiGijW_sendMessage(_c, 0, m);
  cMsg_Uo3i5Q7F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YtJZFwKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_zwh4JqIh_sendMessage(_c, 0, m);
  cMsg_SsqpV6JY_sendMessage(_c, 0, m);
  cMsg_xpbfhNbI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3J6dxqyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2spq3PjV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_roMsdNUX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oKopwAok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2spq3PjV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_roMsdNUX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qDViDMnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3MqVK5TS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cPma8qxn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5WBQizsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3MqVK5TS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cPma8qxn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oRYiCjq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G5zlpLke_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2ditrCeI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lKJXO0RR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G5zlpLke_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2ditrCeI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wwbyhfGM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_oKopwAok_sendMessage(_c, 0, m);
  cMsg_5WBQizsy_sendMessage(_c, 0, m);
  cMsg_lKJXO0RR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hgVDNVJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_oKopwAok_sendMessage(_c, 0, m);
  cMsg_qDViDMnB_sendMessage(_c, 0, m);
  cMsg_oRYiCjq6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jcQtNU2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_3J6dxqyA_sendMessage(_c, 0, m);
  cMsg_5WBQizsy_sendMessage(_c, 0, m);
  cMsg_oRYiCjq6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_frJedWpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IM07QcPN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wTRuw4d9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fvl5twd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_IM07QcPN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wTRuw4d9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_50yGdrdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qf5nhT0r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nLdKigWW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LBtrreit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qf5nhT0r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nLdKigWW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uA666aFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kvq8PEkL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_23jpzAoJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0m86oUSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kvq8PEkL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_23jpzAoJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o8lMnKE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_frJedWpT_sendMessage(_c, 0, m);
  cMsg_LBtrreit_sendMessage(_c, 0, m);
  cMsg_0m86oUSR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9LWPcLy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_fvl5twd8_sendMessage(_c, 0, m);
  cMsg_50yGdrdi_sendMessage(_c, 0, m);
  cMsg_0m86oUSR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0q46K3jx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_fvl5twd8_sendMessage(_c, 0, m);
  cMsg_LBtrreit_sendMessage(_c, 0, m);
  cMsg_uA666aFG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RKkxV0kC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V4qGE8Dj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4mSZJEMt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PuYS7Qet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V4qGE8Dj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4mSZJEMt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ucWLcvjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2tw3IPeO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_55W9Ay9h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KGH7TUdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2tw3IPeO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_55W9Ay9h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wLoOBF8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VYTxJkuK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Xb3PZXH6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DyuSAbSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_VYTxJkuK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Xb3PZXH6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R2G0ZEUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_PuYS7Qet_sendMessage(_c, 0, m);
  cMsg_KGH7TUdp_sendMessage(_c, 0, m);
  cMsg_DyuSAbSb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_O6ZQmpWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_PuYS7Qet_sendMessage(_c, 0, m);
  cMsg_ucWLcvjY_sendMessage(_c, 0, m);
  cMsg_wLoOBF8y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rDweEXAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_RKkxV0kC_sendMessage(_c, 0, m);
  cMsg_ucWLcvjY_sendMessage(_c, 0, m);
  cMsg_DyuSAbSb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PWHh759x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_3J6dxqyA_sendMessage(_c, 0, m);
  cMsg_qDViDMnB_sendMessage(_c, 0, m);
  cMsg_lKJXO0RR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RRNzdasz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_RKkxV0kC_sendMessage(_c, 0, m);
  cMsg_KGH7TUdp_sendMessage(_c, 0, m);
  cMsg_wLoOBF8y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hvD66egp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HKQpvdXN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pb2qaLHb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_y20qKm5Q, 0, m, &cSlice_y20qKm5Q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_v1ZvOFOD_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_y20qKm5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kaGRWRPc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kaGRWRPc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_esMFhHkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kaGRWRPc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_kaGRWRPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lRkGrv7S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JsnYlQSI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BVZLTVr3, 0, m, &cSlice_BVZLTVr3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IYoNlLL1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_BVZLTVr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_23bI2PeS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_23bI2PeS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_l03E5NFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_23bI2PeS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_23bI2PeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_65E3XGrF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IYoNlLL1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_N1dUBT6f, 0, m, &cSlice_N1dUBT6f_sendMessage);
      break;
    }
    default: {
      cSwitchcase_pb2qaLHb_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_N1dUBT6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ECMaRth9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ECMaRth9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_elQrobAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ECMaRth9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ECMaRth9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HHgEpOb5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_v1ZvOFOD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cBgLRigu, 0, m, &cSlice_cBgLRigu_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YGpX6Z2y_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_cBgLRigu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KCr3JRgk_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KCr3JRgk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_k4UvNNfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KCr3JRgk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KCr3JRgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NeBwzRFY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YGpX6Z2y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_a4yWsZSj, 0, m, &cSlice_a4yWsZSj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_CxY9da8f_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_a4yWsZSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_w98XA9L9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_w98XA9L9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3rFsWThy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w98XA9L9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_w98XA9L9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Az1Z813o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eG4CcQ1p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_daYoqsAJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_daYoqsAJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gfkKhcl1, 1, m, &cDelay_gfkKhcl1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xKT80P5B_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gfkKhcl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gfkKhcl1, m);
  cMsg_pmGNkXhC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_daYoqsAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gfkKhcl1, 0, m, &cDelay_gfkKhcl1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xKT80P5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gfkKhcl1, 0, m, &cDelay_gfkKhcl1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_kN6PYeKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U5OyVyLv, HV_BINOP_SUBTRACT, 0, m, &cBinop_U5OyVyLv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_b3Tr2nBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aoeLbx3P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WViZEuTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aoeLbx3P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_VbOeiTi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kN6PYeKN, 0, m, &cVar_kN6PYeKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_yqSKFNh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P55UXqGj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rzuo1eRR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BkLEgueY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U5OyVyLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kBRq5raK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kBRq5raK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bunhPs7p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bunhPs7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_l1ESXELI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PKPCiqcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5FdOGezW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pdAwmJnf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pdAwmJnf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cASTRmc2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_5FdOGezW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b3Tr2nBp, 1, m, &cIf_b3Tr2nBp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6T5AxvYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WViZEuTG, 1, m, &cIf_WViZEuTG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cASTRmc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_b3Tr2nBp, 0, m, &cIf_b3Tr2nBp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l1ESXELI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WViZEuTG, 0, m, &cIf_WViZEuTG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rzuo1eRR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U5OyVyLv, HV_BINOP_SUBTRACT, 1, m, &cBinop_U5OyVyLv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_P55UXqGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_BkLEgueY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kN6PYeKN, 0, m, &cVar_kN6PYeKN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aoeLbx3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tNHjsHDC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CxY9da8f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WZHU89Az, 0, m, &cSlice_WZHU89Az_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_WZHU89Az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yAeNgLbw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yAeNgLbw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_bKRJLI8W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yAeNgLbw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yAeNgLbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sgDqyKCI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PZCMhqx7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ygvUtOtg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mdliTsX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bU1QlgXQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_mnnx2MGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ptjNQ6Tq, 0, m, &cVar_ptjNQ6Tq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HKQpvdXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h5P3utxo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cEjqzPeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_eG4CcQ1p_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SACyemOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bWDdpuK9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pmGNkXhC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xVLPHzC3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bWDdpuK9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xVLPHzC3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DF9mscSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Bzcqfh8a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bzcqfh8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MznV1Yn2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MznV1Yn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MihoIFMK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_ziv4TCOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zXsJ37wP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_d0nL95km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9vYY6d8o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vwSkkcSj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DaizjQv6_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CYX8o6qB_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cB9JCG71_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bdkNK5Zf_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aS6qXW1H_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kymzVRd4_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_DaizjQv6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0u6YEU2G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_CYX8o6qB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dUpocC4d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_cB9JCG71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z6gf41vS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bdkNK5Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fKUfTaJj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_aS6qXW1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tOfiBhQN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_kymzVRd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2hQ6Xkgy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_fsWELQVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ERbuYvQ2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_i95SjX4J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1LPScDMr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_r0P4XZ88_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MZOX2opP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MZOX2opP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0sJKAH2l, 1, m, &cDelay_0sJKAH2l_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QWwzoVQj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0sJKAH2l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0sJKAH2l, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fsWELQVM, 0, m, &cIf_fsWELQVM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MZOX2opP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0sJKAH2l, 0, m, &cDelay_0sJKAH2l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QWwzoVQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0sJKAH2l, 0, m, &cDelay_0sJKAH2l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3taxhTYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bQu9HkcL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q5HeyPvs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZkzspTCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JspWi30r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UYcSL2NG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UYcSL2NG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_r0P4XZ88_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JspWi30r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fsWELQVM, 1, m, &cIf_fsWELQVM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q5HeyPvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i95SjX4J, 0, m, &cIf_i95SjX4J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bQu9HkcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i95SjX4J, 1, m, &cIf_i95SjX4J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1LPScDMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B4iM2IRL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ERbuYvQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_B4iM2IRL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5iI7lBGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zcCISeSQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1a7mLjvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4wwahCGN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_N9VJWQFP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AeJNe9r5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AeJNe9r5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Y1CbydSc, 1, m, &cDelay_Y1CbydSc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_meg4X1xc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Y1CbydSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y1CbydSc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5iI7lBGQ, 0, m, &cIf_5iI7lBGQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AeJNe9r5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y1CbydSc, 0, m, &cDelay_Y1CbydSc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_meg4X1xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y1CbydSc, 0, m, &cDelay_Y1CbydSc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DEtRDE2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MTd8SV9c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JPSbV1vG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sDLs04Mr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xhbxdLLb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E5wMHRo2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xhbxdLLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5iI7lBGQ, 1, m, &cIf_5iI7lBGQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E5wMHRo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_N9VJWQFP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JPSbV1vG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1a7mLjvD, 0, m, &cIf_1a7mLjvD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MTd8SV9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1a7mLjvD, 1, m, &cIf_1a7mLjvD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4wwahCGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FIoLLwn3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zcCISeSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FIoLLwn3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SzQVb3nc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lejT1qZt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_kuRPpUKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JbIclsZq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_I32l11lD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nvxCzQyg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nvxCzQyg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oQG7lRUA, 1, m, &cDelay_oQG7lRUA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BUe6V4TR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oQG7lRUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oQG7lRUA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SzQVb3nc, 0, m, &cIf_SzQVb3nc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nvxCzQyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oQG7lRUA, 0, m, &cDelay_oQG7lRUA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BUe6V4TR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oQG7lRUA, 0, m, &cDelay_oQG7lRUA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gVl23WXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9XlHCrCw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zvycelah_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RxZcZNPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eZzu9xap_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ehu9zNTJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eZzu9xap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SzQVb3nc, 1, m, &cIf_SzQVb3nc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ehu9zNTJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_I32l11lD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zvycelah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kuRPpUKM, 0, m, &cIf_kuRPpUKM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9XlHCrCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kuRPpUKM, 1, m, &cIf_kuRPpUKM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JbIclsZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t9OU5TQP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lejT1qZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t9OU5TQP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_DDiZfLfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FyFi0ZIb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_PcyBNWOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JrOOoGjo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Nir0BjQX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uAETXTkA_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uAETXTkA_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4aSvqN0Y, 1, m, &cDelay_4aSvqN0Y_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GhVnQQze_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4aSvqN0Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4aSvqN0Y, m);
  cIf_onMessage(_c, &Context(_c)->cIf_DDiZfLfD, 0, m, &cIf_DDiZfLfD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uAETXTkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4aSvqN0Y, 0, m, &cDelay_4aSvqN0Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GhVnQQze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4aSvqN0Y, 0, m, &cDelay_4aSvqN0Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mZMd3lVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Kfu96iKj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xud6DLNs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_h68RKRsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Axa09SSp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZpsdqYyc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZpsdqYyc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Nir0BjQX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Axa09SSp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DDiZfLfD, 1, m, &cIf_DDiZfLfD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xud6DLNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PcyBNWOo, 0, m, &cIf_PcyBNWOo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Kfu96iKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PcyBNWOo, 1, m, &cIf_PcyBNWOo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JrOOoGjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jq63n30X, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FyFi0ZIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jq63n30X, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_M3O2afSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BbvSCenc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_W3m1VkFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eHvONmUB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SdpPAQk4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ejVDzSqG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ejVDzSqG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Y9BdBT7A, 1, m, &cDelay_Y9BdBT7A_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_57LWoK1O_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Y9BdBT7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Y9BdBT7A, m);
  cIf_onMessage(_c, &Context(_c)->cIf_M3O2afSr, 0, m, &cIf_M3O2afSr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ejVDzSqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y9BdBT7A, 0, m, &cDelay_Y9BdBT7A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_57LWoK1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Y9BdBT7A, 0, m, &cDelay_Y9BdBT7A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R6rPHu87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZbTcbtNE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ymbEU5qH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_G7knovsF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I9RluLb6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4lmL3LA7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4lmL3LA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SdpPAQk4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_I9RluLb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M3O2afSr, 1, m, &cIf_M3O2afSr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ymbEU5qH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W3m1VkFF, 0, m, &cIf_W3m1VkFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZbTcbtNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W3m1VkFF, 1, m, &cIf_W3m1VkFF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eHvONmUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XVxykLJp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BbvSCenc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XVxykLJp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_V4VzFz5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WXhaNvrM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MdwjivAK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nPaLCu7S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_x8dxiaCN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ND2VwEI6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ND2VwEI6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1S41F4pg, 1, m, &cDelay_1S41F4pg_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_295jLHxv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1S41F4pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1S41F4pg, m);
  cIf_onMessage(_c, &Context(_c)->cIf_V4VzFz5l, 0, m, &cIf_V4VzFz5l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ND2VwEI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1S41F4pg, 0, m, &cDelay_1S41F4pg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_295jLHxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1S41F4pg, 0, m, &cDelay_1S41F4pg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9iIyGUPD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WN8vsf4X_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_doLXrnHx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3b5dbf5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fEhfWBc7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rRmfTbwa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fEhfWBc7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V4VzFz5l, 1, m, &cIf_V4VzFz5l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rRmfTbwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_x8dxiaCN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_doLXrnHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MdwjivAK, 0, m, &cIf_MdwjivAK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WN8vsf4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MdwjivAK, 1, m, &cIf_MdwjivAK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nPaLCu7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sbI24bLm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WXhaNvrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sbI24bLm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_YPnK61nS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VMFe0Hbn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vArZgK2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IrSOKomx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3RMiVo5R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OQ8iCrWa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OQ8iCrWa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Bd1NwBJW, 1, m, &cDelay_Bd1NwBJW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JodtNsab_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Bd1NwBJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Bd1NwBJW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YPnK61nS, 0, m, &cIf_YPnK61nS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OQ8iCrWa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bd1NwBJW, 0, m, &cDelay_Bd1NwBJW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JodtNsab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bd1NwBJW, 0, m, &cDelay_Bd1NwBJW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tjzrdThT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_emnEEeGI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9Ib2qRww_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ovhVzOGh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lKwzTZ8E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xJtvf2HX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lKwzTZ8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YPnK61nS, 1, m, &cIf_YPnK61nS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xJtvf2HX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3RMiVo5R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_emnEEeGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vArZgK2C, 1, m, &cIf_vArZgK2C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9Ib2qRww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vArZgK2C, 0, m, &cIf_vArZgK2C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IrSOKomx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_32HOGny0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VMFe0Hbn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_32HOGny0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_n8q5SITd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VQitVMML_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_K4ugri5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rn5Zt1EF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CDokGOoy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_45EQVmBH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_45EQVmBH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ny7LNx9L, 1, m, &cDelay_ny7LNx9L_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pS4hmM6z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ny7LNx9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ny7LNx9L, m);
  cIf_onMessage(_c, &Context(_c)->cIf_n8q5SITd, 0, m, &cIf_n8q5SITd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_45EQVmBH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ny7LNx9L, 0, m, &cDelay_ny7LNx9L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pS4hmM6z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ny7LNx9L, 0, m, &cDelay_ny7LNx9L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gxUufFze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nkgfDePu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9EbZRZb8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lirHLM7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BEweN6XK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9DvmNTO9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BEweN6XK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n8q5SITd, 1, m, &cIf_n8q5SITd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9DvmNTO9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CDokGOoy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_nkgfDePu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4ugri5t, 1, m, &cIf_K4ugri5t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9EbZRZb8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K4ugri5t, 0, m, &cIf_K4ugri5t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rn5Zt1EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d3vRVI26, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VQitVMML_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d3vRVI26, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sD0xcbCy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gLvVH9iD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oheanOqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0JAY72QK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fmqupyPt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_B1DmKAFC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_B1DmKAFC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DcE4QbZP, 1, m, &cDelay_DcE4QbZP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rIOq7lzJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_DcE4QbZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DcE4QbZP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sD0xcbCy, 0, m, &cIf_sD0xcbCy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_B1DmKAFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DcE4QbZP, 0, m, &cDelay_DcE4QbZP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rIOq7lzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DcE4QbZP, 0, m, &cDelay_DcE4QbZP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_seoT6lSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hBuF1Xrz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_twUlBvex_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6Di2ZR00_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rOfyV4oq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1upYRpRM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1upYRpRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fmqupyPt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rOfyV4oq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sD0xcbCy, 1, m, &cIf_sD0xcbCy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hBuF1Xrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oheanOqr, 1, m, &cIf_oheanOqr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_twUlBvex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oheanOqr, 0, m, &cIf_oheanOqr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0JAY72QK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X5aH9IJ0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gLvVH9iD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_X5aH9IJ0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aYwZOvbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g4d91c71_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JFJ1geJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PxHb3Bbm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3peEwipP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_n797N7m7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_n797N7m7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xhljCyzY, 1, m, &cDelay_xhljCyzY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cp8Hkzvh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xhljCyzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xhljCyzY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aYwZOvbe, 0, m, &cIf_aYwZOvbe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n797N7m7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xhljCyzY, 0, m, &cDelay_xhljCyzY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cp8Hkzvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xhljCyzY, 0, m, &cDelay_xhljCyzY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_K7Cwm6Vn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2J1MVAnb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VmcqdfQI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qT6QDhBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cRf4kUGZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pV2D3zc5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pV2D3zc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3peEwipP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cRf4kUGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aYwZOvbe, 1, m, &cIf_aYwZOvbe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VmcqdfQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JFJ1geJN, 0, m, &cIf_JFJ1geJN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2J1MVAnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JFJ1geJN, 1, m, &cIf_JFJ1geJN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PxHb3Bbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h5IzSJuH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g4d91c71_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h5IzSJuH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_v8V6MjcD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_wAZmUMb2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ITVdBsIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uRzQ9SPT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nElEQsU4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qXG4PziV_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qXG4PziV_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nppsJd9h, 1, m, &cDelay_nppsJd9h_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ffJ4VVdj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nppsJd9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nppsJd9h, m);
  cIf_onMessage(_c, &Context(_c)->cIf_v8V6MjcD, 0, m, &cIf_v8V6MjcD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qXG4PziV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nppsJd9h, 0, m, &cDelay_nppsJd9h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ffJ4VVdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nppsJd9h, 0, m, &cDelay_nppsJd9h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PGgLjnQc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RsffVFNc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iu8i2NNP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GLYjaiPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4Uak2ToY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IBiSN0B1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4Uak2ToY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v8V6MjcD, 1, m, &cIf_v8V6MjcD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IBiSN0B1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nElEQsU4_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RsffVFNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ITVdBsIa, 1, m, &cIf_ITVdBsIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iu8i2NNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ITVdBsIa, 0, m, &cIf_ITVdBsIa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uRzQ9SPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a1zP4T8k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wAZmUMb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_a1zP4T8k, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2gAolVg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WQX0slyw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EUG2GJzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WPYXlTfd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_V5l8Ri5b_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_uYtgxsPS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_uYtgxsPS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_w8YFZfc1, 1, m, &cDelay_w8YFZfc1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YtnkXxOj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_w8YFZfc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_w8YFZfc1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2gAolVg1, 0, m, &cIf_2gAolVg1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uYtgxsPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_w8YFZfc1, 0, m, &cDelay_w8YFZfc1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YtnkXxOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_w8YFZfc1, 0, m, &cDelay_w8YFZfc1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zi7Gp83D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x4Ye09mt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jn4A4Dar_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4HiY5mSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GLYI4Wct_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X3LcAsCz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GLYI4Wct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2gAolVg1, 1, m, &cIf_2gAolVg1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X3LcAsCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_V5l8Ri5b_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_x4Ye09mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EUG2GJzX, 1, m, &cIf_EUG2GJzX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jn4A4Dar_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EUG2GJzX, 0, m, &cIf_EUG2GJzX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WPYXlTfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7Y9NzMRE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WQX0slyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7Y9NzMRE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0u6YEU2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_0uFsknwC_sendMessage(_c, 0, m);
  cMsg_mjmapW21_sendMessage(_c, 0, m);
  cMsg_UlmGcCxx_sendMessage(_c, 0, m);
  cMsg_j0zm8xs0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dUpocC4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_0uFsknwC_sendMessage(_c, 0, m);
  cMsg_mzrTKocN_sendMessage(_c, 0, m);
  cMsg_GFGcnTtD_sendMessage(_c, 0, m);
  cMsg_TjvMG6WE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_z6gf41vS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_k4hSc1Zx_sendMessage(_c, 0, m);
  cMsg_mzrTKocN_sendMessage(_c, 0, m);
  cMsg_j0zm8xs0_sendMessage(_c, 0, m);
  cMsg_7a9oZuTd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fKUfTaJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_k4hSc1Zx_sendMessage(_c, 0, m);
  cMsg_DrAJc5BS_sendMessage(_c, 0, m);
  cMsg_UlmGcCxx_sendMessage(_c, 0, m);
  cMsg_SuFWmbgg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tOfiBhQN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_shPqUYxy_sendMessage(_c, 0, m);
  cMsg_TjvMG6WE_sendMessage(_c, 0, m);
  cMsg_q8ExF25e_sendMessage(_c, 0, m);
  cMsg_UlmGcCxx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2hQ6Xkgy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_shPqUYxy_sendMessage(_c, 0, m);
  cMsg_SuFWmbgg_sendMessage(_c, 0, m);
  cMsg_mzrTKocN_sendMessage(_c, 0, m);
  cMsg_BNJrqeN9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rZYpJhiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZkzspTCA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3taxhTYL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GJWvPW5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZkzspTCA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3taxhTYL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IVpNwX2o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sDLs04Mr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DEtRDE2T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z5B6QZEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sDLs04Mr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DEtRDE2T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z92z4fup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RxZcZNPD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gVl23WXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_y9Itfcq9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RxZcZNPD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gVl23WXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0uFsknwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_rZYpJhiF_sendMessage(_c, 0, m);
  cMsg_z5B6QZEg_sendMessage(_c, 0, m);
  cMsg_y9Itfcq9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_k4hSc1Zx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_GJWvPW5I_sendMessage(_c, 0, m);
  cMsg_IVpNwX2o_sendMessage(_c, 0, m);
  cMsg_y9Itfcq9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_shPqUYxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_GJWvPW5I_sendMessage(_c, 0, m);
  cMsg_z5B6QZEg_sendMessage(_c, 0, m);
  cMsg_z92z4fup_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uRrdiZbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_h68RKRsb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mZMd3lVK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WYVqPVAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_h68RKRsb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mZMd3lVK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ibif9cck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G7knovsF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R6rPHu87_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rVwO4P4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_G7knovsF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R6rPHu87_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UeqkCTZI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3b5dbf5n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9iIyGUPD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YARNhRQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3b5dbf5n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9iIyGUPD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mzrTKocN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_WYVqPVAv_sendMessage(_c, 0, m);
  cMsg_rVwO4P4K_sendMessage(_c, 0, m);
  cMsg_YARNhRQH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mjmapW21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_WYVqPVAv_sendMessage(_c, 0, m);
  cMsg_ibif9cck_sendMessage(_c, 0, m);
  cMsg_UeqkCTZI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DrAJc5BS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_uRrdiZbk_sendMessage(_c, 0, m);
  cMsg_rVwO4P4K_sendMessage(_c, 0, m);
  cMsg_UeqkCTZI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nOuKmTOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qT6QDhBZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_K7Cwm6Vn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RLpwjX9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qT6QDhBZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_K7Cwm6Vn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0Hw8nSFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GLYjaiPu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PGgLjnQc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0vnEHqqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GLYjaiPu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PGgLjnQc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mxblxj5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4HiY5mSl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Zi7Gp83D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ASRUeJBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4HiY5mSl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Zi7Gp83D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SuFWmbgg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_nOuKmTOO_sendMessage(_c, 0, m);
  cMsg_0vnEHqqS_sendMessage(_c, 0, m);
  cMsg_ASRUeJBA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TjvMG6WE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_RLpwjX9V_sendMessage(_c, 0, m);
  cMsg_0Hw8nSFA_sendMessage(_c, 0, m);
  cMsg_ASRUeJBA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_j0zm8xs0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_RLpwjX9V_sendMessage(_c, 0, m);
  cMsg_0vnEHqqS_sendMessage(_c, 0, m);
  cMsg_mxblxj5P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GoDJsCue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ovhVzOGh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tjzrdThT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_B7LUTv6f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ovhVzOGh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tjzrdThT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kDXQMWg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lirHLM7w_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gxUufFze_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mykgzM67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lirHLM7w_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gxUufFze_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3ExVP0Zt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6Di2ZR00_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_seoT6lSR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UECcyvKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6Di2ZR00_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_seoT6lSR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UlmGcCxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_B7LUTv6f_sendMessage(_c, 0, m);
  cMsg_mykgzM67_sendMessage(_c, 0, m);
  cMsg_UECcyvKm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GFGcnTtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_B7LUTv6f_sendMessage(_c, 0, m);
  cMsg_kDXQMWg5_sendMessage(_c, 0, m);
  cMsg_3ExVP0Zt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BNJrqeN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_GoDJsCue_sendMessage(_c, 0, m);
  cMsg_kDXQMWg5_sendMessage(_c, 0, m);
  cMsg_UECcyvKm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_q8ExF25e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_uRrdiZbk_sendMessage(_c, 0, m);
  cMsg_ibif9cck_sendMessage(_c, 0, m);
  cMsg_YARNhRQH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7a9oZuTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_GoDJsCue_sendMessage(_c, 0, m);
  cMsg_mykgzM67_sendMessage(_c, 0, m);
  cMsg_3ExVP0Zt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_VjpPQ4tC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8XIKLeoA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SArIWO9e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kFTDXIk8, 0, m, &cSlice_kFTDXIk8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_dx57PcXS_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_kFTDXIk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QfBiKYwf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QfBiKYwf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_mvTtlBvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QfBiKYwf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_QfBiKYwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R3goB1eP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mZOZPSB0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Hri8LROb, 0, m, &cSlice_Hri8LROb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Nbp2ZBH3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Hri8LROb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Uqir3IoJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Uqir3IoJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_F2Y7HQcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Uqir3IoJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Uqir3IoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QzSDW1Ch_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Nbp2ZBH3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_p1XlZIRs, 0, m, &cSlice_p1XlZIRs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_SArIWO9e_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_p1XlZIRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_qMFVZjdn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_qMFVZjdn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_FZB0ZcyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qMFVZjdn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_qMFVZjdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_itCH8w6K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_dx57PcXS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Fublmqw5, 0, m, &cSlice_Fublmqw5_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3jrBwBcI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Fublmqw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5yH2CMnM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5yH2CMnM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_EHvukwr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5yH2CMnM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5yH2CMnM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rIJM5ZMH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3jrBwBcI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QtIoCRRp, 0, m, &cSlice_QtIoCRRp_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6FpVUuxn_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_QtIoCRRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hYhqzGj4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hYhqzGj4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_aBaYNcqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hYhqzGj4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hYhqzGj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jUIFJC4d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5cj1wa9d_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cmTBXgZD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cmTBXgZD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hdMNj3cw, 1, m, &cDelay_hdMNj3cw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jxuSYbAa_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hdMNj3cw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hdMNj3cw, m);
  cMsg_0fpTUjwl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cmTBXgZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hdMNj3cw, 0, m, &cDelay_hdMNj3cw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jxuSYbAa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hdMNj3cw, 0, m, &cDelay_hdMNj3cw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_CTNK4np4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EFPgFzbQ, HV_BINOP_SUBTRACT, 0, m, &cBinop_EFPgFzbQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_SLnefy9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Qd45HGNa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Z3Yew3A4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Qd45HGNa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_0oW4pH8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CTNK4np4, 0, m, &cVar_CTNK4np4_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_LZhyhGt6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sokzCRyi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4S6uY0pN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pcnraZFa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EFPgFzbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tBhFH3mM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_tBhFH3mM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vT2490Tu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vT2490Tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_xHVIyRbo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Lod9VWPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JG3UZQ9t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WWw566wZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WWw566wZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pRU7mrWv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JG3UZQ9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SLnefy9F, 1, m, &cIf_SLnefy9F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9f6WYNcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z3Yew3A4, 1, m, &cIf_Z3Yew3A4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pRU7mrWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_SLnefy9F, 0, m, &cIf_SLnefy9F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xHVIyRbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z3Yew3A4, 0, m, &cIf_Z3Yew3A4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4S6uY0pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EFPgFzbQ, HV_BINOP_SUBTRACT, 1, m, &cBinop_EFPgFzbQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sokzCRyi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_pcnraZFa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CTNK4np4, 0, m, &cVar_CTNK4np4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Qd45HGNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H3B7m8a5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6FpVUuxn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PeZbOSGe, 0, m, &cSlice_PeZbOSGe_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_PeZbOSGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oaupmLAN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oaupmLAN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_V2ZpxfWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oaupmLAN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_oaupmLAN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zQef4QhO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zXsJ37wP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XQfxtmDL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9vYY6d8o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2NkPVBct, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_YZ6cWG4W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d0nL95km, 0, m, &cVar_d0nL95km_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8XIKLeoA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YAghyYIJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BolzWekt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5cj1wa9d_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_w8yaFtpb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gJHni3d7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0fpTUjwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kimRrmJL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gJHni3d7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kimRrmJL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_z9Mdd3bT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_8hF3DmZw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8hF3DmZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iGVvrJ4O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iGVvrJ4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SXDfr4sB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_JHogYyi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bjvXDe4v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_76U8aiaE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KoTOTu52_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_J3EUOL4D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2hu8u56f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vsIPu6R6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EbcIXOsP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q8rzfF7o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tAcNmxUs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_O88oDTIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EbcIXOsP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q8rzfF7o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tAcNmxUs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_wDyK6gql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oNPkBVmv, 0, m, &cVar_oNPkBVmv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_laBpC56H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EbcIXOsP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q8rzfF7o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tAcNmxUs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5pp04Fpn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EbcIXOsP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q8rzfF7o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tAcNmxUs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jyvx32lx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EbcIXOsP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q8rzfF7o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tAcNmxUs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lPPCpfsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_iEO1H9NN, 0, m, &cVar_iEO1H9NN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pVsBevlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_p8BgECbH, 0, m, &cVar_p8BgECbH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9SwTRX1z, 0, m, &cVar_9SwTRX1z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0gntx3dC, 0, m, &cVar_0gntx3dC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YTxe5TsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wDyK6gql_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AxtYVOtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_K17MS296_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fyipu96C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_46QnCIbm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_K17MS296_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fyipu96C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vWE7IDw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_K17MS296_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fyipu96C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jK7GLV2V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_K17MS296_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fyipu96C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2KOaBRms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_K17MS296_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fyipu96C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_a0DCATJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_LQlB7YD5, 0, m, &cVar_LQlB7YD5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0jk5eLf0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_pcH1SsGi, 0, m, &cVar_pcH1SsGi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7l0QiPRK, 0, m, &cVar_7l0QiPRK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VHhf3vvh, 0, m, &cVar_VHhf3vvh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_klLqTZdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EbcIXOsP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q8rzfF7o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tAcNmxUs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Urx4CI6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SlIa71ak_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3Ov4pMpV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VrDXfVVM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FlxLAEJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SlIa71ak_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3Ov4pMpV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VrDXfVVM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_bijHNcYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DWaNM7nr, 0, m, &cVar_DWaNM7nr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WoKxMsbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SlIa71ak_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3Ov4pMpV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VrDXfVVM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aqneh2ID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SlIa71ak_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3Ov4pMpV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VrDXfVVM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qal9rl05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SlIa71ak_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3Ov4pMpV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VrDXfVVM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LUCEp5cW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Sdo3lpDM, 0, m, &cVar_Sdo3lpDM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HHfGJ1AK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_BIDTOkDp, 0, m, &cVar_BIDTOkDp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Df8NG4jh, 0, m, &cVar_Df8NG4jh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9bPzjpAS, 0, m, &cVar_9bPzjpAS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rUCy8EF5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_bijHNcYn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j4p9ROIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SlIa71ak_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3Ov4pMpV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VrDXfVVM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mhjLflmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GM8ZOKQA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_JsnYlQSI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mZOZPSB0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Zwa3zjBP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GM8ZOKQA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_JsnYlQSI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mZOZPSB0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_BEVzLhit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A5wjfCZV, 0, m, &cVar_A5wjfCZV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bj3b7vsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GM8ZOKQA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_JsnYlQSI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mZOZPSB0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AqM8Kvn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GM8ZOKQA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_JsnYlQSI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mZOZPSB0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eibpRtvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GM8ZOKQA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_JsnYlQSI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mZOZPSB0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ts77w7fI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_oskUz3BR, 0, m, &cVar_oskUz3BR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c2wVNaFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_gYNkXc1B, 0, m, &cVar_gYNkXc1B_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uVUKfnUT, 0, m, &cVar_uVUKfnUT_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0JYD7tiy, 0, m, &cVar_0JYD7tiy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2wZ8u2n9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_BEVzLhit_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LdCI810x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GM8ZOKQA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_JsnYlQSI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mZOZPSB0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3BRb2IlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_JHogYyi2, 0, m, &cVar_JHogYyi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bjvXDe4v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_EbcIXOsP_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_q8rzfF7o_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_tAcNmxUs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iZGhYBcM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_76U8aiaE, 0, m, &cVar_76U8aiaE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KoTOTu52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_SlIa71ak_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_3Ov4pMpV_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_VrDXfVVM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FBx0euOC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_J3EUOL4D, 0, m, &cVar_J3EUOL4D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2hu8u56f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_GM8ZOKQA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_JsnYlQSI_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_mZOZPSB0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_hmtNb6SG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cI2zMJTt_sendMessage(_c, 0, m);
  cMsg_gsWmG7zR_sendMessage(_c, 0, m);
  cMsg_mY2Rgig8_sendMessage(_c, 0, m);
  cMsg_jI8u7rUR_sendMessage(_c, 0, m);
  cMsg_3Syyj08p_sendMessage(_c, 0, m);
  cMsg_SawlCcQ5_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_82KHGqLn, 0, m, &cVar_82KHGqLn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VfC27wtP, 0, m, &cVar_VfC27wtP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_j9129ntY, 0, m, &cVar_j9129ntY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HIYQ7wwk, 0, m, &cVar_HIYQ7wwk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pPN91ibx, 0, m, &cVar_pPN91ibx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_U1mdHZ0V, 0, m, &cVar_U1mdHZ0V_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_a8eASCcD, 0, m, &cVar_a8eASCcD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_t29uluZS, 0, m, &cVar_t29uluZS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ace5LrL2, 0, m, &cVar_Ace5LrL2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c2o5UWE1, 0, m, &cVar_c2o5UWE1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_k2f8fgNI, 0, m, &cVar_k2f8fgNI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_d8BMzwng, 0, m, &cVar_d8BMzwng_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IxhQXAy1, 0, m, &cVar_IxhQXAy1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_36Tm3B9Y, 0, m, &cVar_36Tm3B9Y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_T9k6fkkJ, 0, m, &cVar_T9k6fkkJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7VUUI9HL, 0, m, &cVar_7VUUI9HL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_deZkYkCa, 0, m, &cVar_deZkYkCa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Yd5Pb2s4, 0, m, &cVar_Yd5Pb2s4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5j6OuAA8, 0, m, &cVar_5j6OuAA8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XJGG8aYv, 0, m, &cVar_XJGG8aYv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Wgmp88QU, 0, m, &cVar_Wgmp88QU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lwS99WFm, 0, m, &cVar_lwS99WFm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_28gt6RSI, 0, m, &cVar_28gt6RSI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bRilKh5J, 0, m, &cVar_bRilKh5J_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dnhbZgDr, 0, m, &cVar_dnhbZgDr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cm0FqbEe, 0, m, &cVar_cm0FqbEe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HIxdO1aO, 0, m, &cVar_HIxdO1aO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QravkE1l, 0, m, &cVar_QravkE1l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dS4N0SbW, 0, m, &cVar_dS4N0SbW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xCaSPl2j, 0, m, &cVar_xCaSPl2j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jYrPM3Dj, 0, m, &cVar_jYrPM3Dj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_byBSdWrA, 0, m, &cVar_byBSdWrA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4HE3UrFm, 0, m, &cVar_4HE3UrFm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ELBmc68E, 0, m, &cVar_ELBmc68E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Fy8ab7Nx, 0, m, &cVar_Fy8ab7Nx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RuMTqrAU, 0, m, &cVar_RuMTqrAU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Knxxtkzz, 0, m, &cVar_Knxxtkzz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7oueZOyc, 0, m, &cVar_7oueZOyc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_t0PBCmDi, 0, m, &cVar_t0PBCmDi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3yk4dewA, 0, m, &cVar_3yk4dewA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rIvGLzZp, 0, m, &cVar_rIvGLzZp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_48U1IPvw, 0, m, &cVar_48U1IPvw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RvIsNlho, 0, m, &cVar_RvIsNlho_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lYhfEjTh, 0, m, &cVar_lYhfEjTh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Egmh9Lpf, 0, m, &cVar_Egmh9Lpf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Gd9H39Ob, 0, m, &cVar_Gd9H39Ob_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_esMFhHkZ, 0, m, &cVar_esMFhHkZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_l03E5NFn, 0, m, &cVar_l03E5NFn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_elQrobAs, 0, m, &cVar_elQrobAs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_k4UvNNfc, 0, m, &cVar_k4UvNNfc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3rFsWThy, 0, m, &cVar_3rFsWThy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bKRJLI8W, 0, m, &cVar_bKRJLI8W_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mvTtlBvk, 0, m, &cVar_mvTtlBvk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F2Y7HQcM, 0, m, &cVar_F2Y7HQcM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FZB0ZcyI, 0, m, &cVar_FZB0ZcyI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EHvukwr3, 0, m, &cVar_EHvukwr3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aBaYNcqe, 0, m, &cVar_aBaYNcqe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_V2ZpxfWM, 0, m, &cVar_V2ZpxfWM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bkg3uMst, 0, m, &cVar_bkg3uMst_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_znBPjYnm, 0, m, &cVar_znBPjYnm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xioJyzjb, 0, m, &cVar_xioJyzjb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ql8uIEuy_sendMessage);
  cMsg_0jk5eLf0_sendMessage(_c, 0, m);
  cMsg_a0DCATJ2_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V6QyDWyC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m0fyB4Lk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qeBgpYjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pcH1SsGi, 0, m, &cVar_pcH1SsGi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Qr3zUSvB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7l0QiPRK, 0, m, &cVar_7l0QiPRK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bKBKOxHG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VHhf3vvh, 0, m, &cVar_VHhf3vvh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HsxE3R6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VfC27wtP, 0, m, &cVar_VfC27wtP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_8z6NW0pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wsez62SQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BnUJG2QP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cHODZiqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vs15caxe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FWqSHQha_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dtl0hveU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FJeMkpAv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cNecRfs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x0j1aiVj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TiqkMeGJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ICBtzlYP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K0WChgxp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_G7AZZJAE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gDnDeFRR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pp1AepTZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4heungkz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TXZ8CUzD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_37IrWNZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UZLVI2HV, HV_BINOP_MULTIPLY, 0, m, &cBinop_UZLVI2HV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AfsD5W05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_g5VmJGSE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_J0ZJJlto_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_I4SA0ZiY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ABmVkMJT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Gh8ACpZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LVM61JQ8_sendMessage);
  cMsg_YC5qPI3r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_ygTsrcEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mMN62HOb, HV_BINOP_MULTIPLY, 0, m, &cBinop_mMN62HOb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Smp9PkP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_LD0ab0zA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_l4B0dvUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L3dmGNMa, HV_BINOP_MULTIPLY, 1, m, &cBinop_L3dmGNMa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rO38frYE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JQ0qETqq_sendMessage);
  cMsg_Qhg3cswC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_48rDKiz1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fWW7dtve, HV_BINOP_MULTIPLY, 0, m, &cBinop_fWW7dtve_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eeHq7nRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NyfjKb0E_sendMessage(_c, 0, m);
  cMsg_JBBxGKTH_sendMessage(_c, 0, m);
  cMsg_vJ0ZjvL9_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_VE4Tc74n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_f82Pm7LD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4yWsiAPO_sendMessage);
  cMsg_WijLr83X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_SbQAbDdr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pPN91ibx, 0, m, &cVar_pPN91ibx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kuixHftH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cPwS4CfI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RUFP2r3G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4noZkWWw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I1JtdqOS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MyKx8ROj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_b6j9uty3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dwbdb8CS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YBATEbzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_goOFvyD5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_neJL5AAI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kEPklVyA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7yxbiHoQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GPsSGD2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KunLfVH1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t6Uy8GEg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IJm2piir_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dQEl1piB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XHaenwID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_01q0NN8p, HV_BINOP_MULTIPLY, 0, m, &cBinop_01q0NN8p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_y1matWRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_34AdfzCx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aNmCUIuY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AUYKsTjr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_bjymOs78_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nW0QQuVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eroYetly_sendMessage);
  cMsg_RtLhLc2b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_Cg7CnHei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lwKEZWaT, HV_BINOP_MULTIPLY, 0, m, &cBinop_lwKEZWaT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eWMaMjCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_VGr0hcjt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZRbk3UBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zLwVTZYS, HV_BINOP_MULTIPLY, 1, m, &cBinop_zLwVTZYS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wl58f7yt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_auXW9vGv_sendMessage);
  cMsg_GVacmN4m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_Oxk22QTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Qyr6E5K, HV_BINOP_MULTIPLY, 0, m, &cBinop_0Qyr6E5K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_czjXeeV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o54j6TRx_sendMessage(_c, 0, m);
  cMsg_tkHDn6UB_sendMessage(_c, 0, m);
  cMsg_GVzndg7u_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_w1s0iN2k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gXtewtfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ko8CU3zD_sendMessage);
  cMsg_cISjBaAK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_FqtxxQ2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LQlB7YD5, 0, m, &cVar_LQlB7YD5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sGvYf9Wt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Lgdc2NJm, 0, m, &cVar_Lgdc2NJm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FF68wK0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iEO1H9NN, 0, m, &cVar_iEO1H9NN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cxdHwCVK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_p8BgECbH, 0, m, &cVar_p8BgECbH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7OMe6F37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9SwTRX1z, 0, m, &cVar_9SwTRX1z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_TZlZEZjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0gntx3dC, 0, m, &cVar_0gntx3dC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aWY7La0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_wDyK6gql_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eRe6FGl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_LWVUjZ1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3sIuJVT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_egflv3T5, 0, m, &cVar_egflv3T5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hiJ3Y6L2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yIEV25Mi, 0, m, &cVar_yIEV25Mi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QmSFIOwO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_3lLibdOq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_17ddtp5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cdKgCLXX_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_37KCsRBC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EnI7UUGl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_n8yEkPHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tQJCclrz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pHFWbN8J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HUSobkk6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LbvaNpzb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_YCZT5bSZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lnyGf284, 0, m, &cVar_lnyGf284_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4DsqxIPX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lrBKp10r, 0, m, &cVar_lrBKp10r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gTH9AigY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_WbDjag2o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_T8350C9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8zfqxD0E_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WJCTv3Xq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gX5URXZI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MjSfk0li_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rsQQUdGj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_UztV2Sby_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_RnzXylPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1FCAFIrB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_grs6P37p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_0h4UBJ0h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uh6qG0Be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kAsO31UA, 0, m, &cVar_kAsO31UA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qOblx3YZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Df7FmTrw, 0, m, &cVar_Df7FmTrw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZCPKQpUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_k7kXq8EJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_1TurlE60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qwFgzyux_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gMxGZzK9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UPd3PMau_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KYciATec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_efxn6JHE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_b2lJLGT8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zEbLFWsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MDijuY6g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_nSl8pbi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gzn2XyHT, 0, m, &cVar_Gzn2XyHT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_XAgP5bex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hHScpxpH, 0, m, &cVar_hHScpxpH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ebs5Tv8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_XYIBsIk3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vXwFT9CL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jNONJAsL_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i5dHdtch_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GOusd91H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_loVKCh43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kMEagXoj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2Dq5Hsd4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_tXf7qvH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bYjlwAD5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_I37p7P2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_U65c1Fgq, 0, m, &cVar_U65c1Fgq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Nymg8WOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Sdo3lpDM, 0, m, &cVar_Sdo3lpDM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rmOHNeNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BIDTOkDp, 0, m, &cVar_BIDTOkDp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7Z8MLVRN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Df8NG4jh, 0, m, &cVar_Df8NG4jh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_IvYXFDxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9bPzjpAS, 0, m, &cVar_9bPzjpAS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Jq3MWhEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_bijHNcYn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eq01d5fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_RvPFOLN2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lRkGrv7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cYrB7Djs, 0, m, &cVar_cYrB7Djs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NeBwzRFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hvD66egp, 0, m, &cVar_hvD66egp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HHgEpOb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_mnnx2MGK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_65E3XGrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Fmy4M0wC_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SACyemOX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cEjqzPeH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Az1Z813o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PKPCiqcb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6T5AxvYN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_sgDqyKCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DF9mscSO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_R3goB1eP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ziv4TCOm, 0, m, &cVar_ziv4TCOm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_rIJM5ZMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VjpPQ4tC, 0, m, &cVar_VjpPQ4tC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_itCH8w6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_YZ6cWG4W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QzSDW1Ch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vwSkkcSj_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w8yaFtpb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BolzWekt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jUIFJC4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Lod9VWPz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9f6WYNcA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zQef4QhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z9Mdd3bT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_9AO3cKfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZX9Wv4MV, 0, m, &cVar_ZX9Wv4MV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_t9TFYvcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oskUz3BR, 0, m, &cVar_oskUz3BR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QIxboBLl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gYNkXc1B, 0, m, &cVar_gYNkXc1B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vBfp72iV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uVUKfnUT, 0, m, &cVar_uVUKfnUT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WkHT1t5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0JYD7tiy, 0, m, &cVar_0JYD7tiy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_TGatSi5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_BEVzLhit_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FO1bNkuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JHogYyi2, 0, m, &cVar_JHogYyi2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3sBPe6DG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_76U8aiaE, 0, m, &cVar_76U8aiaE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ofDkbl2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J3EUOL4D, 0, m, &cVar_J3EUOL4D_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_B8VpTAXp, VOf(Bf0));
    __hv_line_f(&sLine_hCVSJGeT, VOf(Bf1));
    __hv_line_f(&sLine_PcZhNQpm, VOf(Bf2));
    __hv_line_f(&sLine_YQLUaU4A, VOf(Bf3));
    __hv_line_f(&sLine_Pe5Mm6xx, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_FhRoeOxW, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_gN7AeNHa, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_xbtYZy74, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_aISBR6S0, VOf(Bf1));
    __hv_line_f(&sLine_Qni8NWXm, VOf(Bf0));
    __hv_line_f(&sLine_moxq9Go6, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_Zc3gRG0y, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_G9XBcEEA, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_h8iT86i4, VOf(Bf5));
    __hv_line_f(&sLine_a2TBZHJR, VOf(Bf1));
    __hv_line_f(&sLine_yxb3L2kN, VOf(Bf2));
    __hv_line_f(&sLine_KMsSoLr7, VOf(Bf4));
    __hv_line_f(&sLine_hu9bTXdi, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_9VGLwEnd, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_N7pSDOD1, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_J3sH5Juy, VOf(Bf6));
    __hv_line_f(&sLine_kjdN2qEs, VOf(Bf2));
    __hv_line_f(&sLine_y8wbx5fi, VOf(Bf1));
    __hv_line_f(&sLine_BjiQgERK, VOf(Bf5));
    __hv_line_f(&sLine_nlbunnz9, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_65QUhcil, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_DQ0jUcYo, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_uAIsNeSY, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_bQqdC1Jc, VOf(Bf2));
    __hv_line_f(&sLine_VwhbUyhD, VOf(Bf6));
    __hv_line_f(&sLine_DXBNUfbS, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_YHbQbGwc, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_BaJpR5jD, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_NlsXBH3D, VOf(Bf8));
    __hv_line_f(&sLine_IyM0qxL5, VOf(Bf2));
    __hv_line_f(&sLine_wehOwrvB, VOf(Bf1));
    __hv_line_f(&sLine_eG4f4WJG, VOf(Bf7));
    __hv_line_f(&sLine_wC0W9NnK, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_IHQldDvy, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_ZMpfhBwT, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_f19T5txh, VIf(Bf0));
    __hv_varwrite_f(&sVarf_KjFml1tN, VIf(Bf6));
    __hv_varwrite_f(&sVarf_2KpkWvp2, VIf(Bf4));
    __hv_varwrite_f(&sVarf_x16RsUrd, VIf(Bf7));
    __hv_varread_f(&sVarf_URFlykIs, VOf(Bf7));
    __hv_varread_f(&sVarf_aJgXMgLX, VOf(Bf4));
    __hv_varread_f(&sVarf_Oz54zCxp, VOf(Bf6));
    __hv_varread_f(&sVarf_l2RneahV, VOf(Bf0));
    __hv_varread_f(&sVarf_xJGWkDXq, VOf(Bf9));
    __hv_varread_f(&sVarf_301BvmGE, VOf(Bf1));
    __hv_line_f(&sLine_XLfSsUWi, VOf(Bf2));
    __hv_line_f(&sLine_as1au9Jp, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_Oz54zCxp, VIf(Bf7));
    __hv_varwrite_f(&sVarf_xJGWkDXq, VIf(Bf4));
    __hv_varread_f(&sVarf_Q8XVUF8L, VOf(Bf2));
    __hv_varread_f(&sVarf_yCtzL4d5, VOf(Bf9));
    __hv_varread_f(&sVarf_KZD5r2HZ, VOf(Bf1));
    __hv_varread_f(&sVarf_9HAsJHMK, VOf(Bf6));
    __hv_varread_f(&sVarf_kd6CgsgT, VOf(Bf10));
    __hv_varread_f(&sVarf_YFySq87M, VOf(Bf11));
    __hv_varread_f(&sVarf_KPHTtcg4, VOf(Bf12));
    __hv_varwrite_f(&sVarf_zlmHmdW0, VIf(Bf7));
    __hv_varread_f(&sVarf_fGZK0rZh, VOf(Bf13));
    __hv_line_f(&sLine_LlPnVQ15, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_07yYVCzh, VOf(Bf15));
    __hv_line_f(&sLine_5EgXFMls, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_o6xza5w8, VOf(Bf14));
    __hv_line_f(&sLine_tkI2i0YT, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_9HAsJHMK, VIf(Bf17));
    __hv_varread_f(&sVarf_zlmHmdW0, VOf(Bf17));
    __hv_line_f(&sLine_fnL2nUtH, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_H3iVh2tI, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_deU2Pzd3, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_kd6CgsgT, VIf(Bf16));
    __hv_line_f(&sLine_FjVRQLnx, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_RPFrYt74, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_uQEdBznj, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_YFySq87M, VIf(Bf16));
    __hv_line_f(&sLine_0mK7wafh, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_eoWW9Pce, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_jYFd0k10, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_KPHTtcg4, VIf(Bf16));
    __hv_varwrite_f(&sVarf_fGZK0rZh, VIf(Bf2));
    __hv_varwrite_f(&sVarf_07yYVCzh, VIf(Bf9));
    __hv_varwrite_f(&sVarf_o6xza5w8, VIf(Bf1));
    sEnv_process(this, &sEnv_0HmVfmcQ, VIf(Bf6), &sEnv_0HmVfmcQ_sendMessage);
    sEnv_process(this, &sEnv_PZ2KquSf, VIf(Bf7), &sEnv_PZ2KquSf_sendMessage);
    __hv_line_f(&sLine_kchRL7yo, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_UNz9KVcE, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_rfBuu1Up, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_0KY9QWJo, VOf(Bf6));
    __hv_line_f(&sLine_f8esvJwG, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_Q8XVUF8L, VIf(Bf9));
    __hv_varwrite_f(&sVarf_0KY9QWJo, VIf(Bf10));
    __hv_varwrite_f(&sVarf_u5CNuUPq, VIf(Bf11));
    __hv_varwrite_f(&sVarf_A3DfOGSg, VIf(Bf12));
    __hv_varread_f(&sVarf_A3DfOGSg, VOf(Bf12));
    __hv_line_f(&sLine_mzXzoS4N, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_KZD5r2HZ, VIf(Bf10));
    __hv_varread_f(&sVarf_u5CNuUPq, VOf(Bf10));
    __hv_line_f(&sLine_nUTIg0M4, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_yCtzL4d5, VIf(Bf10));
    __hv_varwrite_f(&sVarf_l2RneahV, VIf(Bf7));
    __hv_varread_f(&sVarf_p8NgpJiF, VOf(Bf7));
    __hv_varread_f(&sVarf_sx7uAh1p, VOf(Bf10));
    __hv_varread_f(&sVarf_8XwR9bVo, VOf(Bf9));
    __hv_varread_f(&sVarf_qKiMqxDi, VOf(Bf11));
    __hv_varread_f(&sVarf_dEkXqIwj, VOf(Bf6));
    __hv_varread_f(&sVarf_PI1T9EXF, VOf(Bf12));
    __hv_varread_f(&sVarf_dmugJmfW, VOf(Bf1));
    __hv_varwrite_f(&sVarf_nwz3einT, VIf(Bf4));
    __hv_varread_f(&sVarf_rZR4PDFP, VOf(Bf2));
    __hv_line_f(&sLine_Ja58qyH4, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_qy9KURN6, VOf(Bf17));
    __hv_line_f(&sLine_QI3Yokhg, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_B6Eh2GKu, VOf(Bf16));
    __hv_line_f(&sLine_Dsmpp6Kc, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_qKiMqxDi, VIf(Bf15));
    __hv_varread_f(&sVarf_nwz3einT, VOf(Bf15));
    __hv_line_f(&sLine_ooj8Okrn, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_d6JVGv2r, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_ZCZKqEF8, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_dEkXqIwj, VIf(Bf13));
    __hv_line_f(&sLine_8ubjhU6f, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_FFEzuyIQ, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_NB8pRGaw, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_PI1T9EXF, VIf(Bf13));
    __hv_line_f(&sLine_AUN6fHQx, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_d4J8SYe3, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_mzs1TARu, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_dmugJmfW, VIf(Bf13));
    __hv_varwrite_f(&sVarf_rZR4PDFP, VIf(Bf7));
    __hv_varwrite_f(&sVarf_qy9KURN6, VIf(Bf10));
    __hv_varwrite_f(&sVarf_B6Eh2GKu, VIf(Bf9));
    sEnv_process(this, &sEnv_CzX6y72S, VIf(Bf11), &sEnv_CzX6y72S_sendMessage);
    sEnv_process(this, &sEnv_0kOALBXK, VIf(Bf4), &sEnv_0kOALBXK_sendMessage);
    __hv_line_f(&sLine_hD9KjdUo, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_YNniUw2L, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_V56uGy6H, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_wk3ruqcA, VOf(Bf11));
    __hv_line_f(&sLine_i7nfuP3z, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_p8NgpJiF, VIf(Bf10));
    __hv_varwrite_f(&sVarf_wk3ruqcA, VIf(Bf6));
    __hv_varwrite_f(&sVarf_efcBuVB3, VIf(Bf12));
    __hv_varwrite_f(&sVarf_ytLlpGCD, VIf(Bf1));
    __hv_varread_f(&sVarf_ytLlpGCD, VOf(Bf1));
    __hv_line_f(&sLine_ZLcSS2Wj, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_8XwR9bVo, VIf(Bf6));
    __hv_varread_f(&sVarf_efcBuVB3, VOf(Bf6));
    __hv_line_f(&sLine_JDNuPB4P, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_sx7uAh1p, VIf(Bf6));
    __hv_varwrite_f(&sVarf_301BvmGE, VIf(Bf4));
    __hv_varwrite_f(&sVarf_IpRNBWVU, VIf(Bf0));
    __hv_varread_f(&sVarf_f19T5txh, VOf(Bf0));
    __hv_varread_f(&sVarf_KjFml1tN, VOf(Bf4));
    __hv_varread_f(&sVarf_boRTuumQ, VOf(Bf6));
    __hv_varread_f(&sVarf_yllOb11Z, VOf(Bf10));
    __hv_varread_f(&sVarf_LZRRZoeg, VOf(Bf12));
    __hv_varread_f(&sVarf_fN1VLAo0, VOf(Bf11));
    __hv_line_f(&sLine_26pryQYb, VOf(Bf1));
    __hv_line_f(&sLine_fiyrj77y, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_boRTuumQ, VIf(Bf0));
    __hv_varwrite_f(&sVarf_LZRRZoeg, VIf(Bf4));
    __hv_varread_f(&sVarf_YJBQCD2V, VOf(Bf1));
    __hv_varread_f(&sVarf_cmiLLLWe, VOf(Bf12));
    __hv_varread_f(&sVarf_QOEfrcVk, VOf(Bf11));
    __hv_varread_f(&sVarf_myooPsZ2, VOf(Bf6));
    __hv_varread_f(&sVarf_P7lutH8Y, VOf(Bf7));
    __hv_varread_f(&sVarf_wENodh5n, VOf(Bf13));
    __hv_varread_f(&sVarf_Eeg5HPsV, VOf(Bf15));
    __hv_varwrite_f(&sVarf_Rhqa2uE3, VIf(Bf0));
    __hv_varread_f(&sVarf_XzdS5UXi, VOf(Bf2));
    __hv_line_f(&sLine_r3onwTIM, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_Nx1dE2Iy, VOf(Bf18));
    __hv_line_f(&sLine_3HhGHDQ0, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_C7OLZwnh, VOf(Bf17));
    __hv_line_f(&sLine_PyfWhrOs, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_myooPsZ2, VIf(Bf14));
    __hv_varread_f(&sVarf_Rhqa2uE3, VOf(Bf14));
    __hv_line_f(&sLine_ELsFdM82, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_1n6euF3C, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_BYmYGjfl, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_P7lutH8Y, VIf(Bf16));
    __hv_line_f(&sLine_elVWOgD1, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_hKG3IoY3, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_ZFqLCQ1k, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_wENodh5n, VIf(Bf16));
    __hv_line_f(&sLine_WnPWJfst, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_SSjcjdAH, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_49vNVd5q, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Eeg5HPsV, VIf(Bf16));
    __hv_varwrite_f(&sVarf_XzdS5UXi, VIf(Bf1));
    __hv_varwrite_f(&sVarf_Nx1dE2Iy, VIf(Bf12));
    __hv_varwrite_f(&sVarf_C7OLZwnh, VIf(Bf11));
    sEnv_process(this, &sEnv_07jQv5oD, VIf(Bf6), &sEnv_07jQv5oD_sendMessage);
    sEnv_process(this, &sEnv_GzsIqgOg, VIf(Bf0), &sEnv_GzsIqgOg_sendMessage);
    __hv_line_f(&sLine_KmqYu8WU, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_7SVRN5Yo, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_I0R7Epxf, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_AyeqazWZ, VOf(Bf6));
    __hv_line_f(&sLine_ogSdFWuu, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_YJBQCD2V, VIf(Bf12));
    __hv_varwrite_f(&sVarf_AyeqazWZ, VIf(Bf7));
    __hv_varwrite_f(&sVarf_FjWm0Hby, VIf(Bf13));
    __hv_varwrite_f(&sVarf_MkpviS73, VIf(Bf15));
    __hv_varread_f(&sVarf_MkpviS73, VOf(Bf15));
    __hv_line_f(&sLine_dSBINeTO, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_QOEfrcVk, VIf(Bf7));
    __hv_varread_f(&sVarf_FjWm0Hby, VOf(Bf7));
    __hv_line_f(&sLine_XWNUIbpn, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_cmiLLLWe, VIf(Bf7));
    __hv_varwrite_f(&sVarf_yllOb11Z, VIf(Bf0));
    __hv_varread_f(&sVarf_JGofW8Qs, VOf(Bf0));
    __hv_varread_f(&sVarf_QNxZxfb2, VOf(Bf7));
    __hv_varread_f(&sVarf_7mGfusUl, VOf(Bf12));
    __hv_varread_f(&sVarf_jyllSyN4, VOf(Bf13));
    __hv_varread_f(&sVarf_qE3hOzfR, VOf(Bf6));
    __hv_varread_f(&sVarf_oktpr2VI, VOf(Bf15));
    __hv_varread_f(&sVarf_iylwZ1xl, VOf(Bf11));
    __hv_varwrite_f(&sVarf_RmkJYO76, VIf(Bf4));
    __hv_varread_f(&sVarf_nHlPE4pD, VOf(Bf1));
    __hv_line_f(&sLine_AzoM4Awg, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_GBnqKIgY, VOf(Bf14));
    __hv_line_f(&sLine_WZTu2RSn, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_ZFpV6TKb, VOf(Bf16));
    __hv_line_f(&sLine_BczxQmEy, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_jyllSyN4, VIf(Bf18));
    __hv_varread_f(&sVarf_RmkJYO76, VOf(Bf18));
    __hv_line_f(&sLine_iBJFuMKm, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_fip42Fud, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_d6kJBYbM, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_qE3hOzfR, VIf(Bf2));
    __hv_line_f(&sLine_FReKVDpm, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_fZNbvPTl, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_8nyuOLmi, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_oktpr2VI, VIf(Bf2));
    __hv_line_f(&sLine_xoXuKlgk, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_C8XQukgW, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_N6FxBB9Q, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_iylwZ1xl, VIf(Bf2));
    __hv_varwrite_f(&sVarf_nHlPE4pD, VIf(Bf0));
    __hv_varwrite_f(&sVarf_GBnqKIgY, VIf(Bf7));
    __hv_varwrite_f(&sVarf_ZFpV6TKb, VIf(Bf12));
    sEnv_process(this, &sEnv_CEZfNXph, VIf(Bf13), &sEnv_CEZfNXph_sendMessage);
    sEnv_process(this, &sEnv_esMIjQMD, VIf(Bf4), &sEnv_esMIjQMD_sendMessage);
    __hv_line_f(&sLine_vunoRvLd, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Iupblza6, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_3hWV6JTz, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_iJGAORtR, VOf(Bf13));
    __hv_line_f(&sLine_WcSrq6Qo, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_JGofW8Qs, VIf(Bf7));
    __hv_varwrite_f(&sVarf_iJGAORtR, VIf(Bf6));
    __hv_varwrite_f(&sVarf_dTd6nGt3, VIf(Bf15));
    __hv_varwrite_f(&sVarf_Yd32b5hZ, VIf(Bf11));
    __hv_varread_f(&sVarf_Yd32b5hZ, VOf(Bf11));
    __hv_line_f(&sLine_YrO2vMUg, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_7mGfusUl, VIf(Bf6));
    __hv_varread_f(&sVarf_dTd6nGt3, VOf(Bf6));
    __hv_line_f(&sLine_4sVTRl64, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_QNxZxfb2, VIf(Bf6));
    __hv_varwrite_f(&sVarf_fN1VLAo0, VIf(Bf4));
    __hv_varwrite_f(&sVarf_SaM7xH3r, VIf(Bf10));
    __hv_varread_f(&sVarf_2KpkWvp2, VOf(Bf10));
    __hv_varread_f(&sVarf_x16RsUrd, VOf(Bf4));
    __hv_varread_f(&sVarf_cWUxwiKw, VOf(Bf6));
    __hv_varread_f(&sVarf_DICPepow, VOf(Bf7));
    __hv_varread_f(&sVarf_gFEK1e2V, VOf(Bf15));
    __hv_varread_f(&sVarf_PVOSpCGO, VOf(Bf13));
    __hv_line_f(&sLine_9wEtTPvR, VOf(Bf11));
    __hv_line_f(&sLine_Gm4CORVX, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_cWUxwiKw, VIf(Bf10));
    __hv_varwrite_f(&sVarf_gFEK1e2V, VIf(Bf4));
    __hv_varread_f(&sVarf_QixrpCEQ, VOf(Bf11));
    __hv_varread_f(&sVarf_56YKbWiK, VOf(Bf15));
    __hv_varread_f(&sVarf_cMwdiEmN, VOf(Bf13));
    __hv_varread_f(&sVarf_cXT4ly8y, VOf(Bf6));
    __hv_varread_f(&sVarf_cxeavKNf, VOf(Bf0));
    __hv_varread_f(&sVarf_OFsQ6zBR, VOf(Bf2));
    __hv_varread_f(&sVarf_GDRMpUWh, VOf(Bf18));
    __hv_varwrite_f(&sVarf_a7RJ8pMI, VIf(Bf10));
    __hv_varread_f(&sVarf_T9iTm35d, VOf(Bf1));
    __hv_line_f(&sLine_NDvAocVa, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_jvlQIHoi, VOf(Bf19));
    __hv_line_f(&sLine_XgqXX4Wf, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_bcTh77DA, VOf(Bf14));
    __hv_line_f(&sLine_mB8qETZb, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_cXT4ly8y, VIf(Bf17));
    __hv_varread_f(&sVarf_a7RJ8pMI, VOf(Bf17));
    __hv_line_f(&sLine_okofCinN, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_q8tkcxV3, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_UE3U3iA0, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_cxeavKNf, VIf(Bf16));
    __hv_line_f(&sLine_NI487CUj, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_M1p1ERqF, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_DJ3H26CZ, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_OFsQ6zBR, VIf(Bf16));
    __hv_line_f(&sLine_VEVOV61h, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_GAyXeG5q, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_N3nljExq, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_GDRMpUWh, VIf(Bf16));
    __hv_varwrite_f(&sVarf_T9iTm35d, VIf(Bf11));
    __hv_varwrite_f(&sVarf_jvlQIHoi, VIf(Bf15));
    __hv_varwrite_f(&sVarf_bcTh77DA, VIf(Bf13));
    sEnv_process(this, &sEnv_VbOeiTi6, VIf(Bf6), &sEnv_VbOeiTi6_sendMessage);
    sEnv_process(this, &sEnv_yqSKFNh5, VIf(Bf10), &sEnv_yqSKFNh5_sendMessage);
    __hv_line_f(&sLine_tNHjsHDC, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_xVLPHzC3, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_MihoIFMK, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_utxZkkju, VOf(Bf6));
    __hv_line_f(&sLine_bU1QlgXQ, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_QixrpCEQ, VIf(Bf15));
    __hv_varwrite_f(&sVarf_utxZkkju, VIf(Bf0));
    __hv_varwrite_f(&sVarf_gvsYJlTK, VIf(Bf2));
    __hv_varwrite_f(&sVarf_r57eLSDZ, VIf(Bf18));
    __hv_varread_f(&sVarf_r57eLSDZ, VOf(Bf18));
    __hv_line_f(&sLine_h5P3utxo, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_cMwdiEmN, VIf(Bf0));
    __hv_varread_f(&sVarf_gvsYJlTK, VOf(Bf0));
    __hv_line_f(&sLine_ygvUtOtg, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_56YKbWiK, VIf(Bf0));
    __hv_varwrite_f(&sVarf_DICPepow, VIf(Bf10));
    __hv_varread_f(&sVarf_9vfhUxjv, VOf(Bf10));
    __hv_varread_f(&sVarf_gasrCciw, VOf(Bf0));
    __hv_varread_f(&sVarf_s7mlO3VF, VOf(Bf15));
    __hv_varread_f(&sVarf_YyEKNKGq, VOf(Bf2));
    __hv_varread_f(&sVarf_tY4vqW83, VOf(Bf6));
    __hv_varread_f(&sVarf_KY1cZi8a, VOf(Bf18));
    __hv_varread_f(&sVarf_ZwR86er3, VOf(Bf13));
    __hv_varwrite_f(&sVarf_JXxpcs1C, VIf(Bf4));
    __hv_varread_f(&sVarf_pu5XSZyb, VOf(Bf11));
    __hv_line_f(&sLine_h5IzSJuH, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_1Ea58nho, VOf(Bf17));
    __hv_line_f(&sLine_a1zP4T8k, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_rufkVpm4, VOf(Bf16));
    __hv_line_f(&sLine_7Y9NzMRE, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_YyEKNKGq, VIf(Bf19));
    __hv_varread_f(&sVarf_JXxpcs1C, VOf(Bf19));
    __hv_line_f(&sLine_B4iM2IRL, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_jq63n30X, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_32HOGny0, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_tY4vqW83, VIf(Bf1));
    __hv_line_f(&sLine_FIoLLwn3, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_XVxykLJp, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_d3vRVI26, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_KY1cZi8a, VIf(Bf1));
    __hv_line_f(&sLine_t9OU5TQP, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_sbI24bLm, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_X5aH9IJ0, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_ZwR86er3, VIf(Bf1));
    __hv_varwrite_f(&sVarf_pu5XSZyb, VIf(Bf10));
    __hv_varwrite_f(&sVarf_1Ea58nho, VIf(Bf0));
    __hv_varwrite_f(&sVarf_rufkVpm4, VIf(Bf15));
    sEnv_process(this, &sEnv_0oW4pH8d, VIf(Bf2), &sEnv_0oW4pH8d_sendMessage);
    sEnv_process(this, &sEnv_LZhyhGt6, VIf(Bf4), &sEnv_LZhyhGt6_sendMessage);
    __hv_line_f(&sLine_H3B7m8a5, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_kimRrmJL, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_SXDfr4sB, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_1ClGFzmH, VOf(Bf2));
    __hv_line_f(&sLine_2NkPVBct, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_9vfhUxjv, VIf(Bf0));
    __hv_varwrite_f(&sVarf_1ClGFzmH, VIf(Bf6));
    __hv_varwrite_f(&sVarf_p0qEee95, VIf(Bf18));
    __hv_varwrite_f(&sVarf_PKKWqEdV, VIf(Bf13));
    __hv_varread_f(&sVarf_PKKWqEdV, VOf(Bf13));
    __hv_line_f(&sLine_YAghyYIJ, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_s7mlO3VF, VIf(Bf6));
    __hv_varread_f(&sVarf_p0qEee95, VOf(Bf6));
    __hv_line_f(&sLine_XQfxtmDL, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_gasrCciw, VIf(Bf6));
    __hv_varwrite_f(&sVarf_PVOSpCGO, VIf(Bf4));
    __hv_varwrite_f(&sVarf_C8pZIDpj, VIf(Bf7));
    __hv_varwrite_f(&sVarf_HCFW3yT7, VIf(Bf8));
    __hv_varwrite_f(&sVarf_HN3ANOlN, VIf(Bf9));
    __hv_varwrite_f(&sVarf_reJO9akO, VIf(Bf12));
    __hv_varwrite_f(&sVarf_URFlykIs, VIf(Bf3));
    __hv_varwrite_f(&sVarf_aJgXMgLX, VIf(Bf5));
    __hv_varread_f(&sVarf_HCFW3yT7, VOf(Bf5));
    __hv_varread_f(&sVarf_HN3ANOlN, VOf(Bf3));
    __hv_varread_f(&sVarf_reJO9akO, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O1), VOf(O1));
    __hv_varread_f(&sVarf_IpRNBWVU, VOf(Bf12));
    __hv_varread_f(&sVarf_SaM7xH3r, VOf(Bf5));
    __hv_varread_f(&sVarf_C8pZIDpj, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
